.. _release-2019-2-1:

===========================
Salt 2019.2.1 Release Notes
===========================

Version 2019.2.1 is a bugfix release for :ref:`2019.2.0 <release-2019-2-0>`.

Known Issues
============

* **ISSUE** `#54751`_: Proxy minion fails to start. Fix planned in 2019.2.2 release.

* **ISSUE** `#54762`_: URIs with IPv6 addresses are broken, preventing master-minion communication in IPv6-only environments. Fix planned in 2019.2.2 release.

* **ISSUE** `#54776`_: Minion fails to start when it contains `ping_interval` in minion configuration file. Fix planned in 2019.2.2 release.

* **ISSUE** `#54731`_: Returners (except for default salt master returner) not loading properly in Py3. Fix planned in 2019.2.2 release.

* **ISSUE** `#54758`_: salt-call state.show_states gives  "Passed invalid arguments" error when a sls defined in top.sls file is missing. Fix planned in 2019.2.2 release.

* **ISSUE** `#54765`_: Jinja from import is broken. Fix planned in 2019.2.2 release.

* **ISSUE** `#54771`_: Affects only Debian 10. pkgrepo.managed does not work if used with proxy (configured at salt-minion). No fix date available yet.

* **ISSUE** `#54759`_: Deprecation warnings for pyzmq. No fix date available yet.

Change to YAML Renderer
=======================

.. code-block:: jinja

    /etc/foo.conf:
      file.managed:
        - source: salt://foo.conf.jinja
        - template: jinja
        - context:
            data: {{ data }}

In 2019.2.0, the above SLS will result in an error message following changes to
the YAML renderer that now require the new Jinja filter `tojson`.

.. code-block:: jinja

    /etc/foo.conf:
      file.managed:
        - source: salt://foo.conf.jinja
        - template: jinja
        - context:
            data: {{ data|tojson }}

In 2019.2.1, we introduce a new configuration option for both the Salt master and Salt minion
configurations to be able to support the older YAML renderer.  Using the option
``use_yamlloader_old`` will allow the YAML renderer to function as before.

Statistics
==========

- Total Merges: **541**
- Total Issue References: **70**
- Total PR References: **355**

- Contributors: **49** (`Akm0d`_, `Ch3LL`_, `DmitryKuzmenko`_, `Ethyling`_, `FireGrace`_,
  `KChandrashekhar`_, `ScoreUnder`_, `amendlik`_, `aplanas`_, `arsiesys`_, `bbinet`_, `bryceml`_,
  `cbosdo`_, `cdalvaro`_, `chdamianos`_, `cmcmarrow`_, `cro`_, `damianosSemmle`_, `dmurphy18`_,
  `doesitblend`_, `dwoz`_, `felippeb`_, `frogunder`_, `garethgreenaway`_, `github-abcde`_, `isbm`_,
  `jfindlay`_, `lomeroe`_, `mattLLVW`_, `mattp-`_, `mirceaulinic`_, `nicholasmhughes`_, `rbthomp`_,
  `rombert`_, `rsmekala`_, `s0undt3ch`_, `sathieu`_, `sbrennan4`_, `sdodsley`_, `simonflood`_,
  `sjorge`_, `soer7022`_, `stratusjerry`_, `tanlingyun2005`_, `terminalmage`_, `twangboy`_,
  `waynew`_, `weswhet`_, `xuhcc`_)

Changelog for v2019.2.0..v2019.2.1
==================================

*Generated at: 2019-09-09 19:56:22 UTC*

* **ISSUE** `#54429`_: (`frogunder`_) [2019.2.1] Sudo user error (refs: `#54433`_)

* **PR** `#54433`_: (`dwoz`_) Re-gen executors with proper arguments
  @ *2019-09-09 19:14:05 UTC*

  * 62fc61c Merge pull request `#54433`_ from dwoz/sudo_minion

  * e08eb19 Merge branch '2019.2.1' into sudo_minion

* **PR** `#54434`_: (`frogunder`_) fix_docs
  @ *2019-09-09 18:55:28 UTC*

  * 76fac57 Merge pull request `#54434`_ from frogunder/fix_doc

  * 2d22d73 fix_docs error

  * a266a5c fix_docs

  * db5464a Fix linter warts

  * 144a600 Re-gen executors with proper arguments

* **PR** `#54424`_: (`frogunder`_) remove in progress from release_notes 2019.2.1
  @ *2019-09-05 23:11:03 UTC*

  * 4071dcb Merge pull request `#54424`_ from frogunder/releasenotes_201921_new

  * b66436f Update 2019.2.1.rst

  * bcfef11 remove in progress from release_notes 2019.2.1

* **PR** `#54416`_: (`frogunder`_) Update man_pages for 2019.2.1
  @ *2019-09-05 22:48:51 UTC*

  * c1587cc Merge pull request `#54416`_ from frogunder/man_pages_201921

  * 6f7c4ee Update man_pages for 2019.2.1

* **PR** `#54419`_: (`frogunder`_) releasenotes 2019.2.1
  @ *2019-09-05 22:48:42 UTC*

  * 3118e2f Merge pull request `#54419`_ from frogunder/release_notes_201921

  * 2caee96 Update doc/topics/releases/2019.2.1.rst

  * ffabde2 Update 2019.2.1.rst

  * dd6426d Update doc/topics/releases/2019.2.1.rst

  * 9d4239c Update doc/topics/releases/2019.2.1.rst

  * 8c60ae4 Update doc/topics/releases/2019.2.1.rst

  * 72cb24c releasenotes 2019.2.1

* **PR** `#54409`_: (`dwoz`_) Point salt-call to correct multi-master configs
  @ *2019-09-04 20:08:24 UTC*

  * 04e28cf Merge pull request `#54409`_ from dwoz/mm_log

  * e207de6 Point salt-call to correct multi-master configs

* **PR** `#54396`_: (`dwoz`_) Use different logging port for multimaster tests
  @ *2019-09-03 23:20:23 UTC*

  * 2c281e0 Merge pull request `#54396`_ from dwoz/multimaster_logging

  * 104e0a0 Use different logging port for multimaster tests

* **ISSUE** `#54256`_: (`sleminov-tc`_) Empty salt api token file breaks maintenance process. (refs: `#54325`_, `#54324`_, `#54388`_, `#54376`_)

* **ISSUE** `#37945`_: (`gstachowiak`_) Missing exception handling in salt.master.Maintenance. Process never completes. (refs: `#54325`_, `#54324`_, `#54388`_, `#54376`_)

* **PR** `#54388`_: (`dwoz`_) 54256 re fix empty api token 2019.2.1
  @ *2019-09-03 23:19:20 UTC*

  * **PR** `#54325`_: (`waynew`_) Delete bad API token files (refs: `#54388`_)

  * **PR** `#54324`_: (`waynew`_) Delete bad API token files (refs: `#54325`_, `#54388`_)

  * 730a007 Merge pull request `#54388`_ from dwoz/54256-re-fix-empty-api-token-2019.2.1

  * 80651d3 Fix linter

  * 982ed3d Delete bad API token files

* **ISSUE** `#54256`_: (`sleminov-tc`_) Empty salt api token file breaks maintenance process. (refs: `#54325`_, `#54324`_, `#54388`_, `#54376`_)

* **ISSUE** `#37945`_: (`gstachowiak`_) Missing exception handling in salt.master.Maintenance. Process never completes. (refs: `#54325`_, `#54324`_, `#54388`_, `#54376`_)

* **PR** `#54376`_: (`dwoz`_) Move tokens in place with an atomic operation
  @ *2019-09-03 20:40:50 UTC*

  * 11016ce Merge pull request `#54376`_ from dwoz/tmp_token

  * 0b28c60 Fix linter complaints

  * 8e33343 Move tokens in place with an atomic operation

* **PR** `#54386`_: (`twangboy`_) Fix unit.utils.test_win_dacl (2019.2.1)
  @ *2019-09-03 16:57:25 UTC*

  * 5161203 Merge pull request `#54386`_ from twangboy/fix_test_win_dacl_2019.2.1

  * b8fa7d3 Sort the perms

* **PR** `#54355`_: (`s0undt3ch`_) [2019.2.1] [GitPillar Tests] Have the started processes log instead of just writing to stdout/stderr
  @ *2019-08-29 23:26:50 UTC*

  * b4caaad Merge pull request `#54355`_ from s0undt3ch/hotfix/test-daemons-2019.2.1

  * 561c0a2 Have the started processes log instead of just writing to stdout/stderr

  * c2a3115 Don't overwritethe stderr logger

* **PR** `#54353`_: (`cmcmarrow`_) adds @skipIf not windows
  @ *2019-08-29 19:33:11 UTC*

  * ce5b109 Merge pull request `#54353`_ from cmcmarrow/2019_win_system_skip

  * 8e28074 adds @skipIf not windows

* **PR** `#54338`_: (`dwoz`_) Log server closes completely during shutdown
  @ *2019-08-29 17:14:05 UTC*

  * 94c03e5 Merge pull request `#54338`_ from dwoz/logging_fixup

  * a3e227e Log server closes completely during shutdown

* **PR** `#54327`_: (`garethgreenaway`_) [2019.2.1] Catch the AccessDenied exception and continue when running under Py3.
  @ *2019-08-29 16:59:34 UTC*

  * 490ee69 Merge pull request `#54327`_ from garethgreenaway/more_test_program_fixes

  * 97b4d86 Catch the AccessDenied exception and continue when running under Py3.

* **PR** `#54316`_: (`Akm0d`_) Azure cleanup
  @ *2019-08-27 16:14:09 UTC*

  * bb911c3 Merge pull request `#54316`_ from Akm0d/azure-cleanup

  * 2072773 pass longer timeout to msazure destroyinstance

  * 34eb477 Merge branch '2019.2.1' of https://github.com/saltstack/salt into azure-cleanup

  * 7ae48b1 Allow azure tests enough time to clean up interfaces

  * b45ae74 Clean up azure instances properly

* **PR** `#54314`_: (`garethgreenaway`_) [2019.2.1] Do not raise the exception in testprogram.py
  @ *2019-08-26 23:59:37 UTC*

  * 9334e4e Merge pull request `#54314`_ from garethgreenaway/testprogram_access_denied_do_not_raise

  * a53bacb Do not raise the exception if a process can not be access, just continue

* **PR** `#54305`_: (`dwoz`_) Fix wart in test_process tests on windows
  @ *2019-08-26 17:59:12 UTC*

  * 71fb051 Merge pull request `#54305`_ from dwoz/winfix

  * 4e68860 Fix wart in test_process tests on windows

* **PR** `#54303`_: (`dwoz`_) Fix wart in periodic callback interval
  @ *2019-08-24 20:04:35 UTC*

  * 4d80f0a Merge pull request `#54303`_ from dwoz/periodic_cb

  * bf5f7de Fix wart in periodic callback interval

* **ISSUE** `#54219`_: (`KChandrashekhar`_) integration.shell.test_call.py and tests/integration/shell/test_proxy.py (refs: `#54259`_)

* **ISSUE** `#54153`_: (`KChandrashekhar`_) Ubuntu 16.04 Proxy failures  (refs: `#54259`_)

* **PR** `#54259`_: (`dwoz`_) Call os.fork less to avoid race conditions
  @ *2019-08-24 02:12:42 UTC*

  * 5838851 Merge pull request `#54259`_ from dwoz/less_forking

  * bf4d0dd Fix process list tests on windows py3

  * 316ec78 Allow more time for slow test

  * 9baf86f Do not remove attributes from process class

  * e7b6aa8 Clean up cruft

  * ed7103a Attempt to fix integration.shell.test_call test

  * 659c805 Change noise log to debug

  * 0660b1a Clean up typos

  * 9f1fe42 Call os.fork less to avoid race conditions

* **ISSUE** `#50814`_: (`doesitblend`_) Minion continues trying down master (refs: `#54239`_, `#53417`_)

* **ISSUE** `#49680`_: (`doesitblend`_) Beacon events handled differently than event.send (refs: `#53344`_, `#54239`_)

* **ISSUE** `#49663`_: (`doesitblend`_) Beacon only fires to single random master in HA mode (refs: `#53344`_, `#54239`_)

* **PR** `#54247`_: (`DmitryKuzmenko`_) 2019.2.1 with multimaster bb fixes
  @ *2019-08-23 20:19:19 UTC*

  * **PR** `#54239`_: (`DmitryKuzmenko`_) Multimaster tests with bb fixes (refs: `#54247`_)

  * **PR** `#53848`_: (`DmitryKuzmenko`_) Features/multimaster tests (refs: `#54239`_)

  * **PR** `#53417`_: (`DmitryKuzmenko`_) Multimaster minion hang on fire_master (refs: `#54239`_, `#53848`_)

  * **PR** `#53344`_: (`DmitryKuzmenko`_) Run beacons on the only one minion instance. Return to all masters. (refs: `#54239`_, `#53848`_)

  * 531f3aa Merge pull request `#54247`_ from DSRCorporation/2019.2.1_with_multimaster_bb_fixes

  * 62cd8cd Merge branch '2019.2.1' into 2019.2.1_with_multimaster_bb_fixes

* **PR** `#54235`_: (`github-abcde`_) Fix 46034 2019.2.1
  @ *2019-08-22 22:32:09 UTC*

  * 993c341 Merge pull request `#54235`_ from ogd-software/fix_46034-2019.2.1

  * 93bd30d Add alternative fix for "!" stomping Apparently (after watching Jenkins tests fail),
    what yaml.safe_load returns depends not on the version of salt, but on some other external
    dependency. Because of this, fix both possible return values.

  * c95dd4d Add test for this specific bugfix

  * efc29d8 Prevent yamlify_arg from stomping "!"

* **PR** `#54282`_: (`Akm0d`_) clean up renamed instances in the teardown
  @ *2019-08-22 22:13:51 UTC*

  * 5d1a4d0 Merge pull request `#54282`_ from Akm0d/clean-up-renamed

  * 11c1117 Removed redundant parenthesis

  * 802235d don't delete shutting down ec2 instances

  * 3602942 reversed the order in which an instance was renamed

  * 5500ede renamed _alt_name function

  * 23beab4 clean up renamed instances in the teardown

* **PR** `#54252`_: (`s0undt3ch`_) [2019.2.1] More control on spun test daemons on git pillar tests
  @ *2019-08-22 22:13:08 UTC*

  * c181f5a Merge pull request `#54252`_ from s0undt3ch/hotfix/git-pillar-2019.2.1

  * 4eb85fa Skip tests on RHEL family < 7

  * 64a1be8 Don't even go through the transport to get the system grains

  * d0f8efa Don't keep recreating the git repos. Restore from backup.

  * 6114e9d All prep work is done in `setUpClass`.

  * 5b030dd Daemons are now started/stopped on tests, not by salt

  * ed60f0d We don't actually need grains

  * 911446d Lock `uwsgi` requirement.

      * 805f0ac Merge branch '2019.2.1' into 2019.2.1_with_multimaster_bb_fixes

* **PR** `#54214`_: (`Ch3LL`_) Remove unnecessary logging from minion.py
  @ *2019-08-22 18:08:26 UTC*

  * b40cdbf Merge pull request `#54214`_ from Ch3LL/fix_logging

  * 8fd24cf Remove unnecessary logging from minion.py

      * 9d28098 Merge branch '2019.2.1' into 2019.2.1_with_multimaster_bb_fixes

* **PR** `#54277`_: (`dwoz`_) Win runas plus
  @ *2019-08-21 23:59:16 UTC*

  * de77762 Merge pull request `#54277`_ from dwoz/win_runas_plus

  * f719591 Update tests

  * d8749d9 Do not remove attributes from process class

  * ac5a2a4 Only close handle if it got created

* **PR** `#54278`_: (`Akm0d`_) Correctly detect when an ms_azure instance is deleted
  @ *2019-08-21 23:14:01 UTC*

  * 93cf40a Merge pull request `#54278`_ from Akm0d/cloud-test-logging

  * 2dc1520 Merge branch '2019.2.1' into cloud-test-logging

  * 3867448 Fixed incorrect arguments

  * bdce5f4 Fix detecting msazure deletion with multiple tries

* **PR** `#54263`_: (`s0undt3ch`_) [2019.2.1] Exit test suite if test daemons fail to start
  @ *2019-08-21 22:06:52 UTC*

  * 94f77a0 Merge pull request `#54263`_ from s0undt3ch/hotfix/test-daemons-2019.2.1

  * 655efd6 Rearrange logging termination

  * 28fa5d2 Prevent traceback on python interpreter shutdown

  * 9035731 Write to stderr a message with the exit code

  * 566c620 Exit the test suite if one of the test daemons fails to start

* **PR** `#54270`_: (`s0undt3ch`_) [2019.2.1] Speedup testing helpers decorators
  @ *2019-08-21 20:33:25 UTC*

  * 3b9fd44 Merge pull request `#54270`_ from s0undt3ch/hotfix/requires-system-grains-2019.2.1

  * 9f99bff Speedup testing helpers decorators

* **ISSUE** `#53931`_: (`KChandrashekhar`_) integration.states.test_pip_state.PipStateTest.test_issue_6912_wrong_owner_requirements_file (refs: `#54274`_)

* **PR** `#54274`_: (`felippeb`_) `#53931`_ never fail on codecov curls
  @ *2019-08-21 18:12:19 UTC*

  * 2c4afa0 Merge pull request `#54274`_ from felippeb/2019.2.1

  * 9c0b216 `#53931`_ never fail on codecov curls

* **PR** `#54264`_: (`dwoz`_) Fix unit utils jinja when run on their own
  @ *2019-08-21 17:22:10 UTC*

  * b3c70c3 Merge pull request `#54264`_ from dwoz/jinja_units

  * 10a6d53 Fix unit utils jinja when run on their own

* **PR** `#54266`_: (`Akm0d`_) Fix incorrect types on failing cloud tests
  @ *2019-08-21 17:14:40 UTC*

  * 308ba55 Merge pull request `#54266`_ from Akm0d/cloud_test_ultimate_fix

  * ff2125a Invert assertion to test for instance gone

  * 82136a8 test for ec2 instance shutting down

  * 283f631 run cloud --query if delete string is not available

  * 33e6b6d changed deprecated assertEquals

  * 41e6bc8 Cloud tests run correctly everywhere

  * 03a8b2c reverted literal_eval

* **PR** `#54251`_: (`Akm0d`_) reduced query calls to salt-cloud
  @ *2019-08-20 20:10:59 UTC*

  * 25d0b52 Merge pull request `#54251`_ from Akm0d/cloud_test_optimization

  * 5fe6bfc Optimized salt-cloud queries

  * 43418a4 Merge pull request `#7`_ from Ch3LL/cloud_provider_files

    * b93944b Remove joyent config cloud test files

    * bd37849 Rename provider azure-config to azurearm-config

  * e7c06cb Added longer delays for ec2 tests

  * 5ceb47e Correctly check for GCE and EC2 deletion

  * 52c178c Added pretty yaml formatting to cloud-test logs

  * 4fc5e9e re-fixed simultaneous GCE tests

  * 326e9f2 Merge pull request `#6`_ from Ch3LL/cloud_provider_files

    * adb1464 fix pylint

    * 51ce819 Move provider config setup into Setup/Teardown class

  * e58b40a Merge pull request `#5`_ from Ch3LL/cloud_provider_files

    * ab8adcc Only use the provider conf.d file we are testing

  * 76609ad Merge branch '2019.2.1' into cloud_test_optimization

  * f764bc0 Clean up expensive queries

  * b3d02df reduced query calls to salt-cloud

* **PR** `#54240`_: (`Ch3LL`_) Fix TypeError python3 in get_image_id ec2 cloud
  @ *2019-08-20 20:10:01 UTC*

  * ba81ca3 Merge pull request `#54240`_ from Ch3LL/get_image_ec2

  * a3a39f3 Use ami variable instead in test

  * dc1ae52 Fix TypeError python3 in get_image_id

          * d6ad475 Merge branch '2019.2.1' into 2019.2.1_with_multimaster_bb_fixes

* **PR** `#54246`_: (`dwoz`_) Cut down on log noise
  @ *2019-08-19 17:20:03 UTC*

  * 8404ec2 Merge pull request `#54246`_ from dwoz/log_noise

  * e572711 Cut down on log noise

* **PR** `#54245`_: (`dwoz`_) Fix the sshd pid file
  @ *2019-08-19 17:19:32 UTC*

  * 5b3e925 Merge pull request `#54245`_ from dwoz/sshd_pid_file

  * df95347 Fix the sshd pid file

* **PR** `#54237`_: (`dwoz`_) Do not dup2 things without fileno
  @ *2019-08-18 17:13:29 UTC*

  * 268803b Merge pull request `#54237`_ from dwoz/dup2

  * 2ebd22b Fix linter

  * 63c616a Do not dup2 things without fileno

      * 0b33498 Workaround for beacons.list_available slowness.

      * b7a1058 Minor: Better support of named multimaster tests.

      * a5cccdf Minor: remove unneded logging

      * 314bbb3 Support tcp transport in multimaster tests. Minor beacon update.

      * fcb8ff0 Properly set HAS_IPTABLES from __virtual__ return.

      * a75db01 Multimaster related fixup: don't run test engine on minions

      * 8a88542 Multimaster beacons fix: put list into a dict to fire on the bus

      * 790fb41 Inotify beacons test logging and cleanup update

      * d84c8851 Inotify beacon test fixes and improvements.

      * 472ffc0 Give minion more time to handle beacon creation.

      * 17ceee0 Fixed Lint errors

      * 0bcf53c Fixed the unicode and timing inotify test issues.

      * f17bcf3 Improved assertion error diagnostic for master down test.

      * db0bae8 Run multimaster as well tests when no specific group is set

      * 723f363 Ignore the multimaster minion subgroup test in module names test.

      * 612191c Fixed lint failures

      * c1efae6 Multimaster test for events handling on master disconnect

      * 1654fe8 Multimaster inotify beacons test

      * 65dc47c Multimaster tests environment and test module test.

      * 2c178b0 Moved annoying message to trace log level.

      * 3e497c1 Handle minion events asynchronously.

      * 909323a Tests fixes

      * 6dad18f Cleanup event object

      * 2bf55be Run beacons on the only one minion instance. Return to all masters.

* **PR** `#54121`_: (`Akm0d`_) Refactored cloud tests
  @ *2019-08-16 17:24:14 UTC*

  * 27d89bd Merge pull request `#54121`_ from Akm0d/gce_cloud_test

  * 48c57b3 Try multiple times to detect deletion of an instance

  * 74300eb return a valid set

  * 2d63b87 Wait for an instance to be fully created if necessary

  * 83ad8b3 Merge branch '2019.2.1' of github.com:SaltStack/salt into gce_cloud_test

* **ISSUE** `#54174`_: (`dwoz`_) SignalHandlingMultiprocessingProcess bugs (refs: `#54204`_)

* **PR** `#54204`_: (`dwoz`_) Fix signal handling in subprocesses
  @ *2019-08-16 00:46:40 UTC*

  * c5ee91c Merge pull request `#54204`_ from dwoz/signal_proc

  * 09e5e49 Merge branch '2019.2.1' into signal_proc

* **ISSUE** `#7745`_: (`mgwilliams`_) yaml 'module' has no attribute 'Dumper' (refs: `#54223`_)

* **PR** `#54223`_: (`dwoz`_) Test verify logs without a whole minion
  @ *2019-08-16 00:46:09 UTC*

  * 99a8fc5 Merge pull request `#54223`_ from dwoz/7754_test_removal

  * 4be711e Fix up linter warts

  * 7573826 Remove crufty un-needed tests

  * effa77d Test verify logs without a whole minion

    * b40f41f Revert fallback to default signals change

    * 1d83b10 Fix signal handling in subprocesses

      * f90fe66 Reverted foo/bar creds per `#46265`_

      * 3f56bad Reduced the amount of informtaion in debuggings tatements

      * de53bf0 Merge branch '2019.2.1' of github.com:SaltStack/salt into gce_cloud_test

* **PR** `#54203`_: (`dwoz`_) Run transport test loops in single thread
  @ *2019-08-15 20:10:20 UTC*

  * 8d440e0 Merge pull request `#54203`_ from dwoz/transport_tests

  * 22b9d38 Run transsport test loops in single thread

    * f6180a6 Even better logging of errors

    * a15dc4b better formatting and error reporting

    * 51fbc2a better logging on instance create failure

    * 1f7dd52 removed hack fixes from gce

    * 31cdc7c WAR ROOM SKIP GCE TESTS

    * 7d603be hasattr cannot find parent properties starting with __

    * 686cab9 Separated assertInstanceDestroy and _destry_instance

    * 158a38c Revert "Removed subclass from cloud name"

    * b7cf43d Removed subclass from cloud name

    * 8c5eb18 fixed pylint error on format string

    * 59e20bc Merge branch '2019.2.1' of https://github.com/saltstack/salt into gce_cloud_test

* **PR** `#54191`_: (`garethgreenaway`_) [2019.2.1] Addition logging in testprogram used by integration.shell.test_minion.MinionTest.test_exit_status_correct_usage
  @ *2019-08-13 21:44:41 UTC*

  * a05018e Merge pull request `#54191`_ from garethgreenaway/test_program_test_mininion

  * 8463f84 Adding some additional logging when the call to "proc_cmdline = proc.cmdline()" reults in a AccessDenied exception, so we can see what the process is and who the process is running as.

* **PR** `#54202`_: (`waynew`_) Only run one filter test
  @ *2019-08-13 21:33:32 UTC*

  * e5e9299 Merge pull request `#54202`_ from waynew/shorter-jinja-ssh-tests

  * c333ac8 Only run one filter test

    * 5912f24 Switched to Azurearm over msazure

* **PR** `#54172`_: (`Ch3LL`_) Migrate from azure to azurearm tests
  @ *2019-08-13 20:07:34 UTC*

  * a13cb3e Merge pull request `#54172`_ from Ch3LL/azurearm_tests

  * 465523f Migrate from azure to azurearm tests

* **ISSUE** `#50535`_: (`wyardley`_) salt errors with current azure-storage because of no version set (refs: `#50567`_)

* **PR** `#54173`_: (`Ch3LL`_) Cherry Pick `#50567`_ and `#53238`_ into 2019.2.1
  @ *2019-08-13 20:07:09 UTC*

  * **PR** `#53238`_: (`nicholasmhughes`_) Azure: Fixed ability to pass SSH key to Linux VMs (refs: `#54173`_)

  * **PR** `#50567`_: (`rombert`_) azurefs: gracefully handle AttributeError (refs: `#54173`_)

  * 39d0c59 Merge pull request `#54173`_ from Ch3LL/azure_fixes

  * 9052eaf reverting log string handling

  * a1a61ee fixed ability to pass ssh key to Linux VMs

  * 4a141a1 azurefs: gracefully handle AttributeError

    * 6fa28de fixed underscore

      * c35379a Moved finding installer into class

    * 95484f8 Moved finding installer into class

    * a86ae34 moved installer finder to SetUp method

    * 933964a removed default user/pass from profitbricks test file

    * 2a2437d fixed dictionary access

    * b9ee411 Fixed broken tests

    * 80efd26 fixed misspelled provider information

    * 511779b removed unused imports

    * 1cd1c13 setUp all cloud tests the same way

    * d322408 Got rid of unnecessary delay

    * 98ba18c fixed pylint error

    * c34c17e Merge branch '2019.2.1' of https://github.com/saltstack/salt into gce_cloud_test

* **PR** `#54178`_: (`dwoz`_) Fix flaky set_computer_name in mac_system module
  @ *2019-08-12 18:26:40 UTC*

  * 19f4d5e Merge pull request `#54178`_ from dwoz/mac_computer_name

  * e51100e Fix skip on non macos platforms

  * a3a9d92 Fix linter

  * c499d44 Revert unwanted flaky from non computer name tests

  * 941fcc8 Fix flaky set_computer_name in mac_system module

      * 90e8350 Merge branch '2019.2.1' of https://github.com/saltstack/salt into gce_cloud_test

* **PR** `#54180`_: (`dwoz`_) Point test-kitchen to my keepalive_maxcount branch
  @ *2019-08-12 18:18:26 UTC*

  * 6fe6799 Merge pull request `#54180`_ from dwoz/keepalive_maxcount

  * dc9ee21 Add reminder about kitchen version

  * 19a1f1b Point test-kitchen to my keepalive_maxcount branch

    * 60f8351 Fixed failing Ec2 Tests

    * e2f085c removed py3-only function call

    * 4406c57 fixed lint errors, more descriptive fails

    * 6840d5f assert instances exist in unified way

    * 03da233 skip EOL joyent tests, secure delete instances

    * 3123bb1 Merge branch '2019.2.1' of https://github.com/saltstack/salt into gce_cloud_test

* **ISSUE** `#53306`_: (`doesitblend`_) Fully Qualify CMD on Windows Minions (refs: `#53311`_, `#54033`_)

* **PR** `#54033`_: (`twangboy`_) Backport `#53311`_ to 2019.2.1
  @ *2019-08-09 16:46:36 UTC*

  * **PR** `#53311`_: (`doesitblend`_) Add fully qualified cmd call (refs: `#54033`_)

  * 9f5302d Merge pull request `#54033`_ from twangboy/fix_win_service_2019.2.1

  * 2850fab Merge branch '2019.2.1' into fix_win_service_2019.2.1

  * 0e2a2b8 Merge branch '2019.2.1' into fix_win_service_2019.2.1

  * 16c704e Backport `#53311`_ to 2019.2.1

* **PR** `#53900`_: (`twangboy`_) Fix inconsistent full names in LGPO
  @ *2019-08-09 09:15:41 UTC*

  * c0e49d9 Merge pull request `#53900`_ from twangboy/fix_lgpo

  * e05abdf Merge branch '2019.2.1' into fix_lgpo

  * e4e71cd Remove duplicate test

  * 68c632b Add some tests

  * 3c34075 Fall back to slower method if new method not available

  * 0108bcd Avoid using the lowercase method in XPath

  * fcc0405 Fix telemetry issue, add some timining logs

* **PR** `#52818`_: (`twangboy`_) Add watchdog as a bundled dependency on Windows
  @ *2019-08-09 04:26:54 UTC*

  * 9eb2938 Merge pull request `#52818`_ from twangboy/add_watchdog

  * 2658634 pre-commit

  * 35691f2 Add watchdog to Linux and OSX .in files

  * 5ef5969 Rremove opensuse 42 static files

  * ec285d0 Remove watchdog from the rest of the .in files

  * 86e64ae Remove unused import, remove Windows reference

  * b934d53 Remove watchdog from windows.in

  * cfaee96 Fix and unify watchdog beacon tests for all OS's

  * cc73204 Put Windows tests in their own class

  * 6fbf1a3 Remove unused import... lint

  * 832a1db Fix windowsisms

  * 4f47d50 Update static requirements

  * 762fe3b Remove some fluff

  * 946076c Add watchdog for tests

  * 02248dc Fix modified test to account for OS variances

  * 15ee479 Compile static requirements

  * 78a5723 Add watchdog to Linux and OSX .in files

  * 9a0f08a Update static requirements

  * 5cad13b Rremove opensuse 42 static files

  * 1f05fce Remove watchdog from the rest of the .in files

  * 121595a Remove unused import, remove Windows reference

  * c410a4b Remove watchdog from windows.in

  * 05a0845 Fix and unify watchdog beacon tests for all OS's

  * 200e230 Put Windows tests in their own class

  * 6cc8d96 Remove unused import... lint

  * a4abb72 Fix windowsisms

  * 005bed9 Update static requirements

  * c1bc627 Remove some fluff

  * 92c8d47 Add watchdog for tests

  * 9544624 Add watchdog as a bundled dependency on Windows

* **PR** `#54143`_: (`Akm0d`_) Don't call potentially missing shade library (`#53734`_)
  @ *2019-08-09 01:05:26 UTC*

  * **PR** `#53734`_: (`Akm0d`_) Don't call potentially missing shade library (refs: `#54143`_)

  * 5bef520 Merge pull request `#54143`_ from Akm0d/openstack_fix

  * 3f58885 Merge branch '2019.2.1' into openstack_fix

  * 71f5f38 Don't call potentially missing shade library (`#53734`_)

            * 29ee7ce removed print statements, optimized query

            * 14b7539 added back print statements for easy debug

            * 823b3b2 Removed print statements and broken re

            * 9696ed9 experiment with sublcass names

            * 2fa6157 more verbose instance names based on test

            * 2acb2df undercased non-const variable and added print statements

            * c5e875d Merge branch '2019.2.1' of https://github.com/saltstack/salt into gce_cloud_test

* **PR** `#54001`_: (`garethgreenaway`_) [2019.2.1] Porting metaproxy changes in `#50183`_ to 2019.2.1
  @ *2019-08-08 04:24:31 UTC*

  * **PR** `#50183`_: (`cro`_) Allow proxy minion types to be dynamically loaded (refs: `#54001`_)

  * 584e3f2 Merge pull request `#54001`_ from garethgreenaway/add_metaproxy_2019_2_1

  * 8353467 Merge branch 'add_metaproxy_2019_2_1' of github.com:garethgreenaway/salt into add_metaproxy_2019_2_1

    * 1892d86 Merge branch '2019.2.1' into add_metaproxy_2019_2_1

  * ab72e1b Adding unit.test_proxy_minion to ignore list

  * 09f6fed Removing match tests, functionality does not exist in 2019.2.1

  * 4af95e4 Adding tests to ensure _metaproxy_call to called when ProxyMinion objects are created.

  * d162a88 Adding salt/metaproxy/proxy.py and tests/unit/modules/test_match.py

  * 51726b1 POrting metaproxy changes in `#50183`_ to 2019.2.1

* **ISSUE** `#51008`_: (`cdalvaro`_) cwd option not working with cmd.run and runas (refs: `#52632`_, `#54079`_)

* **PR** `#54136`_: (`ScoreUnder`_)  Fix cmd.run on MacOS (rebased)
  @ *2019-08-08 04:20:31 UTC*

  * **PR** `#54079`_: (`ScoreUnder`_) Fix cmd.run on MacOS -- wrong environment variables (refs: `#54136`_)

  * **PR** `#52632`_: (`cdalvaro`_) Prevent shell injection as root with cmd.run on macOS (refs: `#54079`_)

  * **PR** `#47212`_: (`weswhet`_) fix macOS running as user. (refs: `#54079`_)

  * bf863d0 Merge pull request `#54136`_ from ScoreUnder/2019.2.1-patch-macos-cmd.run

  * 1182eb9 Add integration test justifying strange use of braces after cd in cmd.run

  * 733d2e7 Fixes to ITs

  * da38993 Add integration tests for cwd/runas changes on MacOS

  * ab8b39c Fix environment in cmd.run runas on MacOS

            * c9cb18f Don't call potentially missing shade library (`#53734`_)

            * 5ef8414 Added more verbose logging to cloud tests

            * 2f3942f better logging and fail messages

            * 9454f4c Fixed pylint errors and temporary print statements

            * fd13ce1 Further refactored cloud test code

            * b03cc48 Assume the instance exists and needs to be deleted

            * 0991ff5 fixed pylint errors and failed tests

            * 55e502a Merge branch '2019.2.1' of https://github.com/saltstack/salt into gce_cloud_test

* **PR** `#53974`_: (`Ch3LL`_) [2019.2.1] Add pygit2 requirement
  @ *2019-08-06 17:32:05 UTC*

  * e268b95 Merge pull request `#53974`_ from Ch3LL/add_pygit2

  * 11864a0 Merge branch '2019.2.1' into add_pygit2

  * d1b1452 Merge branch '2019.2.1' into add_pygit2

  * a5698cc Merge branch '2019.2.1' into add_pygit2

  * 7dd97a6 Merge branch '2019.2.1' into add_pygit2

  * 358974a Skip Pygit2 tests on windows

  * bc64961 Use accurate file:/// URI on windows for gitfs tests

  * 894f958 Fix GitFS support for pygit2 >= 0.28.0

  * 4580030 [2019.2.1] Add pygit2 requirement

                  * 4009bb5 fixed pylint errors

                  * 459b16d put cloudtest base in separate file so that only one change needs to be made

                  * 8e72335 Merge branch 'gce_cloud_test' of github.com:Akm0d/salt into gce_cloud_test

                    * 0e2621e Merge branch '2019.2.1' into gce_cloud_test

                  * 9f98b16 finished merge

* **PR** `#54108`_: (`dwoz`_) More robust azure instance deletion
  @ *2019-08-03 03:58:20 UTC*

  * 46f5e2e Merge pull request `#54108`_ from dwoz/azure_test

  * 754b719 Fix linter

  * 773235d Fix missing time import

  * 5a8f2ec More robust azure instance deletion

* **PR** `#54017`_: (`dmurphy18`_) Allow for main thread having terminated pid, before ThreadPoolExecutor threads
  @ *2019-08-02 18:11:48 UTC*

  * 2cb5a0b Merge pull request `#54017`_ from dmurphy18/fix_deb9_build90_tests

  * 2866520 Skip process kill tests on Windows

  * 5577f14 Clean up lint errors

  * 4ca709e Merge branch '2019.2.1' into fix_deb9_build90_tests

  * 264c767 Merge pull request `#1`_ from dwoz/fix_deb9_build90_tests

    * 9bb9466 Add unit tests for weird pid does not exist cases

    * 64d9752 Add warning messages to help determine why pids do not exist

  * 406d382 Adjusted for review comments

  * 2d20fbe Adjusted try/except statements on process checking

  * e189177 Removed typos

  * 2e3ca43 Updated for review comments

  * 68c29af Allow for main thread having terminated pid, before ThreadPoolExecutor threads

                * e3158c8 refactored all cloud tests

                * 194e0c7 Refactored GCE cloud test

* **PR** `#54080`_: (`dmurphy18`_) Disabling random website tests till allow for quota usage
  @ *2019-07-31 21:16:54 UTC*

  * 4e2efcd Merge pull request `#54080`_ from dmurphy18/u1804_py3_random_skip

  * 0660e6e Disabling random website tests till allow for quota usage

* **PR** `#54063`_: (`twangboy`_) Make the skip apply to any system missing crypt
  @ *2019-07-30 19:22:07 UTC*

  * dbbbcc9 Merge pull request `#54063`_ from twangboy/fix_test_pycrypto_2019.2.1

  * 6fcf035 Make the skip apply to any system missing crypt

* **PR** `#54050`_: (`cmcmarrow`_) fixs integration terminate error
  @ *2019-07-30 13:38:55 UTC*

  * 4df6271 Merge pull request `#54050`_ from cmcmarrow/integration_terminate_fix

  * ebb07f4 Merge branch '2019.2.1' into integration_terminate_fix

* **PR** `#54057`_: (`dmurphy18`_) Added support for is_fedora and skip Minion test test_issue_7754 on Fedora
  @ *2019-07-29 22:41:25 UTC*

  * 9d1bd63 Merge pull request `#54057`_ from dmurphy18/fix_fedora30_test

  * 30f3bda Added support for is_fedora and skip Minion test test_issue_7754

  * b3293a9 Merge branch '2019.2.1' into integration_terminate_fix

* **ISSUE** `#53948`_: (`KChandrashekhar`_) integration.shell.test_call.CallTest.test_issue_2731_masterless (refs: `#54040`_)

* **ISSUE** `#2731`_: (`cwood`_) Masterless Broken in 0.10.5 (refs: `#54040`_)

* **PR** `#54040`_: (`waynew`_) Remove dead test
  @ *2019-07-29 17:23:45 UTC*

  * 5d3bcd7 Merge pull request `#54040`_ from waynew/remove-dead-test

  * e9a5a57 Remove dead test

    * ba3e867 Merge branch '2019.2.1' into integration_terminate_fix

* **PR** `#54051`_: (`twangboy`_) Skip get time test
  @ *2019-07-29 16:54:50 UTC*

  * 70ffcec Merge pull request `#54051`_ from twangboy/fix_test_system

  * ceaba05 Skip get time test

* **PR** `#54038`_: (`Ch3LL`_) Pyton3 digital ocean test fix: to_str on key
  @ *2019-07-29 16:54:19 UTC*

  * 4aed833 Merge pull request `#54038`_ from Ch3LL/do_py3_fix

  * f7346db Pyton3 digital ocean test fix: to_str on key

      * 05cd93f fixs integration terminate error

      * 69c3106 fixs integration terminate error

* **PR** `#53735`_: (`twangboy`_) Fix Windows tests in test_system
  @ *2019-07-26 22:38:28 UTC*

  * 3cedacd Merge pull request `#53735`_ from twangboy/fix_test_system

  * a9e9c97 Add timeouts and account for those in assert

  * d3a160e Merge branch '2019.2.1' into fix_test_system

  * f95f0e7 Merge branch '2019.2.1' into fix_test_system

  * 87e02b8 Use setUpClass

  * 6a685bd Fix some tests in the Windows Class

* **PR** `#53953`_: (`Ch3LL`_) Send SIGTERM to webserver in teardown of gitfs tests
  @ *2019-07-25 21:12:42 UTC*

  * cc1cda1 Merge pull request `#53953`_ from Ch3LL/improve_git_test

  * 347ea1e Use Sigkill and add time.sleep before check

  * 637bf95 Merge branch '2019.2.1' into improve_git_test

  * c0be147 Send SIGTERM webserver during teardown of gitfs tests

  * b776c0c Check if gitfs server fails to setup for tests

* **PR** `#53999`_: (`Ch3LL`_) Generate new key each time for digital ocean key test
  @ *2019-07-25 21:07:45 UTC*

  * 2324167 Merge pull request `#53999`_ from Ch3LL/fix_digital_ocean

  * b0b6e3b Generate new key each time for digital ocean key test

* **PR** `#53970`_: (`garethgreenaway`_) [2019.2.1] Adding a WAR ROOM Skip for test_directory_clean_require_with_name
  @ *2019-07-25 21:03:49 UTC*

  * 32fec66 Merge pull request `#53970`_ from garethgreenaway/osx_skip_test_directory_clean_require_with_name

  * 362b84a Adding a WAR ROOM Skip for test_directory_clean_require_with_name

* **PR** `#54003`_: (`dwoz`_) War room skip for tcp build
  @ *2019-07-24 22:52:18 UTC*

  * 213dfff Merge pull request `#54003`_ from dwoz/skip_test

  * 6cdb8fa War room skip for tcp build

* **PR** `#53897`_: (`cmcmarrow`_) patches salt grains locale_info decode error
  @ *2019-07-23 13:19:00 UTC*

  * 048c097 Merge pull request `#53897`_ from cmcmarrow/timezone_fix

  * d9e402d Merge branch '2019.2.1' into timezone_fix

* **PR** `#53920`_: (`s0undt3ch`_) [2019.2.1] Update CI pipelines. Remove old jenkins cruft.
  @ *2019-07-20 12:33:01 UTC*

  * 9a846b4 Merge pull request `#53920`_ from s0undt3ch/hotfix/ci-pipelines-2019.2.1

  * b09963b Update CI pipelines. Remove old jenkins cruft.

* **PR** `#53728`_: (`garethgreenaway`_) [2019.2.1] Disabling test_get_set_computer_name on OS X and Py3
  @ *2019-07-19 17:18:33 UTC*

  * 15accef Merge pull request `#53728`_ from garethgreenaway/2019_2_1_mac_system_disable_test_get_set_computer_name

  * a6d853c Merge branch '2019.2.1' into 2019_2_1_mac_system_disable_test_get_set_computer_name

  * 5d537ed Missing six import.  Updating skip message.

  * ac6dccd Disabling test_get_set_computer_name on OS X and Py3.

* **PR** `#53913`_: (`garethgreenaway`_) [2019.2.1] skip test_issue_2594_non_invalidated_cache on MacOS
  @ *2019-07-19 17:17:36 UTC*

  * a54ec89 Merge pull request `#53913`_ from garethgreenaway/disable_test_issue_2594_non_invalidated_cache_macos

  * c65c5d5 Skip the test test_issue_2594_non_invalidated_cache on MacOS where it is flakey.

* **PR** `#53902`_: (`twangboy`_) Skip tests that modify date or time
  @ *2019-07-18 17:53:31 UTC*

  * b091eb7 Merge pull request `#53902`_ from twangboy/skip_dt

  * 76cf936 Skip tests that modify date or time

* **PR** `#53901`_: (`s0undt3ch`_) [2019.2.1] Don't fail when combining coverage files
  @ *2019-07-18 17:46:32 UTC*

  * 22b7b1a Merge pull request `#53901`_ from s0undt3ch/hotfix/wrap-coverage-combine

  * b459a48 Don't fail when combining coverage files

* **PR** `#53542`_: (`dwoz`_) Fix leak of SaltMessageClient instances when using tcp transport
  @ *2019-07-18 17:44:44 UTC*

  * 84e798a Merge pull request `#53542`_ from dwoz/tcp_leak

  * 3daeb4f Update TCP pipelines

  * 52f9556 Merge branch '2019.2.1' into tcp_leak

  * f5313fd Fix tcp message client test

  * 3419bf5 Merge branch '2019.2.1' into tcp_leak

  * 3125cd3 Merge branch '2019.2.1' into tcp_leak

  * 9a33582 Merge branch '2019.2.1' into tcp_leak

  * 7eb5d41 Merge branch '2019.2.1' into tcp_leak

  * 481372b Fix torando loop thread issue

  * aff15d4 Fix linter wart

  * 9606db7 Comment the tcp message client test better

  * dcf576f Add unit test for tcp message client close method

  * 4420556 Download artifacts for tcp jobs

  * e6a09dd Merge remote-tracking branch 'origin/tcp_leak' into tcp_leak

    * f484f3f Merge branch '2019.2.1' into tcp_leak

  * 4a37234 Add tcp suffix to github notifications

  * 4a2848b Add transport PR tests

  * 9a4b407 Fix leak of SaltMessageClient instances when using tcp transport

                  * 592f3fe undo test

                  * bc550ad wip pytest test david

                  * 75571e4 fixs timezone decode error

                  * d041660 fixes timezone decode error

                  * 1ddd1a9 fixs timezone decode error

                  * e75dafa patches timezone grain

                  * eaca473 patches salt grains locale_info decode error

* **PR** `#53873`_: (`bryceml`_) increase sleep time between kitchen create failures to account for ap...
  @ *2019-07-16 23:46:09 UTC*

  * 61e9efd Merge pull request `#53873`_ from bryceml/2019.2.1-increase-sleep

  * aae0bf6 increase sleep time between kitchen create failures to account for api limits

* **PR** `#53750`_: (`twangboy`_) Fix memory error when the test suite cleans up (2019.2.1)
  @ *2019-07-16 23:00:07 UTC*

  * 317d9af Merge pull request `#53750`_ from twangboy/fix_helpers

  * fa0e9c3 Merge branch '2019.2.1' into fix_helpers

* **PR** `#53851`_: (`dwoz`_) Master stats revert
  @ *2019-07-16 16:05:38 UTC*

  * 6c2b3a5 Merge pull request `#53851`_ from dwoz/master_stats_revert

  * 0bc72e4 Revert "Merge pull request `#53822`_ from dwoz/master_stats_test"

  * 4553ba7 Revert "Merge pull request `#53829`_ from saltstack/fix_stats_2019.2.1"

* **PR** `#53829`_: (`dwoz`_) Fix stats on windows
  @ *2019-07-12 01:03:47 UTC*

  * 5064027 Merge pull request `#53829`_ from saltstack/fix_stats_2019.2.1

  * 9f2d20d Fix stats on windows

* **PR** `#53826`_: (`dmurphy18`_) WAR ROOM test skip till rewritten to allow for dnf on RHEL 8 and F30
  @ *2019-07-12 00:39:11 UTC*

  * 971eda3 Merge pull request `#53826`_ from dmurphy18/fedora30_fixes

  * 34b261d WAR ROOM test skip till rewritten to allow for dnf on RHEL 8 and Fedora 30

* **PR** `#53822`_: (`dwoz`_) Enable master stats for tests
  @ *2019-07-11 23:37:55 UTC*

  * ba33d76 Merge pull request `#53822`_ from dwoz/master_stats_test

  * d2b8315 Enable master stats for tests

  * 3471422 Fix memory error when the test suite cleans up

* **PR** `#53591`_: (`twangboy`_) Fix whitelist errors in `test_boto_*` state tests on Windows
  @ *2019-07-07 05:45:21 UTC*

  * 1756156 Merge pull request `#53591`_ from twangboy/fix_boto_tests

  * ba8ba26 Merge branch '2019.2.1' into fix_boto_tests

* **ISSUE** `#53532`_: (`dafyddj`_) win_lgpo.py: crash caused by empty presentation text element (refs: `#53662`_)

* **PR** `#53688`_: (`twangboy`_) Merge Forward `#53662`_ (2019.2.1)
  @ *2019-07-07 05:44:25 UTC*

  * **PR** `#53662`_: (`lomeroe`_) Update win_lgpo (refs: `#53688`_)

  * 464464c Merge pull request `#53688`_ from twangboy/mf_53662

  * c19dc97 Merge branch '2019.2.1' into mf_53662

* **ISSUE** `#52391`_: (`rsmekala`_) Port Junos-related bug fixes from develop to 2019.2 (refs: `#52401`_)

* **PR** `#52401`_: (`rsmekala`_) Port Junos-related bug fixes from develop to 2019.2
  @ *2019-07-06 21:50:51 UTC*

  * **PR** `#51164`_: (`rsmekala`_) Updates to salt-junos modules (refs: `#52401`_)

  * 1a76e00 Merge pull request `#52401`_ from rsmekala/2019.2.1

  * 345938d Merge branch '2019.2.1' into 2019.2.1

  * 326f9f4 Merge branch '2019.2.1' into 2019.2.1

  * c11a004 Merge branch '2019.2.1' into 2019.2.1

  * 33b45d2 Merge branch '2019.2.1' into 2019.2.1

  * af66fac Merge branch '2019.2.1' into 2019.2.1

  * 211b169 Ported relevant fixes from unit.modules.test_junos from develop to 2019.2

  * 0c51bc9 Ported relevant fixes from states.junos from develop to 2019.2

  * a966ad1 Ported relevant fixes from proxy.junos from develop to 2019.2

  * 263e9f5 Ported relevant fixes from modules.junos from develop to 2019.2

              * b9033b9 Merge branch '2019.2.1' into mf_53662

              * 75e740e Merge forward `#53662`_

                * 8ace391 Merge branch '2019.2.1' into fix_boto_tests

* **PR** `#53585`_: (`twangboy`_) Fix `test_winrepo` on Windows
  @ *2019-07-06 15:15:47 UTC*

  * 056f596 Merge pull request `#53585`_ from twangboy/fix_test_winrepo

  * c1f8cba Merge branch '2019.2.1' into fix_test_winrepo

* **PR** `#53590`_: (`twangboy`_) Fix `test status` on Windows
  @ *2019-07-06 15:15:13 UTC*

  * db950f2 Merge pull request `#53590`_ from twangboy/fix_test_status

  * 67750b7 Merge branch '2019.2.1' into fix_test_status

  * b667045 Merge branch '2019.2.1' into fix_test_status

  * 9b4338a Merge branch '2019.2.1' into fix_test_status

  * 2735b19 Add __grains__

  * bb12da9 Load grains properly

        * 91da774 Merge branch '2019.2.1' into fix_test_winrepo

* **PR** `#53556`_: (`twangboy`_) Fixes an issue with line endings in the jinja renderer
  @ *2019-07-05 23:06:01 UTC*

  * becaf12 Merge pull request `#53556`_ from twangboy/fix_test_pillar

  * ac405d1 Merge branch '2019.2.1' into fix_test_pillar

* **PR** `#53557`_: (`twangboy`_) Fix test_pydsl on Windows
  @ *2019-07-05 22:36:40 UTC*

  * 7a5111b Merge pull request `#53557`_ from twangboy/fix_test_pydsl

  * d9df951 Merge branch '2019.2.1' into fix_test_pydsl

  * 1619c68 Merge branch '2019.2.1' into fix_test_pydsl

  * 2c3e91d Fix test_pydsl on Windows

      * 137f4a4 Merge branch '2019.2.1' into fix_test_pillar

      * 4a96252 Fixes an issue with line endings in the jinja renderer

          * c8c8bc0 Merge branch '2019.2.1' into fix_test_winrepo

          * 8373865 Merge branch '2019.2.1' into fix_test_winrepo

          * a818396 Split out the tests, patch test=True

                    * 62041eb Merge branch '2019.2.1' into fix_boto_tests

* **PR** `#53653`_: (`s0undt3ch`_) [2019.2.1] Log which address failed to resolve
  @ *2019-07-05 18:29:31 UTC*

  * 8f05226 Merge pull request `#53653`_ from s0undt3ch/hotfix/fix-nox-bypass-2019.2.1

  * f44253c Merge branch '2019.2.1' into hotfix/fix-nox-bypass-2019.2.1

  * 0ead7fe Log which address failed to resolve

* **PR** `#53725`_: (`s0undt3ch`_) [2019.2.1] Archive the kitchen logs
  @ *2019-07-05 18:19:50 UTC*

  * f750f44 Merge pull request `#53725`_ from s0undt3ch/features/f30-reqs-2019.2.1

  * 118fbf7 Improve slack message

  * 62a2ee8 Archive the kitchen logs

* **PR** `#53689`_: (`twangboy`_) Merge Forward `#52593`_ (2019.2.1)
  @ *2019-07-05 14:58:10 UTC*

  * **PR** `#52593`_: (`twangboy`_) Update setup.py (refs: `#53689`_)

  * 0c6009f Merge pull request `#53689`_ from twangboy/fix_setup_2019.2.1

  * c6f3da5 Merge branch '2019.2.1' into fix_setup_2019.2.1

* **PR** `#53690`_: (`twangboy`_) Merge Forward `#52065`_ (2019.2.1)
  @ *2019-07-05 14:55:12 UTC*

  * **PR** `#52065`_: (`twangboy`_) Use the dism binary that matches system architecture (refs: `#53690`_)

  * 54c4220 Merge pull request `#53690`_ from twangboy/fix_win_dism_2019.2.1

  * fae9f1a Merge branch '2019.2.1' into fix_win_dism_2019.2.1

* **PR** `#53719`_: (`s0undt3ch`_) [2019.2.1] PR Pipeline Enhancements
  @ *2019-07-04 20:29:06 UTC*

  * 78c45eb Merge pull request `#53719`_ from s0undt3ch/features/f30-reqs-2019.2.1

  * 76b99fd Enhance lint report

  * 45f19af Use milestones to abort previous, still running, builds, on new builds

* **PR** `#53697`_: (`s0undt3ch`_) [2019.2.1] Add Fedora 30 requirements files
  @ *2019-07-04 04:26:02 UTC*

  * 3db4ddb Merge pull request `#53697`_ from s0undt3ch/features/f30-reqs-2019.2.1

  * 36198cd Delete Opensuse 42 static requirements

  * 4413626 Delete Fedora 28 static requirements

  * 41809e5 Add Fedora 30 requirements files

* **PR** `#53680`_: (`Ch3LL`_) Pytest 5.0 contextmanager str: call value on ExceptionInfo objects
  @ *2019-07-04 00:12:56 UTC*

  * f5c5da4 Merge pull request `#53680`_ from Ch3LL/pytest_5_changes

  * b5e2b0b Merge branch '2019.2.1' into pytest_5_changes

* **PR** `#53682`_: (`twangboy`_) Fix compare issue in lgpo state module
  @ *2019-07-03 04:43:22 UTC*

  * 727843c Merge pull request `#53682`_ from twangboy/fix_lock_1740_lgpo

  * 62450db Merge branch '2019.2.1' into fix_lock_1740_lgpo

  * f6276a3 Fix compare issue in lgpo state module

    * 110b953 Pytest 5.0 contextmanager str: call value on ExceptionInfo objects

    * b71b655 Merge forward `#52065`_

    * 023c47d Fix typo

    * 43dd7b3 Merge Forward `#52593`_

* **PR** `#53678`_: (`twangboy`_) Fix LGPO when string object is None
  @ *2019-07-02 23:47:05 UTC*

  * 491bfa8 Merge pull request `#53678`_ from twangboy/fix_lock_1688_lgpo

  * 7b05bf8 Merge branch '2019.2.1' into fix_lock_1688_lgpo

* **PR** `#53220`_: (`twangboy`_) Don't remove the pythonwin directory (2019.2.1)
  @ *2019-07-02 22:43:43 UTC*

  * 4a4a91b Merge pull request `#53220`_ from twangboy/fix_pywin32_2019.2.1

  * 748bf1c Merge branch '2019.2.1' into fix_pywin32_2019.2.1

* **PR** `#53614`_: (`Ch3LL`_) Increase flaky attempts on mac tests using systemsetup
  @ *2019-07-02 21:33:56 UTC*

  * c2befe2 Merge pull request `#53614`_ from Ch3LL/mac_flaky

  * 5460031 Merge branch '2019.2.1' into mac_flaky

  * 7dcaaf0 Increase flaky attempts on mac tests using systemsetup

* **PR** `#53624`_: (`Ch3LL`_) Allow yaml list notation for nodegroup expansion
  @ *2019-07-02 21:32:43 UTC*

  * 02461cb Merge pull request `#53624`_ from Ch3LL/nodegroup_group_list

  * 475d904 Merge branch '2019.2.1' into nodegroup_group_list

  * fbb15cd Add nodegroup list test

  * ee59d39 Merge branch '2019.2.1' into nodegroup_group_list

  * d236bd4 Allow yaml list notation for nodegroup expansion

* **PR** `#53562`_: (`Ch3LL`_) Move create key call into try/except in Digital Ocean key test
  @ *2019-07-02 16:08:08 UTC*

  * 8857dbd Merge pull request `#53562`_ from Ch3LL/do_key_test

  * 315eb35 Merge branch '2019.2.1' into do_key_test

  * 75ac708 Merge branch '2019.2.1' into do_key_test

  * 128ba07 Move create key call into try/except in Digital Ocean key test

        * 22d4a3a Merge branch '2019.2.1' into fix_pywin32_2019.2.1

        * 6bb6df7 Merge branch '2019.2.1' into fix_pywin32_2019.2.1

        * 534c984 Merge branch '2019.2.1' into fix_pywin32_2019.2.1

        * 382c637 Merge branch '2019.2.1' into fix_pywin32_2019.2.1

        * fb4090d update py3 script

        * 0ea70ba Don't remove pythonwin directory

                  * ba37276 Use string_types instead of text_types

                  * f6d0084 Add some unit tests, raise error on non-string types

                  * 35ed8be Create function for encoding string values

                  * c4c1082 Return encoded null when string value is None

* **PR** `#53627`_: (`dmurphy18`_) Cherry pick pr 53370 from 2018.3 into 2019.2.1
  @ *2019-06-28 19:54:13 UTC*

  * 164aaeb Merge pull request `#53627`_ from dmurphy18/cherry-pick-pr-53370

  * 450d23d Merge branch '2019.2.1' into cherry-pick-pr-53370

* **ISSUE** `#53411`_: (`cro`_) Events can grow stale when event_listen_queue is set. (refs: `#53587`_, `#53412`_)

* **PR** `#53587`_: (`cro`_) Forward port from 2018.3 Add event_listen_queue_max_seconds to fix `#53411`_
  @ *2019-06-28 16:49:46 UTC*

  * **PR** `#53412`_: (`cro`_) Stale events 53411 (refs: `#53587`_)

  * 6559e4c Merge pull request `#53587`_ from cro/53412-2019.2.1

  * 9e69bd4 Merge branch '2019.2.1' into 53412-2019.2.1

  * 949a026 Merge branch '2019.2.1' into 53412-2019.2.1

  * f5d81c9 Merge branch '2019.2.1' into 53412-2019.2.1

  * d74c313 Merge branch '2019.2.1' into 53412-2019.2.1

  * b3c3f52 Make doc build test pass.

  * 8001130 Add event_listen_queue_max_seconds to fix `#53411`_

          * 34e38d7 Merge branch '2019.2.1' into cherry-pick-pr-53370

* **ISSUE** `#53283`_: (`Ch3LL`_) integration.states.test_file.FileTest.test_directory_broken_symlink (refs: `#53295`_)

* **PR** `#53295`_: (`DmitryKuzmenko`_) Recurse kwarg of state.directory state shall be a list or None
  @ *2019-06-27 23:20:10 UTC*

  * 14efced Merge pull request `#53295`_ from DSRCorporation/bugs/test_file_recurse_set

  * 2927b78 Merge branch '2019.2.1' into bugs/test_file_recurse_set

  * 9c01670 Merge branch '2019.2.1' into bugs/test_file_recurse_set

  * 571d82a Merge branch '2019.2.1' into bugs/test_file_recurse_set

  * ee8f0e3 Merge branch '2019.2.1' into bugs/test_file_recurse_set

  * 013e04c Recurse kwarg of state.directory state shall be a list of None

* **ISSUE** `#52926`_: (`waynew`_) integration.states.test_beacon.BeaconStateTestCase.test_present_absent - Beacon "diskusage" is not available (refs: `#53493`_, `#53466`_)

* **ISSUE** `#52245`_: (`twangboy`_) integration.states.test_beacon.BeaconStateTestCase.test_present_absent (refs: `#53493`_, `#53466`_)

* **PR** `#53466`_: (`dwoz`_) More robust beacon state test
  @ *2019-06-27 23:17:01 UTC*

  * 75175bb Merge pull request `#53466`_ from dwoz/test_pres_abs

  * f24bf06 Use new pipeline format

  * a74580b Clean up cruft

  * 68958f5 Do not create duplicate minion ids

  * c47eeb4 Add amazon 2 to PR tests

  * dc90b47 More robust beacon state test

            * 95b1819 Initial working tests for gpg fixes and import keys, signing

            * b2c9ae2 Update access to str/bytes with to_unicode/to_bytes for Python 3

* **PR** `#53609`_: (`s0undt3ch`_) CI Pipelines. Timeout after getting a node. Report exit code.
  @ *2019-06-27 16:09:54 UTC*

  * 582ac5f Merge pull request `#53609`_ from s0undt3ch/hotfix/fix-nox-bypass-2019.2.1

  * 024be84 CI Pipelines. Timeout after getting a node. Report exit code.

* **PR** `#53574`_: (`s0undt3ch`_) [2019.2.1] Minor fixes/adjustments to the new CI pipelines
  @ *2019-06-25 18:48:25 UTC*

  * f568796 Merge pull request `#53574`_ from s0undt3ch/hotfix/fix-nox-bypass-2019.2.1

  * e85e2f4 Minor fixes/adjustments to the new CI pipelines

* **PR** `#53584`_: (`dwoz`_) Add unit tests for recent SaltCacheLoader changes
  @ *2019-06-24 23:40:43 UTC*

  * **PR** `#53563`_: (`twangboy`_) SaltCacheLoader does not create multiple FileClients (refs: `#53584`_)

  * 77b7fc4 Merge pull request `#53584`_ from dwoz/client_cache

  * e9b61dc Add unit tests for recent SaltCacheLoader changes

                        * 5558a0a Add reg to the whitelist

* **PR** `#53563`_: (`twangboy`_) SaltCacheLoader does not create multiple FileClients (refs: `#53584`_)
  @ *2019-06-22 23:23:03 UTC*

  * 6ed6c31 Merge pull request `#53563`_ from twangboy/py3_windows_hang

  * 369720e Allow the file_client to be overridden

  * f6c592c Don't instantiate the file_client every time

* **PR** `#53432`_: (`garethgreenaway`_) [2019.2.1] Various fixes for 2019.2.1 to ensure tests pass on Mac OS X
  @ *2019-06-21 13:47:41 UTC*

  * c606952 Merge pull request `#53432`_ from garethgreenaway/2019_2_1_mac_fixes

  * 1974f11 Disabling a couple more tests in integration.modules.test_cp that hang on OS X and Py2.

  * 7721151 Fixing lint.

  * 1d4e228 Updating various skips for tests to only skip if OS is OS X and Python is Python2.

  * 01dafdc Skipping integration.modules.test_cp.CPModuleTest.test_get_file_str_https on OS X

  * c02db20 Disabling integration.modules.test_state.StateModuleTest.test_parallel_state_with_long_tag

  * 8788877 Skip integration.states.test_file.FileTest.test_issue_11003_immutable_lazy_proxy_sum and integration.states.test_pip_state.PipStateTest.test_22359_pip_installed_unless_does_not_trigger_warnings when running on OS X.

  * cf76027 Removing wrong import of skipIf

  * b10e1e7 Moving the skipIf for OS X from the beacon state tests to the renderer state tests.

  * d2fef9a Disabling beacon state tests on OS X for the time being.

  * 1741bb0 Adding some timeouts to see if it helps the tests pass on OS X.

  * fd0ba0a Ensure the user and group used by @with_system_user_and_group are consistent.

  * e03ab81 Using salt.utils.path.which to find false, on OSX it lives under /usr/bin/

  * 353f9d4 Fixing the beacons.reset function.  Once the reset has taken place in beacons/__init__.py we need to fire an event back to complete the loop and ensure that everything worked as expected.

  * ee3cbc7 fix to how the depends decorator works.  Only run the dependency commands for the module we're checking.

  * 8440176 Fixing a log issue that pops up after test_gen_thin_compression_fallback_py3 on "OS X, need to ensure that salt.utils.thin.os.close is mocked.

  * 9767ddd Format for the sqlite3 database used for the assistive information changed in Mojave, additional columns added.

  * 9c8a7e6 Fixing a bug when the roots fileserver and the location is a symlink to another location.  This fix ensures that when fsroot is referenced we are using the real path and not the symlink path.

* **PR** `#53526`_: (`s0undt3ch`_) [2019.2.1] Update pipelines to work on old and new jenkins
  @ *2019-06-20 15:29:13 UTC*

  * 59e2a1f Merge pull request `#53526`_ from s0undt3ch/hotfix/fix-nox-bypass-2019.2.1

  * 24d6d09 Update pipelines to work on old and new jenkins

* **PR** `#53210`_: (`Ch3LL`_) Cherry-Pick `#52787`_ into 2019.2.1
  @ *2019-06-20 13:33:13 UTC*

  * **PR** `#52787`_: (`garethgreenaway`_) [2018.3] Fixes to test_pip state sls files (refs: `#53210`_)

  * f5f80af Merge pull request `#53210`_ from Ch3LL/cp-52787

  * f27c434 Merge branch '2019.2.1' into cp-52787

* **PR** `#53467`_: (`twangboy`_) Check valid username first (fixes failing symlink test)
  @ *2019-06-19 17:04:30 UTC*

  * fd6cb35 Merge pull request `#53467`_ from twangboy/fix_test_win_file

  * 92950c5 Merge branch '2019.2.1' into fix_test_win_file

  * 6a21edb Merge branch '2019.2.1' into fix_test_win_file

  * 31ce1fb Fix some lint, skip some tests

  * 6de4db6 Monkeypatch in the class instead of globally

  * d663a1f Fix the failing BlockReplace test cases on Windows

  * 299f88f Update test_managed_contents

  * 81110e5 Fix test_file_copy_make_dirs that was failing on Linux

  * 8d0529d Fix some lint

  * 4a9c020 Fix issues with win_runas

  * bceffa1 Remove privs message

  * 54be0a6 Verify username early in win_runas

* **PR** `#53475`_: (`Ch3LL`_) Add pypsexec requirement for cloud tests
  @ *2019-06-19 13:30:25 UTC*

  * 3230078 Merge pull request `#53475`_ from Ch3LL/add_pypsexec

  * ab59a55 Merge branch '2019.2.1' into add_pypsexec

  * f954363 Merge branch '2019.2.1' into add_pypsexec

  * 8f7cbfc Merge branch '2019.2.1' into add_pypsexec

  * fa22b39 Add pypsexec requirement for cloud tests

* **PR** `#53491`_: (`Ch3LL`_) Update test_gen_hash for macosx
  @ *2019-06-19 13:16:04 UTC*

  * bdd7c2c Merge pull request `#53491`_ from Ch3LL/crypt_test_mac

  * 85e96bd Merge branch '2019.2.1' into crypt_test_mac

  * 700338e Merge branch '2019.2.1' into crypt_test_mac

  * 4ce7fb1 Merge branch '2019.2.1' into crypt_test_mac

  * 832ded6 Merge branch '2019.2.1' into crypt_test_mac

  * 775b8c2 Merge branch '2019.2.1' into crypt_test_mac

  * 0832b49 Update test_gen_hash for macosx

* **PR** `#53494`_: (`Ch3LL`_) Always delete digital ocean key for test_key_management test
  @ *2019-06-19 13:14:51 UTC*

  * 8c2e952 Merge pull request `#53494`_ from Ch3LL/do_cloud_test

  * 5053eab Merge branch '2019.2.1' into do_cloud_test

  * 64a3e8d Merge branch '2019.2.1' into do_cloud_test

  * 45c0c43 Merge branch '2019.2.1' into do_cloud_test

  * 3826c56 Allows delete digital ocean key for test_key_management test

                * 6b6dc66 Merge branch '2019.2.1' into cp-52787

* **PR** `#53434`_: (`weswhet`_) Update documentation for newer mac_service module.
  @ *2019-06-19 01:15:19 UTC*

  * 2e3778b Merge pull request `#53434`_ from weswhet/patch-2

  * 89398a9 Update salt.modules.service.rst

  * b9c1b1a Update salt.modules.service.rst

  * a962a64 Merge branch '2019.2.1' into patch-2

* **PR** `#53498`_: (`amendlik`_) Fix broken documentation links
  @ *2019-06-18 23:44:05 UTC*

  * f72ebba Merge pull request `#53498`_ from amendlik/links

  * e360a70 Fix broken documentation links for service virtual module

  * 56f65ec Fix broken documentation links for pkg virtual module

    * 010a2c5 Update documentation for newer mac_service module.

              * 1bbdc7f Merge branch '2019.2.1' into cp-52787

* **PR** `#53514`_: (`Ch3LL`_) Revert logging changes from `#53492`_
  @ *2019-06-18 20:49:04 UTC*

  * **PR** `#53492`_: (`dwoz`_)  Fix syndic connection when using tcp transport (refs: `#53514`_)

  * 0793272 Merge pull request `#53514`_ from Ch3LL/disable_py3_logging

  * 8c8f0ac import six runtests log handler

  * f442b33 Revert "Enable logging for test runs on py3"

            * b62be16 Merge branch '2019.2.1' into cp-52787

* **PR** `#53485`_: (`s0undt3ch`_) [2019.2.1] Workaround nox's install only flag
  @ *2019-06-18 09:35:34 UTC*

  * 98285f9 Merge pull request `#53485`_ from s0undt3ch/hotfix/fix-nox-bypass-2019.2.1

  * 69e1d84 Workaround nox's install only flag

          * 8622bba Merge branch '2019.2.1' into cp-52787

* **PR** `#53369`_: (`Akm0d`_) Added refs to AIX module documentation
  @ *2019-06-17 20:29:01 UTC*

  * ff7370e Merge pull request `#53369`_ from Akm0d/aix_docs

  * 2ece253 Merge branch '2019.2.1' into aix_docs

  * f2eda45 Merge branch '2019.2.1' into aix_docs

  * 3e793ac Merge branch '2019.2.1' into aix_docs

  * e800641 Merge branch '2019.2.1' into aix_docs

  * 0ef9892 Merge branch '2019.2.1' into aix_docs

  * 65cb718 Merge branch '2019.2.1' into aix_docs

  * 32f4d7e Merge branch '2019.2.1' into aix_docs

  * a59f45e Merge branch '2019.2.1' into aix_docs

  * 29f89a4 Merge branch '2019.2.1' into aix_docs

  * e74345c Merge branch '2019.2.1' into aix_docs

  * 28fbd11 Merge branch '2019.2.1' into aix_docs

  * 60129f0 Merge branch 'aix_docs' of github.com:Akm0d/salt into aix_docs

    * a1c4abc Merge branch '2019.2.1' into aix_docs

    * e2c9fcc Merge branch '2019.2.1' into aix_docs

  * fd197d3 Merge branch '2019.2.1' of https://github.com/saltstack/salt into aix_docs

  * 6d42cf7 Merge branch 'aix_docs' of github.com:Akm0d/salt into aix_docs

    * fae6045 Merge branch '2019.2.1' into aix_docs

  * 97145b0 Merge branch '2019.2.1' of https://github.com/saltstack/salt into aix_docs

  * 6d16343 Updated 'used for' description of aixpkg

  * 6092683 Added aixpkg to index

  * 2867d07 Added refs to AIX module documentation

                              * 458fe9f Merge branch '2019.2.1' into cp-52787

* **PR** `#53461`_: (`waynew`_) Update file.chattr
  @ *2019-06-14 21:16:52 UTC*

  * 8df7684 Merge pull request `#53461`_ from waynew/fix-chattr-problems

  * a8d8174 Merge branch '2019.2.1' into fix-chattr-problems

* **ISSUE** `#52926`_: (`waynew`_) integration.states.test_beacon.BeaconStateTestCase.test_present_absent - Beacon "diskusage" is not available (refs: `#53493`_, `#53466`_)

* **ISSUE** `#52245`_: (`twangboy`_) integration.states.test_beacon.BeaconStateTestCase.test_present_absent (refs: `#53493`_, `#53466`_)

* **PR** `#53493`_: (`dwoz`_) Cherry-pick and merge beacon event change
  @ *2019-06-14 20:36:10 UTC*

  * cfe866d Merge pull request `#53493`_ from dwoz/cherry_pick_test_fix

  * fb104bb Cherry-pick and merge beacon event change

* **PR** `#53492`_: (`dwoz`_)  Fix syndic connection when using tcp transport (refs: `#53514`_)
  @ *2019-06-14 19:23:41 UTC*

  * a1f4136 Merge pull request `#53492`_ from dwoz/tcp_syndic_fix

  * 17c983b Fix linter

  * 9339425 Enable logging for test runs on py3

  * f1b65d1 Fix syndic connection when using tcp transport

* **PR** `#53437`_: (`twangboy`_) Fix failing symlink test
  @ *2019-06-12 22:53:32 UTC*

  * e852596 Merge pull request `#53437`_ from twangboy/fix_test_win_file

  * 8c30dbd Add priv info to error message

  * a7d41a8 Make them non-destructive tests

  * d8bede0 Remove duplicate test

  * 89aaf2e Remove duplicate test

  * 184ec4a Skip test on linux

  * c97ea99 Mark it a destructive test

  * 9da7090 Fix failing symlink test

* **PR** `#53408`_: (`s0undt3ch`_) [2019.2.1] Fix static requirements
  @ *2019-06-12 22:52:33 UTC*

  * a92836b Merge pull request `#53408`_ from s0undt3ch/hotfix/fix-pkg-reqs-2019.2.1

  * 19629a0 Fix `unit.templates.test_jinja.TestCustomExtensions.test_http_query`

  * 5aee99b Take into account the packaging requirements for OSX

  * b9618f6 Take into account the packaging requirements for windows

  * ff63ae4 Stop compiling static TCP requirements.

    * 62e590b Update file.chattr

* **PR** `#53165`_: (`Ch3LL`_) Update ami's used for windows cloud tests
  @ *2019-06-11 15:54:41 UTC*

  * ab9fe46 Merge pull request `#53165`_ from Ch3LL/ami_window_cloud

  * 1d0b0a6 Merge branch '2019.2.1' into ami_window_cloud

  * a77a05c Merge branch '2019.2.1' into ami_window_cloud

  * a1204dc Merge branch '2019.2.1' into ami_window_cloud

  * d15c8f2 Merge branch '2019.2.1' into ami_window_cloud

  * 941778f Update ami's used for windows cloud tests

  * **PR** `saltstack/salt#53332`_: (`s0undt3ch`_) Non optional full test runs for 2019.2.1 (refs: `#53431`_)

* **PR** `#53431`_: (`dwoz`_) Revert "Non optional full test runs for 2019.2.1"
  @ *2019-06-10 21:44:30 UTC*

  * d806b58 Merge pull request `#53431`_ from saltstack/revert-53332-hotfix/full-test-run-2019.2.1

  * 701218c Revert "Non optional full test runs for 2019.2.1"

* **ISSUE** `#52174`_: (`amendlik`_) file.stat function not working under Python 3 (refs: `#53430`_)

  * **PR** `#53430`_: (`Akm0d`_) Cherry-pick `#52174`_ into 2019.2.1

                            * 7811971 Merge branch '2019.2.1' into cp-52787

* **PR** `#53389`_: (`bryceml`_) only keep last 10 builds of every pr on jenkins to reduce disk usage
  @ *2019-06-10 17:18:48 UTC*

  * 6b800a2 Merge pull request `#53389`_ from bryceml/2019.2.1

  * 05368a1 Merge branch '2019.2.1' into 2019.2.1

* **PR** `#53332`_: (`s0undt3ch`_) Non optional full test runs for 2019.2.1
  @ *2019-06-10 15:51:41 UTC*

  * fe18c40 Merge pull request `#53332`_ from s0undt3ch/hotfix/full-test-run-2019.2.1

  * 2372733 Merge branch '2019.2.1' into hotfix/full-test-run-2019.2.1

  * f8bd47b Merge branch '2019.2.1' into hotfix/full-test-run-2019.2.1

  * 45c3c06 Non optional full test runs for 2019.2.1

      * 928b05f only fetch pr target branch instead of all branches to save time and disk space

      * ccc6106 only keep last 10 builds of every pr on jenkins to reduce disk usage

                          * b970bde Merge branch '2019.2.1' into cp-52787

* **PR** `#53287`_: (`twangboy`_) Fix win system
  @ *2019-06-06 23:35:47 UTC*

  * d0810d7 Merge pull request `#53287`_ from twangboy/fix_win_system

  * 0fc88fb Add TypeError

  * 5b4160d Try NumberOfEnabledCores

  * 49cbfd4 Add a note about skipping unavailable items

  * 044b56b Fix get_system_info for older versions of Windows

* **ISSUE** `#52173`_: (`amendlik`_) file.directory fails to check directory permissions correctly (refs: `#53385`_)

  * **PR** `#53385`_: (`Akm0d`_) Check dir_mode recursively in file.directory

* **PR** `#53386`_: (`dwoz`_) Fix missing import
  @ *2019-06-06 20:45:59 UTC*

  * cf98b83 Merge pull request `#53386`_ from dwoz/missing_import

  * a23d6d9 Fix missing import

* **ISSUE** `#49559`_: (`zyguy`_) Salt-cloud - proxmox driver - returns AttributeError: 'generator' object has no attribute 'next' (refs: `#53240`_)

  * **PR** `#53240`_: (`FireGrace`_) change .next() to next() py2=>py3 leftover

* **ISSUE** `#53274`_: (`Ch3LL`_) integration.states.test_pkg failing on amazon 1 py2 (refs: `#53323`_)

* **PR** `#53323`_: (`dmurphy18`_) Fix for issue `#53274`_, test on Amazon Linux 1
  @ *2019-06-06 17:31:18 UTC*

  * 18991f9 Merge pull request `#53323`_ from dmurphy18/fix_53274

  * 6814852 Merge branch '2019.2.1' into fix_53274

  * bb6c97a Merge branch '2019.2.1' into fix_53274

  * b84833d Merge branch '2019.2.1' into fix_53274

  * 7085f36 Fixed pylint issue on PR not showing when run pylint locally

  * 1200031 Updated to use package bash-doc if Amazon Linux 1 after review comments

  * b2a4a5e Fix for issue `#53274`_, test on Amazon Linux 1

  * **PR** `#53356`_: (`Akm0d`_) Updated paramiko to version 2.2.3 for python3.7 support

* **ISSUE** `#53137`_: (`bryceml`_) update doc pr's to be built using python3 and sphinx 2.0.1 (refs: `#53273`_)

* **PR** `#53273`_: (`s0undt3ch`_) [2019.2.1] Switch docs building under Py3
  @ *2019-06-05 10:01:03 UTC*

  * 1cf57e9 Merge pull request `#53273`_ from s0undt3ch/hotfix/py3-nox-docs-2019.2.1

  * 98653c0 Allow docs to be built on Python >= 3.5, not just Python 3.6

  * c54f06f Have sphinx turn errors into warnings

  * 07f4327 Switch docs building under Py3

* **PR** `#53361`_: (`s0undt3ch`_) [2019.2.1] Only make a new log record if it's a dictionary.
  @ *2019-06-05 09:56:15 UTC*

  * dfd36a2 Merge pull request `#53361`_ from s0undt3ch/hotfix/fix-mp-logging-2019.2.1

  * d70d61f Fully revert 962b11687

* **ISSUE** `#53171`_: (`twangboy`_) integration.states.test_network.NetworkTest.test_managed (refs: `#53351`_)

* **PR** `#53351`_: (`waynew`_) Add checks for Amazon Linux to ip module
  @ *2019-06-04 19:25:58 UTC*

  * 5efb670 Merge pull request `#53351`_ from waynew/53171-fix-network-managed

  * e801afe Add checks for Amazon Linux to ip module

* **PR** `#53242`_: (`s0undt3ch`_) [2019.2.1] newer msgpack ipc fixes
  @ *2019-06-03 23:39:09 UTC*

  * **PR** `#52934`_: (`twangboy`_) Update msgpack calls for newer msgpack (refs: `#53242`_)

  * **PR** `#52755`_: (`dwoz`_) Fix non raw msg pack msg decoding (refs: `#53242`_)

  * **PR** `#52488`_: (`terminalmage`_) Fix deprecation warning in msgpack >= 0.5.2 (2018.3) (refs: `#52755`_)

  * **PR** `#52487`_: (`terminalmage`_) Fix deprecation warning in msgpack >= 0.5.2 (develop) (refs: `#53242`_)

  * ce5d79a Merge pull request `#53242`_ from s0undt3ch/hotfix/msgpack-ipc-2019.2.1

  * d27a524 Merge branch '2019.2.1' into hotfix/msgpack-ipc-2019.2.1

* **PR** `#53289`_: (`cmcmarrow`_) stops pylint E1120 from showing
  @ *2019-06-01 04:57:27 UTC*

  * df448c2 Merge pull request `#53289`_ from cmcmarrow/test_kubernetes_lint_failures_silenced

  * 03eacac Merge branch '2019.2.1' into test_kubernetes_lint_failures_silenced

* **PR** `#53304`_: (`s0undt3ch`_) [2019.2.1] Refactor Jenkins PR pipelines to download artifacts after timeout
  @ *2019-05-31 17:10:19 UTC*

  * 6fac22b Merge pull request `#53304`_ from s0undt3ch/hotfix/jenkins-pipelines-refactor-2019.2.1

  * 6e778ef Refactor Jenkins PR pipelines to download artifacts after timeout

* **PR** `#53297`_: (`s0undt3ch`_) [2019.2.1] The TCP transport needs the exact same requirements as the ZeroMQ one
  @ *2019-05-30 19:42:29 UTC*

  * d359513 Merge pull request `#53297`_ from s0undt3ch/hotfix/tcp-transport-tests

  * bec7fa5 The TCP transport needs the exact same requirements as the ZeroMQ one

  * f93e7d3 stops pylint E1120 from showing

  * cbe6423 stops pylint E1120 from showing

  * c5a5d43 test_kubernetes_lint_failures_silenced

  * b838395 test_kubernetes_lint_failures_silenced

  * 997d0a8 stops pylint E1120 from showing

    * 5542fa8 Add the missing, and required, top pillar file.

    * 0ae2ef0 Under Py2 we still want raw to be set to True

    * 714d663 Re-submit `#52934`_ fixed after being reverted in `#52755`_

    * 243b512 Update msgpack calls for newer msgpack

          * 0f9077b Merge branch '2019.2.1' into cp-52787

* **PR** `#53264`_: (`s0undt3ch`_) [2019.2.1] Minion blackout tests - Add the missing, and required, top pillar file
  @ *2019-05-29 07:30:45 UTC*

  * 50e31ec Merge pull request `#53264`_ from s0undt3ch/2019.2.1

  * acabb70 Merge branch '2019.2.1' into 2019.2.1

* **PR** `#52966`_: (`s0undt3ch`_) Always run the full test suite on the 2019.2.1 release branch
  @ *2019-05-28 15:43:12 UTC*

  * 749c626 Merge pull request `#52966`_ from s0undt3ch/hotfix/full-test-run

  * 247c461 Always run the full test suite on the 2019.2.1 release branch

* **PR** `#53138`_: (`frogunder`_) vultr cloudtest fix
  @ *2019-05-28 14:34:22 UTC*

  * a7afd31 Merge pull request `#53138`_ from frogunder/fix_vultr_cloudtest

  * 9f4550c vultr cloudtest fix

    * 912b9b3 Add the missing, and required, top pillar file.

        * 9d21b75 Merge branch '2019.2.1' into cp-52787

* **PR** `#53258`_: (`s0undt3ch`_) [2019.2.1] Fix multiprocessing logging queue dict changing during iteration errors
  @ *2019-05-27 19:26:27 UTC*

  * d011beb Merge pull request `#53258`_ from s0undt3ch/2019.2.1

  * ad01dd2 More robust minion blackout tests

  * a0346d1 Try harder to get the minion grains

  * 36717bd Try and address the test flakyness

  * ce07d8c Add more information when the assertion fails

  * b99e914 Attempt to fix mine tests

  * fca981c One more known to return None

  * 951df48 One more known to return None

  * eb5fd3e Fix `integration.modules.test_mine.MineTest.test_get` for sub_minion

  * 26314f5 Fix multiprocessing logging queue dict changing during iteration errors

* **PR** `#53153`_: (`s0undt3ch`_) [2019.2.1] Add Amazon Linux 2018.3 and 2 static requirements
  @ *2019-05-27 12:02:20 UTC*

  * b69e080 Merge pull request `#53153`_ from s0undt3ch/2019.2.1

  * 166067c Use `currentBuild.resultIsBetterOrEqualTo` instead

  * cefdd90 Stop error messages about missing roster file on syndic master

  * 6bf8f46 Don't complain when attempting to close sockets at this stage

  * e3f3cc9 Add Amazon Linux 2018.3 and 2 static requirements

  * 872acc0 Switch the ubuntu-14.04 exception with amzn-1

  * **PR** `saltstack/salt#52934`_: (`twangboy`_) Update msgpack calls for newer msgpack (refs: `#53235`_)

* **PR** `#53235`_: (`s0undt3ch`_) Revert "Update msgpack calls for newer msgpack"
  @ *2019-05-24 13:35:20 UTC*

  * 14aeeea Merge pull request `#53235`_ from saltstack/revert-52934-fix_msgpack

  * 3295aea Revert "Update msgpack calls for newer msgpack"

* **PR** `#53131`_: (`s0undt3ch`_) [2019.2.1] Update to salt-bootstrap v2019.05.20
  @ *2019-05-24 07:45:57 UTC*

  * 6923427 Merge pull request `#53131`_ from s0undt3ch/hotfix/update-bootstrap-2019.2.1

  * 4cce4f4 Merge branch '2019.2.1' into hotfix/update-bootstrap-2019.2.1

  * 6751ee1 Merge branch '2019.2.1' into hotfix/update-bootstrap-2019.2.1

  * 6988e07 Update to salt-bootstrap v2019.05.20

* **PR** `#52934`_: (`twangboy`_) Update msgpack calls for newer msgpack (refs: `#53242`_)
  @ *2019-05-23 23:18:23 UTC*

  * a61db20 Merge pull request `#52934`_ from twangboy/fix_msgpack

  * f02a12e Merge branch '2019.2.1' into fix_msgpack

  * 7e2cd34 Merge branch '2019.2.1' into fix_msgpack

  * bc9ce8e Merge branch '2019.2.1' into fix_msgpack

  * 0abd1ec Update msgpack calls for newer msgpack

            * 3366d59 update pylint exceptoin

            * 6c452b3 removing unwanted commits from this branch

            * e0b0ba8 Handling in flaky when maximum number of attempts raised and the exception should be raised.  Different approaches depending on Py2 vs Py3.

            * 434dcda Disabling two tests when using Python 3 and OS X

            * 5784e80 Disabling integration.shell.test_minion.MinionTest.test_issue_7754 test on OS X because it hangs the test suite.

            * 78aeb61 Dropping the version check for InstallationError down to anything 1.0 or greater.  Removing the test that simulates versions of pip below 1.0.

            * 4ec90c2 Adding an jinja if statement to only the python parameter if the result from get_python_executable is a valid value.  Maintaining backwards compatibility to run tests without Nox.

* **PR** `#53192`_: (`twangboy`_) Skip `test_gen_hash` test on Windows
  @ *2019-05-23 05:33:13 UTC*

  * 8a57270 Merge pull request `#53192`_ from twangboy/skip_test_gen_hash

  * 758d020 Skip test on Windows

* **PR** `#53157`_: (`twangboy`_) Fix `unit.modules.test_win_file.WinFileTestCase.test_issue_52002_check_file_remove_symlink`
  @ *2019-05-22 22:32:26 UTC*

  * 446e70c Merge pull request `#53157`_ from twangboy/fix_test_win_file_symlink

  * 5672076 Merge branch '2019.2.1' into fix_test_win_file_symlink

* **PR** `#53141`_: (`Ch3LL`_) Check for all non-word characters when calling secure_password
  @ *2019-05-22 17:24:54 UTC*

  * 6fbe9aa Merge pull request `#53141`_ from Ch3LL/shadow_fed_fix

  * a3c4066 Merge branch '2019.2.1' into shadow_fed_fix

* **PR** `#53161`_: (`Ch3LL`_) Add HAS_REQUIRED_CRYPTO var for m2crypto in joyent
  @ *2019-05-22 13:36:07 UTC*

  * fb29512 Merge pull request `#53161`_ from Ch3LL/joyent_m2crypto

  * 08d03e0 Add HAS_REQUIRED_CRYPTO var for m2crypto in joyent

  * 16ef3d2 Merge branch '2019.2.1' into shadow_fed_fix

  * 09ff867 Check for all non-word when calling secure_password

    * 334c93b Elevate token before creating symlink

* **PR** `#53073`_: (`Ch3LL`_) salt-ssh: python binary exists before version check
  @ *2019-05-20 22:36:34 UTC*

  * 85e9b2f Merge pull request `#53073`_ from Ch3LL/ssh_py3_log

  * 383e781 Improve logging in salt-ssh gen_thin

  * 4371434 salt-ssh: python binary exists before version check

* **PR** `#52957`_: (`Ch3LL`_) Set default_flow_style=None in yaml.dump calls
  @ *2019-05-16 19:42:35 UTC*

  * bd02ea6 Merge pull request `#52957`_ from Ch3LL/yaml_flow_style

  * 5f6581a Merge branch '2019.2.1' into yaml_flow_style

* **PR** `#53072`_: (`Ch3LL`_) Backport `#52754`_ into 2019.2.1
  @ *2019-05-16 19:29:22 UTC*

  * **PR** `#52754`_: (`garethgreenaway`_) [2018.3] Fixes to multiprocessing queue when using MacOS (refs: `#53072`_)

  * f410346 Merge pull request `#53072`_ from Ch3LL/bp-52754-2019.2.1

  * 13e5e55 The maximum for the multiprocessing queue on MacOS is 32767, so if we running on MacOS then we use that maximum.

* **ISSUE** `#52817`_: (`waynew`_) unit.modules.test_telegram.TelegramModuleTest.test_post_message (refs: `#52972`_)

* **PR** `#52972`_: (`garethgreenaway`_) [2019.2.1] Fix to unit.modules.test_telegram
  @ *2019-05-15 07:50:13 UTC*

  * 06fa91b Merge pull request `#52972`_ from garethgreenaway/52817_unit_modules_test_telegram_telegrammoduletest_test_post_message

  * cea7131 Removing global declaration.

  * 5bf9a95 Fixing lint.

  * 4d3c46d fixing broken unit.modules.test_telegram test.

* **PR** `#53025`_: (`Ch3LL`_) Change package name for suse pkg tests
  @ *2019-05-15 07:41:44 UTC*

  * d340cbc Merge pull request `#53025`_ from Ch3LL/suse15_pkg_test

  * 0a213ee Change package name for suse pkg tests

* **PR** `#53020`_: (`Ch3LL`_) Change ssh tops log message to debug
  @ *2019-05-14 16:56:42 UTC*

  * c56fbb0 Merge pull request `#53020`_ from Ch3LL/ssh_tops

  * cbbc764 Merge branch '2019.2.1' into ssh_tops

* **PR** `#52973`_: (`twangboy`_) Fix `integration.states.test_pip_state.PipStateTest.test_issue_2028_pip_installed_state` on Windows
  @ *2019-05-13 20:56:28 UTC*

  * ce099aa Merge pull request `#52973`_ from twangboy/fix_test_pip_state

  * 21838a1 Merge branch '2019.2.1' into fix_test_pip_state

* **PR** `#52986`_: (`Ch3LL`_) Revert "Make sure --run-expensive runtests.py arg works"
  @ *2019-05-13 19:38:17 UTC*

  * 055d374 Merge pull request `#52986`_ from Ch3LL/expensive_revert

  * 368c012 Revert "Make sure --run-expensive runtests.py arg works"

  * cce263e Merge branch '2019.2.1' into fix_test_pip_state

  * 351d415 Return path to Python instead of None

    * c0538d2 Change ssh tops log message to debug

    * e317186 Merge branch '2019.2.1' into yaml_flow_style

* **PR** `#52968`_: (`s0undt3ch`_) [2019.2.1] Salt >= 2018.3.x supports Py3.7
  @ *2019-05-12 21:44:57 UTC*

  * ee05da5 Merge pull request `#52968`_ from s0undt3ch/2019.2.1

  * 73c3726 Salt >= 2018.3.x supports Py3.7

* **ISSUE** `#50310`_: (`xuhcc`_) acme.cert falsely reports changes (refs: `#50400`_)

* **PR** `#52796`_: (`Ch3LL`_) Backport `#50400`_ and `#50402`_ into 2019.2.1
  @ *2019-05-10 19:30:12 UTC*

  * **PR** `#50402`_: (`xuhcc`_) Fix typo in salt.modules.acme (refs: `#52796`_)

  * **PR** `#50400`_: (`xuhcc`_) Fix incorrect change reporting in acme.cert (refs: `#50402`_, `#52796`_)

  * cae51c2 Merge pull request `#52796`_ from Ch3LL/bp-50400

  * 0c2e3e7 Merge branch '2019.2.1' into bp-50400

  * 1268e3e Merge branch '2019.2.1' into bp-50400

  * 09fa9e3 Fix typo

  * 9be5c0c Fix incorrect change reporting in acme.cert

      * 9a27fb3 Merge branch '2019.2.1' into yaml_flow_style

* **PR** `#52770`_: (`twangboy`_) Fix test_file_managed_should_fall_back_to_binary on Windows
  @ *2019-05-09 20:35:02 UTC*

  * 20cccd8 Merge pull request `#52770`_ from twangboy/fix_test_file

  * ac27e69 Merge branch '2019.2.1' into fix_test_file

  * 30a5093 Merge branch '2019.2.1' into fix_test_file

  * c08b10d Merge branch '2019.2.1' into fix_test_file

  * 340ee23 Pass encoding to _validate_str_list

            * 0d0e354 Fix yamldumper test for both py2/py3

            * 20bc954 Update docs for yamldumper test

            * bf648e5 Update tests/unit/utils/test_yamldumper.py

            * 70d578a Set default_flow_style=None in yaml.dump calls

* **PR** `#52943`_: (`Ch3LL`_) Fix elasticsearch state module: allow user to define empty aliases
  @ *2019-05-09 15:46:38 UTC*

  * 4437764 Merge pull request `#52943`_ from Ch3LL/fix_elastisearch

  * 451fb7e Merge branch '2019.2.1' into fix_elastisearch

  * ebff9b9 Fix elasticsearch state module: allow user to define empty aliases

* **PR** `#52952`_: (`s0undt3ch`_) [2019.2.1] More nox changes and test fixes
  @ *2019-05-09 15:03:07 UTC*

  * 9b290b6 Merge pull request `#52952`_ from s0undt3ch/merge-forward/2018.3-to-2019.2.1-cherry

  * a06d7ce We need to call the decorator

  * 77185af Partial revert since this is a class method

  * f5c5771 Lint fixes

  * 3e43c87 Revert "fix compare_versions method"

  * 0e139bf Fix `GOLDEN_IMAGES_CI_BRANCH` value

  * 12a9408 Add Py3.7 static requirements

  * 8e505fb Move tests to existing test modules

  * 4681609 `tests/unit/config/__init__.py` -> `tests/unit/config/test_config.py`

  * b1dc7f6 Pin to `moto<=1.3.7` because of https://github.com/spulec/moto/pull/1952

  * 0ffe7ca We no longer test againt Ubuntu 14.04 which reached EOL

  * 33743fc Don't traceback when trying to close a closed socket

  * da2e147 Always cleanup the changed environ

  * 087c74d No globals in tests, specially dictionaries!

  * a814fc0 Fix underscore wart (and linter)

  * 74b8f5f Fix deprecation warning in msgpack >= 0.5.2

  * 962b116 Try to address dict changing during iteration

  * c58af57 Tweak codeclimate settings for less noise

  * 5bb7869 fix linter

  * 0b81841 Cherry-pick test fix

  * 99f9e1c fix compare_versions method

* **PR** `#52853`_: (`s0undt3ch`_) [2019.2.1] Bring nox into 2019.2.1
  @ *2019-05-09 09:52:42 UTC*

  * a510edf Merge pull request `#52853`_ from s0undt3ch/merge-forward/2018.3-to-2019.2.1-cherry

  * a8f7b46 Test is not destructive.

  * 63663cf We no longer test againt Ubuntu 14.04 which reached EOL

  * 62574ee Typo

  * e3e3761 Proper english in requirements comments

  * e9f6a12 `identical_signature_wrapper` adds `__wrapped__` to function globals

  * 10283b4 Upload coverage reports on full test runs

  * 6e0b61b Less flaky mine tests

  * 3709ed7 msgpack returns string_types

  * a36b15e Add regression test

  * ce782ff Fix non raw msg pack msg decoding

  * f193f0f Update Issue Template: questions removed

  * 4417095 Fix underscore wart (and linter)

  * e6c2ae4 Fix deprecation warning in msgpack >= 0.5.2

  * 6375944 Add ubuntu1804 to pr tests

  * 8fdb04d SIGKILL is not always available use a local variable

  * 4d6b8da Fix linter

  * 759bccc Fix test_doc on windows by using grep yay!

  * 0ce086d Fix remaining failures on ubuntu 1404 and add to PR tests

  * fdf80fd Change py3 windows timeout from 6 to 8 hours

  * b0aa287 Fix missing class wart

  * 21ecb74 fix linter

  * 62c0f9f Skip tests when no libcloud

  * 1d92290 Fix unused import

  * 72cdc91 Fix linter

  * 238fd0f Fix broken pip state

  * 89533ba Fix `NOX_ENV_NAME`

  * 7cfc9e8 Fix `NOX_ENV_NAME`

  * 2087c91 Fix `NOX_ENV_NAME`

  * 2f1aff5 Rename kitchen-centos6-py3 to kitchen-centos6-py2

  * 1eea990 Fix linter

  * 52ca668 Skip tests when no libcloud

  * 2cf4b98 Add centos-6-py2 and Debian 8,9 py2 and 3 to PR tests

  * 522599d Don't fail just because some random process died

  * 34cef86 Ignore super not called

  * b7ace9c Fix linter

  * aceb6d3 Skip libcloud unit tests when no libcloud

  * f73420b Install mock on Python < 3.6

  * 28fbde1 Add `moto` to the windows dependencies

  * 8cbecc1 Pin kubernetes to <4.0

  * 2acb0f3 Make sure --run-expensive runtests.py arg works

  * 22cae20 Remove ref restriciton from kitche-salt

  * 67095df Add 'runFull' build parameter for PR tests

  * 12d8d35 Stop w32time before and start after testing

  * 7f1c22c Skip tests that fail on Windows

  * f4ae97f Upgrade etcd to > 0.4.2

  * 381f5fe Limit and reduce the amount of log records sent over the wire

  * 0c94b5d More entries to ignore

  * c3a21f5 As a script, not as a module

  * 8948b69 Include `COVERAGE_FILE` as an env variable.

  * 0af561e Each generated script is now prepared for code coverage

  * 294d6f4 Use the system's path separator

  * e52ab87 Always combine and generate the XML coverage report

  * 666ca9f Fix proxy minion startup issue on the test suite

  * 7838ace `impacket` does not support Py3

  * ba8d0fe Allow `--install-only` to gather the required information

  * eed7d68 Create nox lint virtualenvs before running them

  * e9e57cf Syndic roster not in 2017.7.9

  * 111c63a4d Create the roster even when not running ssh

  * 11c02a0 Fix unit.test_loader.LoaderGlobalsTest.test_states

  * 8694db1 Fix windows tests

  * 82e9ac5 Avoid race condition in even assertions

  * 9443451 Revert part of 927219c since it is not a fix

  * 5fee762 Fix timeout logic

  * 517650f check timeout when queue empty

  * 7c0a9af fix linter

  * 961dc40 Ignore missing variable in six module

  * 0f5a7f0 Fix typo

  * 6c8c418 Do not limit event assert to first event

  * 3042292 Wait longer for ping reaction

  * 8c10f5f Fix xml block causing docs to fail

  * 6e5768a Add a nox session for the Jenkins tornado jobs

  * 43321e8 Add a cloud nox session for both runtests and pytest

  * b6b4e95 Lint cleanup

  * 0670614 Add tests for wraps

  * 1670b5d Use functools.wraps with decorators

  * 5ae263c Update static requirements for 2018.3 branch

  * 3482c4d Disable code coverage uploads.

  * 0e5bc67 Lint fixes

  * 337c737 Update CI jobs to point to 2018.3

  * 72e8603 Skip test if required cypto libs are not available

  * e6bc9f8 Default to Cryptodome, fallback to PyCrypto

  * b2b0764 Be aware of the different path separators

  * 7e79b18 We need to make sure the virtualenv path entry is removed when searching

  * ff6d3c6 We don't need to be root to run these tests

  * 5965ab4 Disable progress bars on pip installs

  * f86a44e Use the real python executable path when running within a virtualenv

  * 3d407e8 Add a helper to return the path to the real python executable

  * ea9d246 We must also provide `venv_bin` when running within a virtualenv

  * 31e91b0 Fix pip tests, in particular under windows

  * 493f493 Don't fail if pkg_resources is not importable

  * a1eb400 Specify the SHA we need

  * 0b01f21 Let's fully unload pip

  * 0b6f848 Fix docker entries

  * 870b899 Remove unused argument

  * 1656cb4 Disable re-running failed tests for now

  * 6db4141 Also ignore multiprocessing coverage files

  * 83dc97d Actually write the lint reports.

  * 5f97270 Try to make sure some pip internal functions are always present in sys.modules after reloads

  * 0090c55 Try and address the fact that some python packages are only provided by the distro

  * 4a072fe These tests aren't destructive

  * 5c7a956 Don't fail the build if the issue was sending a slack notification

  * 361ef6e Don't try to change ownership on non existing paths

  * 7b17352 More insight(context) on failure reports

  * 93b6b95 Lock supervisor to 3.3.5, last kown working(passing tests) version

  * 51114aa Watch out for too long shebang's

  * d97fe82 The output is important to know why it failed.

  * 9fef385 Strings and integers are not comparable under Python 3

  * d308dce Be verbose in a CI context

  * 8b7105e Fix failed tests re-run logic

  * d6d8db1 Blacklist `enum34` on Py>=3.4. Update requirements.

  * 1cd00c0 Update PR CI jobs for nox

  * 19a83d5 Blacklist pycrypto and install pycryptodome instead

  * 91376b3 Ignore the generated docs archive

  * 207b83a Update compiled requirements

  * 535e7a7 Add TCP transport nox sessions

  * 680b3e5 Compile requirements for the TCP transport

  * 49a1ebe Throw error when running either on Py<2.7 or Py>=3.7

  * 10528b9 Don't repeat filed tests on missing/empty failed test files file

  * 4886809 We currently only support running lint under Py2.7

  * a76981b Remove dead code

  * 7b2c1ce Don't require six

  * a27ed35 Add nox env to build docs

  * e1b3f1d Lock docs python requirements

  * c8de644 Fix lint issues under tests

  * 0372718 Fix lint issues on salt

  * 9eab9f4 Add nox session/env/target to run lint against Salt and its test suite

  * 123f771 Lock lint requirements

  * 8df33ad Back to `+apache-libcloud==1.0.0` and skip windows for now

  * 43e3ae6 Bump apache-libcloud requirement because 1.0.0 fails to install on windows

  * d5f7813 Remove requiremens for platforms which aren't tested under Py3

  * 8f02ee9 Recompile requirements

  * 66626f2 Remove pycryptodome from compiled requirements files

  * 75693e5 Use pycryptodomex on windows and PyCrypto on the rest

  * 4a9c19c Update(fix) requirements

  * 33a3467 We don't test OSX nor Windows under Py3.4

  * fd44fce We want a more verbose pip-compile output

  * c2ae2d5 We now compile requirements for each of the supported minor version

  * 6ee1260 Static requirements are now placed on `py<major>.<minor>` subdirectories

  * 3504804 The required crypto library is pulled in from zeromq.txt or raet.txt

  * 3ffe03c PyZMQ is pulled in from zeromq.txt

  * 7c2fe16 Instead of quoting session parameters, proxy nox sessions

  * d3ae77b Add separate crypto sessions

  * 0399620 Parametrize the transport

  * d33fd03 Update/Generate static requirements to new layout

  * 52ac533 Add pre-commit config to generate static requirements

  * 3cfcb13 Be aware of the new static requirements layout

  * dc7e16a Don't lock the docker requirement. It's not locked on the other platforms

  * 5476ba2 Kubernetes 3.0.0 does include the requirements files. pip-compile chokes on that

  * 79a8261 Previously generated requirements were py2 only

  * 1e29666 IOFLO is pulled in from the raet requirements

  * 4945e35 Fix pylint on 2017.7.9

  * 036bf68 Rerun failed tests

  * 03a9601 Ignore `.nox` directory

  * 50cb630 We have long files

  * db2392f Update CodeClimate settings

  * 899c80e Fix integration.client.test_kwarg test timeouts

* **ISSUE** `#52836`_: (`Ch3LL`_) unit.utils.test_args.ArgsTestCase.test_argspec_report failing (refs: `#52852`_)

* **PR** `#52852`_: (`garethgreenaway`_) [2019.2.1] Fixes to unit.utils.test_args.test_argspec_report
  @ *2019-05-07 19:25:48 UTC*

  * 77355e2 Merge pull request `#52852`_ from garethgreenaway/52836_test_argspec_report_failing

  * eee5a38 Merge branch '2019.2.1' into 52836_test_argspec_report_failing

* **PR** `#52845`_: (`Ch3LL`_) Backport `#52780`_ into 2019.2.1
  @ *2019-05-07 16:27:21 UTC*

  * **PR** `#52780`_: (`sbrennan4`_) Handle ipv6 in _netlink_tool_remote_on (refs: `#52845`_)

  * dcc5fde Merge pull request `#52845`_ from Ch3LL/bp-52780

  * dfff09b Merge branch '2019.2.1' into bp-52780

* **PR** `#52851`_: (`Ch3LL`_)  Reload matcher loader when ext_pillar_first set
  @ *2019-05-07 13:12:07 UTC*

  * 2e4f296 Merge pull request `#52851`_ from Ch3LL/matcher_ext_pillar

  * bdcae5d Add docs for new reload kwarg

  * fc70884 Reload matcher loader when ext_pillar_first set

  * 8ac74e2 Merge branch '2019.2.1' into bp-52780

  * 226c7ce Merge branch '2019.2.1' into bp-52780

  * c1eae84 Add test

  * 69fe65b Use rsplit

      * 8fdc48c Removing create_autospec and having salt.utils.args.argspec_report run against the _test_spec function directly.  Depending on the python version, create_autospec gives different results and cause the test to fail.  The test is now more accurate at testing the arguments for the function.

* **PR** `#52842`_: (`s0undt3ch`_) `libcrypto.OpenSSL_version_num` might be a callable
  @ *2019-05-06 17:00:37 UTC*

  * cc7a0d1 Merge pull request `#52842`_ from s0undt3ch/2019.2.1

  * a944017 `libcrypto.OpenSSL_version_num` might be a callable

* **PR** `#52839`_: (`twangboy`_) Add support for EC2
  @ *2019-05-04 17:28:54 UTC*

  * b625a6a Merge pull request `#52839`_ from twangboy/fix_test_grain

  * 1c9b372 Add support for EC2

* **ISSUE** `#51982`_: (`arsiesys`_) topic (minion_id) need to be encoded before being hash and sent using zeroMQ (refs: `#51983`_)

* **PR** `#52767`_: (`Ch3LL`_) [2019.2.1] Add tests to PR  `#51983`_
  @ *2019-05-03 08:35:27 UTC*

  * **PR** `#51983`_: (`arsiesys`_) encode topic before using hashlib (refs: `#52767`_)

  * 6002939 Merge pull request `#52767`_ from Ch3LL/zmq_filter_test

  * 1ee8f37 Merge branch '2019.2.1' into zmq_filter_test

  * d74b6ee Merge branch '2019.2.1' into zmq_filter_test

  * 3210274 Fix linter warnings

  * e7c9d6e increase timeout when gathering results

  * 784786d Add zmq_filter unit tests

  * 805c5ee encode topic before using hashlib

* **PR** `#52827`_: (`twangboy`_) Add pymssql dependency for Windows builds
  @ *2019-05-03 08:21:40 UTC*

  * 5996932 Merge pull request `#52827`_ from twangboy/add_pymssql

  * 6f0b8e2 Add pymssql dependency for Windows builds

* **ISSUE** `#52717`_: (`Ch3LL`_) debian9 tests segmentation fault (refs: `#52797`_)

* **PR** `#52797`_: (`garethgreenaway`_) [2019.2.1] Only run the libcrypto init if less than OpenSSL 1.1.0
  @ *2019-05-03 05:12:31 UTC*

  * e3918c5 Merge pull request `#52797`_ from garethgreenaway/52717_debian_tests_segmentation_fault

  * 7ab0961 Merge branch '52717_debian_tests_segmentation_fault' of github.com:garethgreenaway/salt into 52717_debian_tests_segmentation_fault

    * f8d816e Merge branch '2019.2.1' into 52717_debian_tests_segmentation_fault

* **PR** `#52771`_: (`twangboy`_) Fix `test_gpg` tests on Windows
  @ *2019-05-02 13:30:18 UTC*

  * b68544f Merge pull request `#52771`_ from twangboy/fix_test_gpg

  * c7f45c2 Pass encoding to stringutils.to_unicode

* **PR** `#52783`_: (`Ch3LL`_) Fix boto_apigateway tests for PyYAML 5.1
  @ *2019-05-02 13:26:34 UTC*

  * 316d05b Merge pull request `#52783`_ from Ch3LL/fix_boto_yaml

  * cde29cb Fix boto_apigateway tests for PyYAML 5.1

  * 6ffbca5 Fixing lint.

  * e24f2f8 Only run the libcrypto init if less than OpenSSL 1.1.0.

* **PR** `#52769`_: (`twangboy`_) Remove domain grain from tests for Windows
  @ *2019-04-30 21:14:26 UTC*

  * 3509465 Merge pull request `#52769`_ from twangboy/fix_test_core

  * 0049f85 Remove domain grain from tests

* **PR** `#52768`_: (`twangboy`_) Remove pchanges... again...
  @ *2019-04-30 20:24:27 UTC*

  * 30dc14b Merge pull request `#52768`_ from twangboy/fix_test_win_dacl

  * 123b607 Remove pchanges... again...

* **PR** `#52753`_: (`twangboy`_) Skip test_gen_thin_compression_fallback_py3
  @ *2019-04-30 03:36:27 UTC*

  * 3e46f51 Merge pull request `#52753`_ from twangboy/skip_test_gen_thin

  * 811b381 Skip test_gen_thin_compression_fallback_py3

* **ISSUE** `#52721`_: (`Ch3LL`_) unit.cloud.clouds.test_ec2 test failing (refs: `#52736`_)

* **PR** `#52736`_: (`dwoz`_) Skip password decryption test when no libraries available
  @ *2019-04-29 17:07:56 UTC*

  * 6bfca94 Merge pull request `#52736`_ from dwoz/ec2test

  * 04ad027 Merge branch '2019.2.1' into ec2test

* **PR** `#52624`_: (`tanlingyun2005`_) fix TypeError: argument of type int is not iterable
  @ *2019-04-29 13:15:42 UTC*

  * 9a1ed78 Merge pull request `#52624`_ from tanlingyun2005/2019.2.1

  * 2c6867e add test case to tests/unit/cli/test_batch.py

  * cb7742e Merge branch '2019.2.1' into 2019.2.1

  * c943900 Merge branch '2019.2.1' into 2019.2.1

  * d4abddd fix TypeError: argument of type int is not iterable

  * ed908b3 Merge branch '2019.2.1' into 2019.2.1

  * 463b60e Merge branch '2019.2.1' into 2019.2.1

  * 65ee219 Merge branch '2019.2.1' of https://github.com/tanlingyun2005/salt into 2019.2.1

    * f71168d Merge branch '2019.2.1' into 2019.2.1

  * 509c797 bug fix salt/cli/batch.py

  * 211915c fix salt/cli/batch.py TypeError: argument of type int is not iterable

  * 070ae84 fix TypeError: argument of type int is not iterable

            * b770f96 Skip test requiring crypto when none available

            * e52b390 Warn when password decrypton requested but not possible

* **PR** `#52696`_: (`Ch3LL`_) Backport `#50087`_ into 2019.2.1
  @ *2019-04-25 20:33:13 UTC*

  * **PR** `#50087`_: (`rbthomp`_) Fix applying of attributes for returner rawfile_json (refs: `#52696`_)

  * 806307a Merge pull request `#52696`_ from Ch3LL/bp-50087

  * 66e97e7 Fix applying of attributes for returner rawfile_json

* **PR** `#52659`_: (`twangboy`_) Fix issues with the win_file tests
  @ *2019-04-22 23:34:36 UTC*

  * 174f558 Merge pull request `#52659`_ from twangboy/fix_test_win_file

  * 915c780 Fix issues with the win_file tests

* **PR** `#52655`_: (`dwoz`_) Parse chattr version and fix test case
  @ *2019-04-22 01:46:29 UTC*

  * d1a61a6 Merge pull request `#52655`_ from dwoz/cron_test_fix

  * e69fcc5 Fix typo

  * 859d088 Merge remote-tracking branch 'origin/cron_test_fix' into cron_test_fix

    * 7f7bb90 Merge branch '2019.2.1' into cron_test_fix

* **PR** `#52601`_: (`Ch3LL`_) Cherry-Pick `#52415`_ into 2019.2.1
  @ *2019-04-21 19:33:03 UTC*

  * **PR** `#52415`_: (`Ch3LL`_) Backport `#49832`_ into 2018.3 (refs: `#52601`_)

  * **PR** `#49832`_: (`terminalmage`_) Replace pchanges with changes to make onchanges/prereq work in test mode (refs: `#52415`_)

  * f7d823c Merge pull request `#52601`_ from Ch3LL/cp-52415

  * ecd6802 Merge branch '2019.2.1' into cp-52415

  * 538d5cf Remove pchanges from win_dacl

  * 81b865f use same newfile message on linux for windows file state

  * 93bdd08 Update dict correctly in file state

  * f3c7f27 remove pchanges for windows file modules

  * fb3b75d Fix tests for pchanges backport into 2018.3

  * 0f296bb Update kernelpkg test to reflect pchanges removal

  * 885d6ff Update file.touch unit tests to reflect addition of changes in test mode

  * 4bc5fd0 Add integration tests for test mode onchanges/prereq

  * ed214c4 Make it possible to use prereq with test and saltmod state mods

  * ceb3f4d Add repack_state_returns to TestCase

  * 982e693 Add exception logging in flaky decorator

  * 0ba0ddf Add test mode changes to file.touch state

  * 6db2beb Replace "pchanges" with "changes" to fix onchanges/prereq requisites

      * 169c2d5 Chattr version py3 fix

      * cf88c27 Fix linter issues

      * 0ea007d Parse chattr version and fix test case

* **ISSUE** `#52508`_: (`Ch3LL`_) integration.modules.test_publish test failures (refs: `#52645`_)

* **PR** `#52645`_: (`dwoz`_) Fix salt.modules.publish and salt.states.x509 tests
  @ *2019-04-20 08:17:19 UTC*

  * af4f204 Merge pull request `#52645`_ from dwoz/test_fixes

  * 9b6f9f9 Clean up cruft

  * c3971a5 Fix salt.modules.publish and salt.states.x509 tests

* **PR** `#52629`_: (`dwoz`_) Fix event assertion race condition
  @ *2019-04-19 19:03:20 UTC*

  * **PR** `#52540`_: (`dwoz`_) Fix race condition in event assertion (refs: `#52629`_)

  * 0a4d2d9 Merge pull request `#52629`_ from dwoz/ping_wait_2019.2.1

  * c001022 Fix linter

  * 423f6f9 Fix vent assertion race condition

* **PR** `#52619`_: (`dwoz`_) Remove unused method from pytest engine
  @ *2019-04-18 23:45:35 UTC*

  * 4859e6c Merge pull request `#52619`_ from dwoz/pytest_engine_2019.2.1

  * 105784a Remove unused method from pytest engine

* **PR** `#52614`_: (`Ch3LL`_) [2019.2.1] Update integration.modules.test_network.NetworkTest.test_network_ping…
  @ *2019-04-18 21:54:28 UTC*

  * 77943e5 Merge pull request `#52614`_ from Ch3LL/cp-test_network-2019.2.1

  * 27c79d2 Update integration.modules.test_network.NetworkTest.test_network_ping test address

* **ISSUE** `#32245`_: (`tkwilliams`_) git_pillar should permit automatic mapping of environment to branch a-la gitfs  (refs: `#50768`_)

* **PR** `#52615`_: (`twangboy`_)  Bring 51661 into 2019.2.1
  @ *2019-04-18 21:53:35 UTC*

  * **PR** `#51661`_: (`sathieu`_) git_pillar: Fix all_saltenvs on base env (refs: `#52615`_)

  * **PR** `#51597`_: (`sathieu`_) git_pillar: Fix all_saltenvs on base env (refs: `#51661`_)

  * **PR** `#50768`_: (`sathieu`_) git_pillar: Add support for all_saltenvs parameter (refs: `#51597`_, `#51661`_)

  * c6b4986 Merge pull request `#52615`_ from twangboy/gitfs_2019.2.1

  * d952674 Merge branch '2019.2.1' into gitfs_2019.2.1

* **ISSUE** `#52547`_: (`cbosdo`_) virt.purge throws a libvirt exception on Xen hypervisor (refs: `#52548`_)

* **PR** `#52548`_: (`cbosdo`_) Virt purge fix
  @ *2019-04-18 20:07:36 UTC*

  * 8ee15a9 Merge pull request `#52548`_ from cbosdo/virt-purge-fix

  * 6ca8f4b Try/except undefineFlags() as this operation is not supported on bhyve

    * 5a0464b Bring 51661 into 2019.2.1

* **PR** `#52591`_: (`Ch3LL`_) [2019.2.1] Update test_schema to mirror the new ValidationErrors in 3.0.0
  @ *2019-04-18 16:34:22 UTC*

  * e03aed5 Merge pull request `#52591`_ from Ch3LL/fix_jsonschema_2019.2

  * e09be842 Update test_schema to mirror the new ValidationErrors in 3.0.0

* **ISSUE** `#52525`_: (`lomeroe`_) deserializer_opts are not passed the serializer in file.serialize (refs: `#52526`_)

* **PR** `#52526`_: (`lomeroe`_) Fix use of deserializer_opts in file.serialize
  @ *2019-04-17 14:08:52 UTC*

  * 21d6365 Merge pull request `#52526`_ from lomeroe/deserializer_opts_fix

  * ea0520c update test for serialization opts

  * 84ff03a Correct attempting to use the serializer_name to pull deserializer_opts when deserializer_name is used as the key in the deserializer_options dict.

* **ISSUE** `#49147`_: (`furgerf`_) Log filled with "Exception occurred while Subscriber handling stream: Already reading" (refs: `#51963`_)

* **PR** `#52570`_: (`DmitryKuzmenko`_) Simplify IPCClient and prevent corrupt messages (Turn 2) 2019.2
  @ *2019-04-17 14:03:02 UTC*

  * **PR** `#52564`_: (`DmitryKuzmenko`_) Simplify IPCClient and prevent corrupt messages (Turn 2) (refs: `#52570`_)

  * **PR** `#52445`_: (`dwoz`_) Simplify IPCClient and prevent corrupt messages (refs: `#52564`_)

  * **PR** `#51963`_: (`DmitryKuzmenko`_) Allow multiple instances of IPCMessageSubscriber in one process (refs: `#52564`_)

  * e522ffe Merge pull request `#52570`_ from DSRCorporation/bugs/revert_51963_2019.2

  * fabbcac A couple of race conditions fixes and a test update.

  * 9c85734 Drop singleton from IPCClient

  * 7cf6d54 Revert "Support parallel work of multiple IPCMEssageSubscribers in one process"

  * 7f26e76 Revert "Update doc conf with the new import `tornado.queues`"

  * 69e9416 Revert "Minor: Fix typo in docstring"

* **ISSUE** `#52449`_: (`Ch3LL`_) integration.cloud.clouds.test_gce.GCETest.test_instance_extra failure (refs: `#52551`_)

* **PR** `#52551`_: (`garethgreenaway`_) [2019.2] Marking the two tests in test_gce as flaky
  @ *2019-04-17 14:00:39 UTC*

  * b173406 Merge pull request `#52551`_ from garethgreenaway/52449_test_gce_random_failures

  * 28af717 Marking the two tests in test_gce as flaky.

* **ISSUE** `#51842`_: (`mattLLVW`_) salt.auth.django docs use wrong model name (refs: `#52553`_)

* **PR** `#52553`_: (`mattLLVW`_) fix: `#51842`_
  @ *2019-04-17 13:59:45 UTC*

  * 8352362 Merge pull request `#52553`_ from mattLLVW/fix_django_auth_docs

  * 3baeedf fix: `#51842`_

* **ISSUE** `#52134`_: (`sploenix`_) Regression: Include list of pillar files under different keys in 2019.2 (refs: `#52490`_)

* **ISSUE** `#22063`_: (`jeanpralo`_) Wildcard inside top.sls file for pillar (refs: `#52490`_)

* **PR** `#52490`_: (`dwoz`_) Fix pillar include regression
  @ *2019-04-17 13:54:39 UTC*

  * 9faa49c Merge pull request `#52490`_ from dwoz/issue_52134

  * 876dd18 Fix merge wart

  * 2ed650b Merge remote-tracking branch 'saltstack/2019.2' into issue_52134

  * b0af11f Run include tests when pillar source changes

  * 307cec6 Fix pillar tests

  * 1a33bde import __future__.absolute_import

  * 5dc5de9 Use file encoding and add docstring

  * e84cd41 Fix pillar include wart

  * c79f496 Add pillar include tests

  * 7745242 Revert "Fix `#22063`_: pillar wildcard support include"

* **PR** `#52552`_: (`twangboy`_) Bring 52170 into 2019.2
  @ *2019-04-17 13:54:17 UTC*

  * **PR** `#52170`_: (`twangboy`_) Fix issue when task doesn't have delay_random defined (refs: `#52552`_)

  * b0c0237 Merge pull request `#52552`_ from twangboy/fix_win_task_2019.2

  * fd19cca Remove some warts in the docs

  * deb0b10 Fix some lint

  * a279d45 Final doc fixes

  * 58f0cd2 Fix docs... attempt 6

  * a66716e Fix docs... attempt 5

  * f6f3381 Fix docs... attempt 4

  * 18cfc15 Fix docs... attempt 3

  * c691e0d More doc fixes

  * e01077b Fix docs issue... maybe...

  * b649495 Honor 80 character line limit

  * eba4507 Bring 52170 into 2019.2

* **PR** `#52528`_: (`Ch3LL`_) [2019.2] Merge forward from 2018.3 to 2019.2
  @ *2019-04-17 13:53:46 UTC*

  * cc0cd5d Merge pull request `#52528`_ from Ch3LL/merge-2019.2

  * 87cf385 increase timeout on test_state for windows

  * 3442202 Increase timeout for test_kwarg tests

  * 2c3ff2f Merge branch '2019.2' into merge-2019.2

* **PR** `#52534`_: (`twangboy`_) Add TLS support up to TLS 1.2
  @ *2019-04-13 22:56:41 UTC*

  * e91240b Merge pull request `#52534`_ from twangboy/tls_support_2019.2

  * 9ec54c4 Add TLS support up to TLS 1.2

    * 474efa1 Fix pylint and state test failure

    * 048a82e Merge branch '2019.2' into merge-2019.2

* **PR** `#52536`_: (`twangboy`_) Bring `#52191`_ into 2019.2 branch
  @ *2019-04-12 21:31:23 UTC*

  * **PR** `#52191`_: (`twangboy`_) Fix issue where version doesn't detect when check_remote=True (refs: `#52536`_)

  * 2c42e4d Merge pull request `#52536`_ from twangboy/fix_choco_2019.2

  * b394ad5 Bring `#52191`_ into 2019.2 branch

  * 795a7f6 Fix windows tests - increase timeout

  * c70772c Fix linux state tests- add new comment

  * 2941567 Merge branch '2018.3' into '2019.2'

  * 262516c Merge pull request `#52209`_ from twangboy/fix_choco_retcode

    * 7aec2d3 Merge branch '2018.3' into fix_choco_retcode

    * bfdc47b Handle new enhanced retcode 2

  * dd7a4ba Merge pull request `#52046`_ from twangboy/use_reg_timezone

    * fc8e970 Merge branch '2018.3' into use_reg_timezone

    * d0987e6 Merge branch '2018.3' into use_reg_timezone

    * 1bf0cbc Merge branch '2018.3' into use_reg_timezone

    * b466f8a Merge branch '2018.3' into use_reg_timezone

    * 34bdae5 Merge branch '2018.3' into use_reg_timezone

    * 9a8afa6 Fix tests, add null byte test

    * 59b1d4f Revert back to using reg to get timezone

  * 0d09608 Merge pull request `#52396`_ from dmurphy18/fix_aix_ssh

    * 8bfa340 Correct typo

    * 6d98577 Altered code to support salt-ssh on AIX

  * 576478e Merge pull request `#52473`_ from Ch3LL/bp-49437

    * 781385f Merge branch '2018.3' into bp-49437

    * 3a3114d Fix merge conflict wart

    * bbfd412 Merge branch '2018.3' into bp-49437

    * 48ee82d Merge branch '2018.3' into bp-49437

    * f66d474 Add support to avoid calling refresh_db in opkg.del_repo

  * d830bc6 Merge pull request `#52493`_ from dwoz/ping_reaction_test

    * 8b05e77 Merge branch '2018.3' into ping_reaction_test

    * 7083d21 Merge branch '2018.3' into ping_reaction_test

    * 7c963c1 Merge branch '2018.3' into ping_reaction_test

    * 75ddeb3 fix linter

    * e3e1d2e fix reactor ping test

  * 9b7a0d1 Merge pull request `#52505`_ from bloomberg/2018_zmq_uri

    * b682ec5 transport.zmq: fix bug introduced by b7df7e75cf2

  * 452bbeb Merge pull request `#52512`_ from dwoz/supervisord_2018.3

    * cd5cd7d The exit code matters.

  * 53228ae Merge pull request `#52475`_ from Ch3LL/bp-49464

    * a891fd3 Make opkg.del_repo be compatible with pkrepo state module

  * 6e79e24 Merge pull request `#52500`_ from terminalmage/invalid-archive-source

    * e9d175b Fix traceback when invalid source passed to archive.extracted

  * 2df74ca Merge pull request `#52476`_ from bloomberg/win_cmd_2018

    * 0e0c42e 2018 backport: modules.cmdmod: handle windows environ better

  * 4dfb2f8 Merge pull request `#52474`_ from Ch3LL/bp-49984

    * c8d547e Use prune option in Pygit2 provider when fetching

  * d699485 Merge pull request `#52393`_ from waynew/52087-mine-delete-test-enhancements

    * e3f5be3 Use uncommon item in mine delete test

  * 89bd258 Merge pull request `#52445`_ from dwoz/ipc_fixes_2018.3

    * 1bdaf29 Ensure exceptions in service future are handled

    * c7ad732 Use six.reraise for py3 compatibility

    * 29999b0 Close message service on subscriber close

    * 47203f7 Fix ipc unit tests

    * 2b35437 Fix linter issues

    * 503cdd2 Remove IPCClient singleton

    * b374034 Re-raise queued exceptions with traceback

* **ISSUE** `#51879`_: (`whytewolf`_) 2019.2.0 binary pillar unicode error returns. (refs: `#52334`_)

* **PR** `#52334`_: (`waynew`_) 51879 fix binary pillar return error
  @ *2019-04-12 03:45:17 UTC*

  * 6eb2bce Merge pull request `#52334`_ from waynew/51879-fix-binary-pillar-return-error

  * ead856e Merge branch '2019.2' into 51879-fix-binary-pillar-return-error

  * 2aa971d lint cleanup

  * 28c2945 keep_pillar not needed

  * fb010c0 Add binary pillar to the docs

  * f2aebf9 Assume file contents are binary

  * 2b8c782 Test gpg render with replace newlines

  * c4b385b Allow binary pillar data

  * 604b671 Return binary data from gpg renderer

  * 32aafab Ignore vscode and fix swap ignore

* **ISSUE** `#52041`_: (`arsiesys`_) 2019.2 influxdb_retention_policy.present broken when used extra arguments (refs: `#52043`_)

* **PR** `#52043`_: (`arsiesys`_) fix missing client_args in influxdb module
  @ *2019-04-12 03:43:03 UTC*

  * 2d59705 Merge pull request `#52043`_ from arsiesys/fix_influxdb_state_rp

  * e617c5b Merge branch '2019.2' into fix_influxdb_state_rp

  * 7661860 fix missing client_args in influxdb module

* **PR** `#52146`_: (`twangboy`_) Add missing symlink test
  @ *2019-04-12 00:51:16 UTC*

  * 1b969c3 Merge pull request `#52146`_ from twangboy/fix_test_symlink_2019.2

  * 8e1c882 Merge branch '2019.2' into fix_test_symlink_2019.2

  * a429542 Merge branch '2019.2' into fix_test_symlink_2019.2

  * 401c253 Merge branch '2019.2' into fix_test_symlink_2019.2

  * cce6200 Fixing lint

  * c7cb009 Merge branch '2019.2' into fix_test_symlink_2019.2

  * 3eae05a Merge branch '2019.2' into fix_test_symlink_2019.2

  * 83bed46 Add missing symlink test

* **PR** `#52341`_: (`cbosdo`_) virt.pool_running: fix pool start
  @ *2019-04-12 00:14:52 UTC*

  * 7a1b8ca Merge pull request `#52341`_ from cbosdo/virt-state-fixes

  * 89f0bd8 Merge branch '2019.2' into virt-state-fixes

  * 25b9681 virt.pool_running: fix pool start

  * 30981d2 Remove unneeded kwargs in virt states

  * 0871c02 virt: allow defining the VM type and arch when creating it

  * 1c65d25 Updating running domains in virt.running

  * 13d7819 Add missing virt states unit tests

  * 0681d86 virt.running support for all virt.init options

  * c6a444b Add test case for virt.running

  * 2db7a98 Let virt running state provide errors

* **ISSUE** `#52350`_: (`Ch3LL`_) Re-Add Python 2 unicode string literals in YAML renderer  (refs: `#52427`_)

* **PR** `#52427`_: (`garethgreenaway`_) [2019.2] Support for old yaml render
  @ *2019-04-12 00:06:37 UTC*

  * 6040282 Merge pull request `#52427`_ from garethgreenaway/52350_readd_and_gate_unicode_string_literal_support

  * 82f010a Merge branch '2019.2' into 52350_readd_and_gate_unicode_string_literal_support

  * ae81fee Merge branch '2019.2' into 52350_readd_and_gate_unicode_string_literal_support

  * b618d44 Merge branch '2019.2' into 52350_readd_and_gate_unicode_string_literal_support

  * b191bc0 Merge branch '2019.2' into 52350_readd_and_gate_unicode_string_literal_support

  * 38a9818 Merge branch '2019.2' into 52350_readd_and_gate_unicode_string_literal_support

  * 2767984 Removing logging entry

  * 71cd303 Adding missing yamlloader_old.py

  * f848aa4 Adding support back in with, a gated configuration option, for the old YAML Loader.

* **ISSUE** `#51865`_: (`magenbrot`_) salt.match.search_by resulting in 'None' since 2019.2 (refs: `#52234`_)

* **PR** `#52234`_: (`garethgreenaway`_) [2019.2] Fixes to matchers when used in pillar
  @ *2019-04-12 00:05:48 UTC*

  * 05ba7c5 Merge pull request `#52234`_ from garethgreenaway/51865_match_search_by_master

  * 1760245 Merge branch '2019.2' into 51865_match_search_by_master

  * d50f011 Merge branch '2019.2' into 51865_match_search_by_master

  * b0cbb60 Merge branch '2019.2' into 51865_match_search_by_master

  * 799a08b Merge branch '2019.2' into 51865_match_search_by_master

  * 21891d6 Merge branch '2019.2' into 51865_match_search_by_master

  * a2173d7 Fixing a typo where attempting to get a list from __opts__ instead of an individual item

  * 6a5b5b2 swapping out if...else approach for __opts__.get approach.

  * aa2c626 With the change/addition of the matcher subsystem in 2019.2, the match.search_by when used in pillar broke when targetting the minion that was also the salt master.  This was caused by the id in __opts__ being used in all cases.  This change updates the glob_match function to use the preserved minion_id of the master if it is available so that targeting works as expected.

* **PR** `#52160`_: (`cbosdo`_) Virt whitespace fix
  @ *2019-04-12 00:04:25 UTC*

  * 80d7aea Merge pull request `#52160`_ from cbosdo/virt-whitespace-fix

  * fd1f539 Merge branch '2019.2' into virt-whitespace-fix

  * b297e7d virt: handle whitespaces in VM names

* **ISSUE** `#51832`_: (`nocturo`_) pillar include stopped working (refs: `#52008`_)

* **PR** `#52008`_: (`waynew`_) Allow `/` in pillar includes
  @ *2019-04-12 00:02:40 UTC*

  * b551bbd Merge pull request `#52008`_ from waynew/51832-re-allow-slash-includes

  * ee3115f Allow leading dots and / as pillar separators

  * 29c676d Ensure _closing exists

  * eb517e1 Swap '/' for '.' when matching

* **ISSUE** `#51821`_: (`OrangeDog`_) 'comment' is an invalid keyword argument for 'test.fail_without_changes' (refs: `#51937`_)

* **PR** `#51937`_: (`garethgreenaway`_) [2019.2] Fix to test state functions to allow arguments that mod_watch uses
  @ *2019-04-11 23:57:44 UTC*

  * d3159cb Merge pull request `#51937`_ from garethgreenaway/51821_ensure_result_comment_changes_valid_arguments

  * 86c63b5 Merge branch '2019.2' into 51821_ensure_result_comment_changes_valid_arguments

  * 0966d61 Merge branch '2019.2' into 51821_ensure_result_comment_changes_valid_arguments

  * 5527dff Ensure the comment, changes, and result are valid arguments for various test state functions as they are valid arguments for mod_watch.

* **ISSUE** `#51818`_: (`syphernl`_) salt.nacl.dec: expected str, bytearray, or unicode (refs: `#51913`_)

* **PR** `#51913`_: (`garethgreenaway`_) [2019.2] Fixes to utils/nacl.py
  @ *2019-04-11 23:56:57 UTC*

  * 7be0428 Merge pull request `#51913`_ from garethgreenaway/51818_fix_when_sk_is_empty

  * 55d7488 Merge branch '2019.2' into 51818_fix_when_sk_is_empty

  * b2128e8 Merge branch '2019.2' into 51818_fix_when_sk_is_empty

  * cb01a1b Merge branch '2019.2' into 51818_fix_when_sk_is_empty

  * 1a1e333 Merge branch '51818_fix_when_sk_is_empty' of github.com:garethgreenaway/salt into 51818_fix_when_sk_is_empty

    * 102f0a3 Merge branch '2019.2' into 51818_fix_when_sk_is_empty

    * 7fd04ec Merge branch '2019.2' into 51818_fix_when_sk_is_empty

  * dd23069 Adding tests for NACL changes.

  * c314f51 Correctly handle the situation when with the secret key or public key values are empty.

* **ISSUE** `#52116`_: (`lordcirth`_) host.present always returns None when in test=True (refs: `#52399`_)

* **PR** `#52399`_: (`waynew`_) Bring host.present in line with Salt's test conventions
  @ *2019-04-11 23:32:28 UTC*

  * d6f0971 Merge pull request `#52399`_ from waynew/52116-fix-host-present-fail

  * 8440ae1 Merge branch '2019.2' into 52116-fix-host-present-fail

  * dd002fd Fix linter

  * 9d1b2a0 Only return None on host.present changes when test

* **PR** `#52477`_: (`mattp-`_) 2019.2 backport `#52472`_ modules.cmdmod: handle windows environ better
  @ *2019-04-11 23:13:34 UTC*

  * **PR** `#52472`_: (`mattp-`_) modules.cmdmod: handle windows environ better (refs: `#52476`_, `#52477`_)

  * 7c709cf Merge pull request `#52477`_ from bloomberg/win_cmd_2019

  * 736a437 2019.2 bacpkport: modules.cmdmod: handle windows environ better

* **ISSUE** `#49661`_: (`ephreal`_) Issues starting salt-master or salt-minion with openssl-1.1.1-1 (refs: `#51655`_)

* **PR** `#52423`_: (`bbinet`_) Remove unused salt.crypt import
  @ *2019-04-11 21:44:41 UTC*

  * **PR** `#51655`_: (`garethgreenaway`_) [2017.7] Removing unused salt.crypt imports (refs: `#52423`_)

  * b0d3c76 Merge pull request `#52423`_ from bbinet/unused-salt-crypt

  * dc330e7 Merge branch '2019.2' into unused-salt-crypt

  * 4b26dea Merge branch '2019.2' into unused-salt-crypt

  * 9607c38 Also remove unused salt.crypt import in pillar/__init__.py

  * 49f2631 Remove unused salt.crypt import

* **PR** `#52506`_: (`mattp-`_) 2019.2: transport.zmq: fix bug introduced by b7df7e75cf2
  @ *2019-04-11 21:12:51 UTC*

  * 4bb9185 Merge pull request `#52506`_ from bloomberg/2019_zmq_uri

  * 1e9dd7f transport.zmq: fix bug introduced by b7df7e75cf2

* **ISSUE** `#52462`_: (`Ch3LL`_) integration.states.test_supervisord test failing (refs: `#52513`_, `#52512`_)

* **PR** `#52513`_: (`dwoz`_) [2019.2] Fix supervisord
  @ *2019-04-11 21:09:17 UTC*

  * 1532642 Merge pull request `#52513`_ from dwoz/supervisord_2019.2

  * dc9ace6 The exit code matters.

* **PR** `#52496`_: (`dwoz`_) Fix wart in IPC merge forward
  @ *2019-04-11 05:19:02 UTC*

  * **PR** `#52482`_: (`dwoz`_) Ipc fixes 2019.2 (refs: `#52496`_)

  * 978084d Merge pull request `#52496`_ from dwoz/ipc_wart

  * 9805f38 Fix wart in IPC merge forward

* **PR** `#52482`_: (`dwoz`_) Ipc fixes 2019.2 (refs: `#52496`_)
  @ *2019-04-10 19:53:58 UTC*

  * 791b646 Merge pull request `#52482`_ from dwoz/ipc_fixes_2019.2

  * f45d29b Remove un-needed test

  * 0141b7f Fix merge wart

  * 82150f0 Remove un-used import

  * c9ec8b1 Ensure exceptions in service future are handled

  * 25f5a90 Use six.reraise for py3 compatibility

  * 6d80789 Fix ipc unit tests

  * c80da32 Fix linter issues

  * 024b4b6 Remove IPCClient singleton

  * f1d0e02 Re-raise queued exceptions with traceback

* **ISSUE** `#51932`_: (`tomlaredo`_) [REGRESSION] --output-diff doesn't display changes anymore with test=True since v2019.2.0 (refs: `#51992`_)

* **PR** `#51992`_: (`garethgreenaway`_) [2019.2] Swapping pchanges for changes in file state.
  @ *2019-04-09 19:38:57 UTC*

  * 3173673 Merge pull request `#51992`_ from garethgreenaway/51932_show_diff_when_test_True

  * 7c4abd6 changes needs to be a dictionary.

  * ac950b3 Merge branch '2019.2' into 51932_show_diff_when_test_True

* **PR** `#52413`_: (`Ch3LL`_) [2019.2] Merge forward from 2018.3 to 2019.2
  @ *2019-04-08 16:19:49 UTC*

  * bd3ad7b Merge pull request `#52413`_ from Ch3LL/merge-2019.2

  * 30783f4 Merge branch '2019.2' into merge-2019.2

* **PR** `#52151`_: (`simonflood`_) Fix typo in actual 2019.2.0 release notes
  @ *2019-04-08 13:36:28 UTC*

  * **PR** `#51861`_: (`simonflood`_) Fix typo in 2019.2.0 release notes (refs: `#52151`_)

  * a18abf2 Merge pull request `#52151`_ from simonflood/patch-2

  * a4a5521 Merge branch '2019.2' into patch-2

  * 3d31102 Fix typo in actual 2019.2.0 release notes

    * 16733da Merge branch '2019.2' into merge-2019.2

    * fe13214 Merge branch '2018.3' into '2019.2'

      * b6028b9 Merge pull request `#52403`_ from bdrung/fix-test-conditions

        * e74f78f Skip ExtendTestCase if templates directory is missing

        * 0473683 Skip SampleConfTest if sample conf directories are missing

      * e5a755d Merge pull request `#52250`_ from twangboy/fix_grains

        * a77ec81 Merge branch '2018.3' into fix_grains

        * b405391 Refer to the windowsdomain grain

        * e103561 Add some documentation about the domain grain on Windows

        * c874831 Don't set the domain grain to windowsdomain

        * 65eb461 Add a test for windows grains

        * 173d1e7 Fix the domain grain on Windows

            * 0ce0c04 Merge branch '2019.2' into 51932_show_diff_when_test_True

* **ISSUE** `#51869`_: (`eimantaszd`_) x509.sign_remote_certificate not working after upgrade to 2019.2.0 (refs: `#52381`_)

* **PR** `#52381`_: (`dwoz`_) Fix issue `#51869`_ and add cert signing test
  @ *2019-04-05 20:36:11 UTC*

  * 6bae227 Merge pull request `#52381`_ from dwoz/issue_51869

  * cd78485 Merge branch '2019.2' into issue_51869

* **ISSUE** `#21927`_: (`jfindlay`_) network.traceroute intermittently stacktraces (refs: `#52370`_)

* **PR** `#52370`_: (`jfindlay`_) Fix network.traceroute exec module function
  @ *2019-04-03 16:39:20 UTC*

  * c1063cf Merge pull request `#52370`_ from jfindlay/traceroute

  * 2f49231 modules.network: update unit test

  * 5b64fc0 modules.network: log and skip problematic traceroute lines

  * e33f5c1 modules.network: standardize util check

* **PR** `#52397`_: (`garethgreenaway`_) [2019.2] Merge forward from 2018.3 to 2019.2
  @ *2019-04-02 22:12:45 UTC*

  * 3675f1e Merge pull request `#52397`_ from garethgreenaway/merge-2019.2

  * 28e76b1 Merge branch '2018.3' into merge-2019.2

  * 28f947e Merge pull request `#52213`_ from garethgreenaway/beacon_state_dont_save_test_true

    * 7f83b4b Swapping out if state looking for test in opts for a __opts__.get

    * e1cf599 Merge branch '2018.3' into beacon_state_dont_save_test_true

    * b751122 Merge branch '2018.3' into beacon_state_dont_save_test_true

    * a901ec4 Don't save beacons when test=True

  * 10d041b Merge pull request `#52344`_ from twangboy/os_release_embedded

    * 74ab4d3 Use old way to get osrelease if new way fails

  * e88d3ba Merge pull request `#52345`_ from garethgreenaway/52197_incron_cannot_have_comments

    * 070837a Merge branch '2018.3' into 52197_incron_cannot_have_comments

    * 8461608 Updating the incron module, state module and tests to remove use of comments.

              * 855f31a Remove un-used file

              * affd9b8 Fix setup/teardown methods

              * 215bf93 Refresh after modifying tmp pillars

              * 95c3aba Add config for listener

              * 5d231f4 remove unused import

              * 8c1b1db Use tmp pillar for signing policies

              * a0e2458 fix unused import

              * 7f5f7dd Fix requisite path

              * 5630498 Fix signing policies path

              * 0bd0826 Fix issue `#51869`_ and add cert signing test

* **PR** `#52347`_: (`Ch3LL`_) [2019.2] Merge forward from 2018.3 to 2019.2
  @ *2019-03-28 16:41:53 UTC*

  * 27e6cbf Merge pull request `#52347`_ from Ch3LL/merge-2019.2

  * 63962b5 Merge branch '2018.3' into '2019.2'

  * bda3ca2 Merge pull request `#51749`_ from terminal-labs/salt-cloud-map-alt-update

    * 9ca0f72 Changed where to mention the map files compatibility for minion configuration options. This is a result of @Ch3LL suggestion on the PR itself for this doc change.

    * 364ef06 Added mention of map file alternative for minion configuration options.

  * a743fff Merge pull request `#52113`_ from twangboy/fix_lgpo

    * bb4a704 Merge branch '2018.3' into fix_lgpo

    * 7186405 Merge branch '2018.3' into fix_lgpo

    * 7656331 Change default language from 1033 to en_US

  * 7040643 Merge pull request `#52172`_ from garethgreenaway/51959_fix_acl_present_output

    * 8c53890 Merge branch '2018.3' into 51959_fix_acl_present_output

    * 0bdde94 Merge branch '2018.3' into 51959_fix_acl_present_output

    * c5337e1 Merge branch '2018.3' into 51959_fix_acl_present_output

    * 889660f Fixing lint.

    * bfdb669 Updating the reverse octal lookup dictionary.  Updating tests.

    * 24c907b Adding additional permissions to the lookup.

    * 4b99afa Fixing the output when there are changes for the ACL state so the permissions are shown and not the octal number.

  * 45d6cad Merge pull request `#52283`_ from dmurphy18/fix_cpe_name_amzn2

    * cbe5f7d Update to allow for malformed CPE_NAME from some OS's

  * 14a6b9d Merge pull request `#52306`_ from terminal-labs/replace-ping-with-version

    * c04ba6e Changed a text artifact from the ping function to supporting text for the version function.

    * 0b1eb00 Replaced `test.ping` with `test.version` Result of issue `#52277`_

  * 7b2b521 Merge pull request `#51963`_ from DSRCorporation/bugs/49147_ipc_subscriber

    * 37aeba3 Minor: Fix typo in docstring

    * cc46e9c Merge branch '2018.3' into bugs/49147_ipc_subscriber

    * 23733bd Regression test for parallel IPCMessageSubscriber support

    * 2bc2a7d Merge branch '2018.3' into bugs/49147_ipc_subscriber

    * 684bf58 Update doc conf with the new import `tornado.queues`

    * 008cf49 Merge branch '2018.3' into bugs/49147_ipc_subscriber

    * 01e9a3d Merge branch '2018.3' into bugs/49147_ipc_subscriber

    * 710ab50 Support parallel work of multiple IPCMEssageSubscribers in one process

  * 87bb513 Fix failing symlink test (`#52145`_)

  * 8255901 document `regex_replace` Jinja filter (`#52326`_)

  * 3211397 Merge pull request `#52310`_ from garethgreenaway/merge-2018.3

    * 9324b83 Merge branch '2018.3' into merge-2018.3

  * 71e9b66 Merge pull request `#52312`_ from terminal-labs/zone-clarification

    * ae0e18f Merge branch '2018.3' into zone-clarification

    * e8c8dba Added in an explanation of the --zone flag approved in `#52251`_

      * 4908ed3 Merge branch '2017.7' into merge-2018.3

      * b6a0161 Merge remote-tracking branch 'upstream/2017.7.9' into 2017.7

        * 1f99e28 Let's not include raet by default

      * 4306779 Merge branch '2017.7.9' into 2017.7

        * 36ed50d Lock to unittest-xml-reporting 2.2.1

      * 3e6cb79 Merge branch '2017.7.9' into 2017.7

        * 57348ca Add static requirements for Arch linux

        * cc6fb46 Additionally ignore files in nox virtualenvs and CI artifacts directories

      * bf9c55e Previously have setuptools-git installed if ioflo is to be installed

      * 973e1ca Merge remote-tracking branch 'upstream/2017.7.9' into 2017.7

        * 981335a Revert "Avoid a traceback on tornado.testing test classes"

      * f48ba6a Merge remote-tracking branch 'upstream/2017.7.9' into 2017.7

        * b039cec Windows now has a static requirements file and no longer needs hacks

        * a86af2b Merge pull request `#52226`_ from dwoz/jenkins_build

          * 8c0f46b Use windows state to bootstrap windows builds

        * 7263956 Lock coverage and xml-unittest-reporting versions

        * dce4ffa Avoid a traceback on tornado.testing test classes

* **PR** `#52314`_: (`twangboy`_) Add the ability to pass a timeout to beacons
  @ *2019-03-27 19:11:13 UTC*

  * d3f4c9d Merge pull request `#52314`_ from twangboy/fix_beacon_tests

  * a5fa99a Add missing \*\*kwargs

  * 7e88d04 Add the ability to pass a timeout to beacons

* **PR** `#52311`_: (`garethgreenaway`_) [2019.2] Merge forward from 2018.3 to 2019.2
  @ *2019-03-26 18:31:32 UTC*

  * bad4e47 Merge pull request `#52311`_ from garethgreenaway/merge-2019.2

  * 11cd485 Merge branch '2018.3' into merge-2019.2

  * 582d306 Merge pull request `#52307`_ from Akm0d/doc_fix

    * 4da0fd6 Fix x509 inconsistent file name in state example

  * 2cdf48e Merge pull request `#52276`_ from terminal-labs/replace-github-dead-link

    * a2fbbe0 Merge branch '2018.3' into replace-github-dead-link

  * 8fa0e51 Merge pull request `#52290`_ from Akm0d/doc_fix

    * ca00e4b Merge branch '2018.3' of github.com:saltstack/salt into doc_fix

    * 8e1ec15 Add missing master/minion docs for log_rotate*

      * 08728cf Merge branch '2018.3' into replace-github-dead-link

  * d2fd84f Merge pull request `#51724`_ from clinta/docker-create-with-ip

    * c933663 Merge branch '2018.3' into docker-create-with-ip

  * 838a7aa Merge pull request `#51753`_ from terminal-labs/docs-sphinx-ref-deadlink-fix

    * f2b6abd Merge branch '2018.3' into docs-sphinx-ref-deadlink-fix

    * 9857f53 Merge branch '2018.3' into docs-sphinx-ref-deadlink-fix

    * 8a11d27 Merge branch '2018.3' into docs-sphinx-ref-deadlink-fix

    * 842ec84 Merge branch '2018.3' into docs-sphinx-ref-deadlink-fix

    * 9275207 Merge branch '2017.7' into docs-sphinx-ref-deadlink-fix

    * 2330c2a makefile had an old sphinx-doc link, updated to new general front page of sphinx docs.

    * 8d70e3b Replaced all bad sphinx links with ones from the new sphinx doc site.

    * ebdffcd replaced two python sphinx deadlinks with sphinx new relevant documentation pages.

              * a4e3e34 Merge branch '2018.3' into docker-create-with-ip

  * efb9ec0 Merge pull request `#52215`_ from garethgreenaway/bp-52212

    * 65857ef Merge branch '2018.3' into bp-52212

    * a96bf24 Back-port PR `#52212`_ to 2018.3

              * c6e553c add networking_config to container_create for custom network_mode

              * 5c99dbd add test to expose ip not added to custom network `#51723`_

  * 679c4b2 Merge pull request `#52269`_ from garethgreenaway/merge-2018.3

    * ee58560 Merge branch '2018.3' into merge-2018.3

  * 418e543 Merge pull request `#52261`_ from dwoz/update_kitchen

    * a87c6ea Use windows state to bootstrap windows builds

    * 1aa1bd8 Merge branch '2017.7' into merge-2018.3

    * 2962e94 Lock coverage and xml-unittest-reporting versions

    * 595303b Merge remote-tracking branch 'upstream/2017.7.9' into 2017.7

      * 55e150c Proper setup and teardown

      * b9b6009 Don't run distro on windows

      * 3cb5c82 Merge pull request `#52208`_ from s0undt3ch/2017.7.9

    * b14dbc9 Merge branch '2017.7.9' into 2017.7

      * 6a789a1 Update static requirements

      * cee9480 Lock PyYAML to < 5.1

      * a4f241d The kitchen nox verifier already takes care of the sinlge `-v` flag.

      * 0cb641e Fix static requirements search bad logic

      * 45a3e4a `distro` reports Opensuse 15 as Opensuse Leap 15

      * de7bb24 Ubuntu 18.04 locked requirements files

      * bc08e3c Ubuntu 16.04 locked requirements files

      * 0d353d2 Ubuntu 14.04 locked requirements files

      * 1186122 Opensuse 42 locked requirements files

      * fa6888b Opensuse 15 locked requirements files

      * b6578b8 Fedora 29 locked requirements files

      * 777dbb0 Fedora 28 locked requirements files

      * 4388fa9 Debian 9 locked requirements files

      * 2f9030f Debian 8 locked requirements files

      * 1b18ec5 CentOS 7 locked requirements files

      * 6e9f0c0 CentOS 6 locked requirements

      * 7415846 Start handling static(and platform specific) requirements files

      * ea4d370 Allow overriding some requirements based on distro information

      * 17017a1 Merge pull request `#51361`_ from olipovch/cloud-sync-after-install

        * 8fde3a0 Merge branch '2017.7' into cloud-sync-after-install

        * ab00151 Fix salt-cloud sync_after_install functionality

    * ff54f53 The kitchen nox verifier already takes care of the sinlge `-v` flag.

    * a2aa708 Fix static requirements search bad logic

    * 621b047 `distro` reports Opensuse 15 as Opensuse Leap 15

    * bc00a26 Ubuntu 18.04 locked requirements files

    * d5ed9e1 Ubuntu 16.04 locked requirements files

    * 03879bf Ubuntu 14.04 locked requirements files

    * c3d7a18 Opensuse 42 locked requirements files

    * b29d986 Opensuse 15 locked requirements files

    * 73154d0 Fedora 29 locked requirements files

    * bf36cd4 Fedora 28 locked requirements files

    * 52cc5bb Debian 9 locked requirements files

    * cb4a823 Debian 8 locked requirements files

    * 2128a79 CentOS 7 locked requirements files

    * 4a29e93 CentOS 6 locked requirements

    * 0d96e64 Start handling static(and platform specific) requirements files

  * 0fc82bd Merge pull request `#52193`_ from Ch3LL/bp-47005

    * 1a54fd1 Merge branch '2018.3' into bp-47005

  * 0f3cd2a Merge pull request `#52194`_ from Ch3LL/bp-52149

    * bff3f3c Merge branch '2018.3' into bp-52149

    * 7e459a1 example names parameter in file.managed state

      * f68caa6 Merge branch '2018.3' into bp-47005

  * 85be178 Merge pull request `#52201`_ from max-arnold/rename-beacon-validate

    * e1e9a2b Merge branch '2018.3' into rename-beacon-validate

  * 0383ac3 Merge pull request `#52189`_ from Ch3LL/merge-2018.3

    * 9972980 Merge branch '2018.3' into merge-2018.3

    * 79962ab Merge branch '2017.7' into '2018.3'

      * fd6068e Allow overriding some requirements based on distro information

      * 659ec11 Merge remote-tracking branch 'upstream/2017.7.9' into 2017.7

        * 18bbbec We need to nest require `req_win.txt`

      * 956a84c Merge pull request `#51995`_ from s0undt3ch/2017.7

        * 0bf9d62 Merge remote-tracking branch 'upstream/2017.7.9' into 2017.7

        * baf776b Merge pull request `#51974`_ from s0undt3ch/features/nox-2017.7

        * ee4df3a Lint fixes

        * 56f841f Windows needs special treatment

        * c3cb447 Requirements fixes

        * 6a67531 We need a fixed winrm-fs so that dotfiles are also included

        * 15c6a53 use kitchen-salt from my fork for now

      * b745332 Merge pull request `#51800`_ from dwoz/typo_fix

        * 5bbe5e0 Fix up docstring

        * 9f3c583 Fix typo in docstring

          * 75acce1 Rename obsolete beacon validation function

          * d1700f3 Merge branch '2018.3' into bp-47005

  * 03f228d Merge pull request `#52112`_ from Ch3LL/proxy_gs

    * 7ad4758 Update device names in proxy getting started docs

          * 25ae7c8 remove freebsd-upstream reference

          * b70c45c Remove salt FreeBSD repo which is now 2 years out of date

                * 62e5404 github issue tracker link and sends you to the url for listed issues.

                * ccf6a06 Replaced a dead link for github issue tracker with another github link for the issue tracker and added a link to show more options for closing issues in commit messages.

* **PR** `#52190`_: (`Ch3LL`_) [2019.2] Merge forward from 2018.3 to 2019.2
  @ *2019-03-23 01:09:33 UTC*

  * 3ac6dbd Merge pull request `#52190`_ from Ch3LL/merge-2019.2

  * 68c02b9 Merge branch '2019.2' into merge-2019.2

* **PR** `#52240`_: (`soer7022`_) Fix Typos "swtich" to "switch"
  @ *2019-03-23 00:08:50 UTC*

  * f5fc807 Merge pull request `#52240`_ from soer7022/patch-2

  * d130832 Merge branch '2019.2' into patch-2

  * 3b6fdf8 Merge branch '2019.2' into patch-2

  * 5db7a3f Fix Typos "swtich" to "switch"

      * 34d601e Merge branch '2019.2' into merge-2019.2

* **ISSUE** `#52036`_: (`ghost`_) rsync.synchronized: "An exception occurred in this state: 'Changes' should be a dictionary." (refs: `#52040`_)

* **PR** `#52040`_: (`garethgreenaway`_) [2019.2] Fix to rsync state
  @ *2019-03-21 19:08:19 UTC*

  * a00245e Merge pull request `#52040`_ from garethgreenaway/52036_rsync_state_no_changes_when_error

  * 09d1672 Merge branch '2019.2' into 52036_rsync_state_no_changes_when_error

* **PR** `#51962`_: (`Ch3LL`_) Update 2019.2.0 release notes with other tojson example
  @ *2019-03-21 16:37:43 UTC*

  * 5387821 Merge pull request `#51962`_ from Ch3LL/rn_update

  * f63bae9 Merge branch '2019.2' into rn_update

* **PR** `#52262`_: (`dwoz`_) Use windows state to bootstrap windows builds
  @ *2019-03-20 22:12:25 UTC*

  * 0fe7f28 Merge pull request `#52262`_ from dwoz/update_kitcen_2019.2

  * 49d529d Use windows state to bootstrap windows builds

  * e2c3f93 Merge branch '2019.2' into rn_update

  * 164398f Merge branch '2019.2' into rn_update

  * c04b2a0 Merge branch '2019.2' into rn_update

  * 9ca6e50 Update doc/topics/releases/2019.2.0.rst

  * 052f193 add additional formatting to 2019.2.0 release notes

  * a6ca59a Update 2019.2.0 release notes with other tojson example

          * 84cd46c Merge branch '52036_rsync_state_no_changes_when_error' of github.com:garethgreenaway/salt into 52036_rsync_state_no_changes_when_error

            * 4a126b3 Merge branch '2019.2' into 52036_rsync_state_no_changes_when_error

          * d5d3117 Removing debugging statements

          * 0fb859d Adding a test for the rsync state

          * 4c678e6 When the retcode is non-zero, there are no changes so should include the default empty dictionary.

          * c6ba2e6 Fix lint for test_win_file

          * 9ada8d9 Merge branch '2018.3' into '2019.2'

          * f8c0266 Allow overriding some requirements based on distro information

          * c58c775 Merge pull request `#52035`_ from Ch3LL/bp-52012

            * 37666bd Merge branch '2018.3' into bp-52012

          * 54ff3fe Merge pull request `#51935`_ from Ch3LL/py3_doc

            * b217f94 Merge branch '2018.3' into py3_doc

            * 605bfaf Update futures dependency for python2 only

            * 072cd84 Update supported python versions in installation docs

          * 892cdae Merge pull request `#52038`_ from terminalmage/docs

            * 4d82146 Minor documentation tweak for file.replace state

          * a7a9754 Merge pull request `#51896`_ from twangboy/win_disks

            * 057d415 Merge branch '2018.3' into win_disks

            * 0d419e3 Fix some lint

            * aa61dab Add tests

            * 9f6ec53 Add all attached drives to the disks grain

          * 48d298c Merge pull request `#51918`_ from twangboy/fix_compat

            * a791901 Fix compat, add tests

            * 2837bb9 Fix _compat for py3

          * 02328a6 Merge pull request `#52030`_ from Ch3LL/bp-52004

            * b4e3183 Fixed comparison of `None` with constants

          * aa82fcc Merge pull request `#52029`_ from Ch3LL/bp-52003

            * fcac9f3 Skip Test on Non-Windows systems

            * f42d17d Derive from LoaderModuleMockMixin

            * 5052017 Define __opts__ dict

            * b7b571e Define __opts__ dict

            * ee3ad08 Define __opts__ dict

            * 64d8451 Use default file module

            * 886ef19 Fix name of makedirs\_ method

            * 4cc5f77 Check for path to be a symlink

          * 5ff1725 Merge pull request `#52028`_ from Ch3LL/bp-50384

            * 6493eb0 Fix issue `#50381`_

                  * f2b4ec8 Don't log debug messages during close

          * 7ab1281 Merge pull request `#51936`_ from gtmanfred/2018.3

            * faa3471 Merge branch '2018.3' into 2018.3

          * 2ebfa22 Merge pull request `#51967`_ from twangboy/add_compat_tests

            * 2056578 Merge branch '2018.3' into add_compat_tests

            * e85f004 Merge branch '2018.3' into add_compat_tests

            * ea69062 Fix lint

            * eb984f5 Add unit tests for _compat.py

          * c8e2971 Merge pull request `#51980`_ from Ch3LL/merge-2018.3

            * 9adc19e Merge branch '2017.7' into '2018.3'

              * bfaa6a9 Merge pull request `#51895`_ from twangboy/win_update_2017.7

                * b2cb1eb Merge branch '2017.7' into win_update_2017.7

              * 7d6280d Merge pull request `#51875`_ from dwoz/avoid_ssl_race

                * e99654d Merge branch '2017.7' into avoid_ssl_race

              * c0bb1f7 Merge pull request `#51850`_ from waynew/cherry-pick-ping-fix

                * 6da495f Fix linter

                * f78b360 fix reactor ping test

              * ad7a9ec Merge pull request `#51893`_ from twangboy/gate_zfs_2017.7

                * e0d58eb Gate zfs module on Windows

                * f758a10 Avoid race condition when initializing OpenSSL

                * 0f125db Add __virtual__ to win_update

              * 864d4be Merge pull request `#51770`_ from Ch3LL/doc_conf_2017

                * 25d9ca2 Update release versions for the 2017.7 branch

              * 3cf3099 Merge pull request `#51774`_ from terminal-labs/py3-server-docs-update

                * 1f00c89 Added in python 3 server according to the consensus from `#51748`_

                * bfb9d87 added the python3 command for startign the python http server.

              * b4153d3 Merge pull request `#51757`_ from twangboy/fix_case_2017.7

                * 6b0b5d2 Fix failing py3 tests

                * feb29f3 Make recurse and directory case sensitive

          * 2c4dff6 Merge pull request `#51905`_ from aplanas/fix_mount

            * ac688df mount: fix extra -t parameter

          * 4b2c8cc Merge pull request `#51815`_ from garethgreenaway/51673_multiple_file_sections_with_excludes

            * 58ef51d Merge branch '2018.3' into 51673_multiple_file_sections_with_excludes

            * 8c4485d Merge branch '2018.3' into 51673_multiple_file_sections_with_excludes

            * b55a894 Fixing some code that was not working correctly with Python 3.

            * 63da8be Fixing a bug that caused excludes to not work as expected when multiple file options were in place, the excludes of the last file section were being used over any previous ones.  Including a test to ensure excludes work as expected when multiple file sections are in place.

          * 1bf3fc8 Merge pull request `#51867`_ from Oloremo/mysql-module-fix-for-python3

            * dfcfebd Merge branch '2018.3' into mysql-module-fix-for-python3

            * b6d217c Merge branch '2018.3' into mysql-module-fix-for-python3

            * 9745b0a Fixed typo

            * 8149e9e Merge branch '2018.3' into mysql-module-fix-for-python3

            * 58d8a2e Merge branch '2018.3' into mysql-module-fix-for-python3

            * f964962 Added handling of empty server_version

            * 58791e9 Decode mysql_version for python3 compatibility

          * 7f05abf Merge pull request `#51908`_ from garethgreenaway/51862_icinga_fixes

            * 233dbaf Adding __salt__ to utils/icinga so cmd.run_all is available.

                                * 1e7490c update kubernetesmod in index.rst

                                * 1f3be1c fix import in test

                                * 8572c17 rename kubernetes module to kubernetesmod

* **PR** `#52032`_: (`Ch3LL`_) Add azure state and execution modules to doc index
  @ *2019-03-11 15:46:49 UTC*

  * 7d6b53c Merge pull request `#52032`_ from Ch3LL/fix_azure_docs

  * 8a8a5fa Add azure module ref pages and fix doc errors

  * 6a1d06a fix additional azure state module doc errors

  * 65d8f27 Update doc failures in azure modules

  * 92dbe2a Merge branch '2019.2' into fix_azure_docs

* **PR** `#52037`_: (`Ch3LL`_) Backport `#51201`_ into 2019.2
  @ *2019-03-07 19:45:18 UTC*

  * **PR** `#51201`_: (`terminalmage`_) Lint: Fix str-format-in-logging, len-as-condition, etc. (2) (refs: `#52037`_)

  * 96935c9 Merge pull request `#52037`_ from Ch3LL/bp-51201

  * 1fb0697 Remove develop modules not needed in 2019.2

  * e3adc2f Lint: Fix str-format-in-logging, len-as-condition, etc. (2)

* **PR** `#52034`_: (`terminalmage`_) fileclient: Fix traceback when template file cannot be cached
  @ *2019-03-07 19:41:24 UTC*

  * 75398e4 Merge pull request `#52034`_ from terminalmage/fix-get-template

  * 744dfd9 fileclient: Fix traceback when template file cannot be cached

* **PR** `#51984`_: (`Ch3LL`_) [2019.2] Merge forward from 2018.3 to 2019.2
  @ *2019-03-07 17:58:42 UTC*

  * 7af4f5c Merge pull request `#51984`_ from Ch3LL/merge-2019.2

  * 54ea40a Merge branch '2019.2' into merge-2019.2

  * 227ddbb Fix linter

  * a168913 Merge branch '2018.3' into '2019.2'

    * c68744a Merge pull request `#51975`_ from s0undt3ch/features/nox-2018.3

      * af4ae91 Lint fixes

      * 33955c9 Windows needs special treatment

      * d4f899f Requirements fixes

      * e550c60 We need a fixed winrm-fs so that dotfiles are also included

      * ada1ef3 use kitchen-salt from my fork for now

    * a689177 Merge pull request `#51807`_ from Ch3LL/2018.3.5_rn

      * 2c0b85c Add 2018.3.5 release notes

    * 6aee2c4 Merge pull request `#51806`_ from twangboy/fix_beacon

      * 2bf6179 Fix some lint

      * 0f38eea Add lowercase test

      * 1459985 Make sure drive letter is uppercase for re compare

      * 7cdc660 Add some tests

      * 48ae8c6 Fix disk.usage beacon on Windows

    * da815ba Merge pull request `#51966`_ from twangboy/use_winapi_com

      * a38300b Use winapi.com instead of coinitialize

    * 7673c69 Merge pull request `#51920`_ from twangboy/add_zabbix

      * e2d496c Add zabbix to the Windows builds

    * 77c2796 Merge pull request `#51802`_ from garethgreenaway/merge-2018.3.4

      * 2e20939 Merge branch '2018.3' into merge-2018.3.4

      * 769f002 Merge branch '2018.3.4' into merge-2018.3.4

        * b53a843 Merge pull request `#51713`_ from dwoz/gemstestagain_2018.3.4

          * f2c6631 Merge branch '2018.3.4' into gemstestagain_2018.3.4

          * 1c82d24 Fix ruby gems tests, again

    * 496525d Merge pull request `#51930`_ from Ch3LL/release_docs

      * 9a68136 Update release documentation

    * a027c97 Merge pull request `#51931`_ from Ch3LL/bp_51298

      * 873cabd Roll back some changes to _compat.py

      * 1fcb0ff Fix edge case when minion ID is a 16-character string

    * 1fa2072 Merge pull request `#51892`_ from twangboy/gate_zfs

      * fbc2c0c Gate zfs grain on Windows

    * 89b0991 Merge pull request `#51836`_ from stratusjerry/backport_49039_2018.3

      * 35fdc4c Update win_pkg.py

    * c1ab63d Merge pull request `#51771`_ from Ch3LL/doc_conf_2018

      * 904beb3 [2018.3] change build_type and release in doc/conf.py

      * 3efcea5 Update release versions for the 2018.3 branch

    * 98f1b03 Merge pull request `#51775`_ from garethgreenaway/merge-2017.7

      * 92ffe03 fixing lint

      * 73b601d Merge branch '2017.7' into merge-2017.7

      * e04f735 Merge pull request `#51502`_ from ogd-software/51501-states-boto3_route53.py-fails-to-validate-ALIAS-A-records

        * e69ce9d Merge branch '2017.7' into 51501-states-boto3_route53.py-fails-to-validate-ALIAS-A-records

        * 5093406 Implement PEP8 E711 styling fix

        * 7640e90 Ensure boto3_route53 correctly validates existing ALIAS records

        * ff633b0 Ensure boto3_route53 survives attempts to validate ALIAS records

      * 9c128aa Merge pull request `#51732`_ from s0undt3ch/features/nox-2017.7

        * 328989d Add initial nox configuration. Tell `tox`'ers to use `nox`'.

      * 99ce48d Merge pull request `#51712`_ from dwoz/gemstestagain

        * 0d3b227 Fix ruby gems tests, again

      * 18452c4 Merge pull request `#51528`_ from twangboy/backport_51471

        * 8c79f02 Merge branch '2017.7' into backport_51471

        * 20a7ee5 Backport 51471

      * ee80ce3 Merge pull request `#51655`_ from garethgreenaway/49661_starting_salt_master_openssl

        * f647b95 Merge branch '2017.7' into 49661_starting_salt_master_openssl

        * 1831e64 Removing options from libcrypto.OPENSSL_init_crypto so it will simply use the defaults.

        * 8d0f801 removing salt.crypt from payload.py which is not used and causing salt-key to break.

        * a5a54c4 Removing unused import which is causing salt-master to not start when using openssl 1.1.1-1.

                      * c9c082c Fix azurearm field list doc error

                      * af0537f Add azure state and execution modules to doc index

* **PR** `#52004`_: (`chdamianos`_) Fixed comparison of `None` with constants (refs: `#52030`_)
  @ *2019-03-06 17:41:52 UTC*

  * 01bcff0 Merge pull request `#52004`_ from chdamianos/fix-constants-comparison

  * 6fd60af Fixed comparison of `None` with constants

* **PR** `#51981`_: (`bryceml`_) Fix typo in 2019.2.0 release notes
  @ *2019-03-05 23:59:33 UTC*

  * 8d6bb5d Merge pull request `#51981`_ from bryceml/2019.2

  * ecf0ef0 Fix typo in 2019.2.0 release notes

                              * a65e621 Adding an additional note warning that the file will not be changed because test=True, but could be changed by other states.

                              * 6c0dcf2 Swapping pchanges for changes in file state.

* **ISSUE** `#51825`_: (`OrangeDog`_) schedule.disable doesn't work in 2019.2.0 (refs: `#51855`_)

* **PR** `#51855`_: (`garethgreenaway`_) [2019.2] Global enable/disable was being ignored
  @ *2019-03-05 19:40:34 UTC*

  * c3105df Merge pull request `#51855`_ from garethgreenaway/51825_scheduled_global_enabled

  * 301e773 Merge branch '51825_scheduled_global_enabled' of github.com:garethgreenaway/salt into 51825_scheduled_global_enabled

    * ae7ab06 Merge branch '2019.2' into 51825_scheduled_global_enabled

    * ff13833 Merge branch '2019.2' into 51825_scheduled_global_enabled

  * 9e7e4ed Fixing broken add_job test.

  * 72466a5 Global enable/disable was being ignored

* **ISSUE** `#51745`_: (`fayak`_) Systemd update 241 on archlinux breaks systemd.py version() function (refs: `#51946`_)

* **PR** `#51946`_: (`Ethyling`_) Fix retrieve systemd version using regex
  @ *2019-03-05 19:20:19 UTC*

  * be28623 Merge pull request `#51946`_ from Ethyling/fix-systemd-version

  * b557707 Add test for systemd version from git describe

  * 94809d0 Fix retrieve systemd version using regex

* **ISSUE** `#51816`_: (`jkrauz`_) pillar_ldap broken in 2019.2.0 (refs: `#51964`_)

* **PR** `#51964`_: (`dwoz`_) [2019.2] Make sure ldap attrs are string types on python 2
  @ *2019-03-05 19:18:30 UTC*

  * c310022 Merge pull request `#51964`_ from dwoz/issue_51816

  * a879140 Merge branch '2019.2' into issue_51816

  * 0e61cf3 Fix linter errors/warnings

  * 171217a Revert debug logging

  * 8c641c6 make LDAP attr defaults string types on py2

* **PR** `#51976`_: (`s0undt3ch`_) [2019.2] Nox fixes
  @ *2019-03-05 18:56:49 UTC*

  * cb817f1 Merge pull request `#51976`_ from s0undt3ch/features/nox-2019.2

  * 0b4e68c Lint fixes

  * 257b3fc Windows needs special treatment

  * b298da0 Requirements fixes

  * 4f45a7e We need a fixed winrm-fs so that dotfiles are also included

  * fa70af2 use kitchen-salt from my fork for now

* **PR** `#51761`_: (`sdodsley`_) Add new module to release notes for 2019.2.0
  @ *2019-03-05 09:44:56 UTC*

  * **PR** `#51681`_: (`sdodsley`_) Add new module to release notes for 2019.2.0 (refs: `#51761`_)

  * f867e6e Merge pull request `#51761`_ from sdodsley/cheery_pick_fb_releasenotes

  * 80192c8 Add new module to release notes for 2019.2.0

* **PR** `#51799`_: (`s0undt3ch`_) Catch attribute error
  @ *2019-03-05 09:38:08 UTC*

  * 08e3956 Merge pull request `#51799`_ from s0undt3ch/2019.2

  * 342244a Merge branch '2019.2' into 2019.2

  * 3e8a17e Catch attribute error

* **PR** `#51810`_: (`Ch3LL`_) Add 2019.2.1 release notes
  @ *2019-03-05 09:26:47 UTC*

  * ff5d7d6 Merge pull request `#51810`_ from Ch3LL/2019.2.1_rn

  * aaee5fa Add 2019.2.1 release notes

* **ISSUE** `#51824`_: (`OrangeDog`_) schedule.present state not idempotent in 2019.2.0 (refs: `#51849`_)

* **PR** `#51849`_: (`garethgreenaway`_) [2019.2] Fix to schedule.list function to filter out attributes that are None
  @ *2019-03-01 19:56:17 UTC*

  * **PR** `#51647`_: (`dwoz`_) [develop] increase batch test timeout on windows (refs: `#51849`_)

  * 3732004 Merge pull request `#51849`_ from garethgreenaway/51824_splay_breaking_schedule_present

  * a0af441 Merge branch '2019.2' into 51824_splay_breaking_schedule_present

* **PR** `#51878`_: (`Ch3LL`_)  Add new terraform salt-ssh roster feature to release notes
  @ *2019-02-27 19:18:49 UTC*

  * 3fdb564 Merge pull request `#51878`_ from Ch3LL/terraform_rn

  * 502d197 fix spelling error in release notes

  * 4d53b41 Add new terraform salt-ssh roster feature to release notes

* **PR** `#51837`_: (`stratusjerry`_) Update win_pkg.py
  @ *2019-02-26 16:51:35 UTC*

  * **PR** `#49039`_: (`stratusjerry`_) Update win_pkg.py (refs: `#51836`_, `#51837`_)

  * e63c872 Merge pull request `#51837`_ from stratusjerry/backport_49039_2019.2

  * 531b23d Update win_pkg.py

  * 39b5645 Splay defaulting to None internally, broke schedule.present causing it to always report differences when a state is run.  Updating the schedule.list function to check if an attribute is None and remove it.

* **PR** `#51772`_: (`Ch3LL`_) Update release versions for the 2019.2 branch
  @ *2019-02-25 14:16:40 UTC*

  * 27dd9fb Merge pull request `#51772`_ from Ch3LL/doc_conf_2019

  * f28cc9b [2019.2] change build_type and release in doc/conf.py

  * 4c670e2 Update release versions for the 2019.2 branch

* **PR** `#51776`_: (`garethgreenaway`_) [2019.2] Merge forward from 2018.3 to 2019.2
  @ *2019-02-24 22:08:58 UTC*

  * 45425a4 Merge pull request `#51776`_ from garethgreenaway/merge-2018.3

  * 186306a reverting change in release notes, adding change to doc/ref/modules/all/index.rst.

  * 1ef140a Fixing lint.

  * 6173578 Fixing lint errors

  * 38dcab9 fixing lint

  * e37fc20 Merge branch '2018.3' into merge-2018.3

  * 7e3e71c Merge pull request `#51756`_ from twangboy/fix_case_sensitive

    * 4c55040 Fix failing py3 tests

    * 64f45f8 Make recurse and directory case sensitive

  * e75fc1c Merge pull request `#51747`_ from ymasson/fix_mysql_grants

    * f614dd7 Fix escaping for special characters

  * b1f7e85 Merge pull request `#51387`_ from chrillux/make-binarydata-output-possible

    * 010393e Make binary data output possible

  * 3475813 Merge pull request `#51694`_ from assafShapira/2018.3

    * 895b97a Merge branch '2018.3' into 2018.3

    * bc2d27a fix minion bootstrapping issue "/usr/lib/python2.7/site-packages/salt/utils/cloud.py", line 472 Configuration value u'provider' needs to be set

  * c7136cb Merge pull request `#51738`_ from garethgreenaway/nftables_cleanup

    * 8201d1e Fixing lint.

    * d681064 Merge branch '2018.3' into nftables_cleanup

    * e37458e Fixing a couple tests.

    * ed1b743 Additional cleanup.  Adding additional documentation for state module.

    * dc4afbb More updates to nftables module, state modules, and unit tests.

    * 3ec96e3 initial work to cleanup the nftables module, state module, and the unit tests.

  * 2121049 Merge pull request `#51733`_ from s0undt3ch/features/nox-2018.3

    * 97532c2 Add initial nox configuration. Tell `tox`'ers to use `nox`'.

  * f4adf33 Merge pull request `#51728`_ from gtmanfred/virtualnames

    * 61b4390 fix modulenames from virtualnames tests

  * d681fb9 Merge pull request `#51721`_ from dwoz/solarisipstests

    * 3263d31 Merge remote-tracking branch 'saltstack/2018.3' into solarisipstests

  * fb0a538 Merge pull request `#51676`_ from Ch3LL/merge-2018.3.4

    * 8111479 Merge branch '2018.3' into merge-2018.3.4

  * e08f08d Merge pull request `#50812`_ from gtmanfred/virtualnames

    * d59952f Merge branch '2018.3' into virtualnames

    * 33bb5bf fix use of virtualname

      * 2ca1253 Merge branch 'merge-2018.3.4' of github.com:Ch3LL/salt into merge-2018.3.4

        * 6d6910a Merge branch '2018.3' into merge-2018.3.4

      * b5a6265 Fix ruby gems tests, again

      * 05f2797 Merge branch '2018.3' into merge-2018.3.4

      * 9f0999f Merge branch '2018.3' into merge-2018.3.4

      * 139daa8 Merge branch '2018.3.4' into 2018.3

        * 9741289 Merge pull request `#51646`_ from dwoz/batch_exit_2018.3.4

          * a8f25bb increase batch test timeout on windows

                * 9caafec Skip solarisips when not on solaris

  * 31c6785 Merge pull request `#51714`_ from dwoz/gemstestagain_2018.3

    * fab74bb Fix ruby gems tests, again

  * 39aadfb Merge pull request `#51689`_ from gtmanfred/2018.3

    * 8c35d51 fix import

    * 6a55cfdf specify minimum version of shade module

  * a475b70 Merge pull request `#51469`_ from s0undt3ch/hotfix/fix-suse-locale-docker

    * 14f49b5 Don't prevent `get_locale` from working when running under docker

  * a59585d Merge pull request `#51671`_ from Ch3LL/merge-2018.3

    * 64322db Fix is_windows utils call

    * a5c8df0 Fix pylint

    * 547889b Merge branch '2017.7' into '2018.3'

      * bcc13db Merge pull request `#51562`_ from gilbrechbuhler/fix_rabbitmq_policy_change_check

        * ed2b1e1 Fix RabbitMQ policy definition update check

      * cafaa98 Merge pull request `#51648`_ from dwoz/increase_wait

        * e2377a9 Merge branch '2017.7' into increase_wait

      * e3d28d9 Merge pull request `#51643`_ from dwoz/batch_exit

        * 42d1d02 increase batch test timeout on windows

        * 7c2d7a4 Increase minion wait for slow boxes

      * b5ae53a Merge pull request `#51631`_ from Ch3LL/lint-2017

        * c0aa4dc Fix linter by ignoring async await check.

        * 396622c Merge branch '2017.7' into lint-2017

      * ba8d0ea Merge pull request `#51547`_ from s0undt3ch/2017.7

        * 8e009e0 Allow NOT to install pip dependencies

      * 30ce509 Merge pull request `#51182`_ from lmf-mx/darwin-plist-update

        * 4297c0d Merge branch '2017.7' into darwin-plist-update

      * 68ac07f Merge pull request `#51442`_ from dwoz/multi_master

        * 40cb4db Merge branch '2017.7' into multi_master

        * 2dc5171 Handle multi_master failover when daemonized

      * 8df083c Merge pull request `#51608`_ from dwoz/wait_minions_2017.7

        * c55359f fix linter

        * 4702e22 Wait for minions to be pingable before starting tests

          * 5afa0a1 Merge branch '2017.7' into darwin-plist-update

          * f46e8be Fix service name in minion plist

              * 1da9cd9 Fix pylint on 2017.7

      * 39122ca Merge pull request `#51589`_ from dwoz/script_fix_2017.7

        * 8697ce7 Disable pylint checks, only for 2017.7

        * e5972f5 Use the code directory instead of cwd for python path

  * b8764fd Merge pull request `#51680`_ from Ch3LL/bp-50336

    * 3502dbb states.gpg: fix missing existing keys; modules.gpg: fix set trust level command

* **PR** `#51734`_: (`s0undt3ch`_) [2019.2] Add initial nox configuration. Tell `tox`'ers to use `nox`'.
  @ *2019-02-21 17:39:29 UTC*

  * 1894082 Merge pull request `#51734`_ from s0undt3ch/features/nox-2019.2

  * 01b74c0 Add initial nox configuration. Tell `tox`'ers to use `nox`'.

* **PR** `#51707`_: (`isbm`_) Bugfix: pillar refresh
  @ *2019-02-21 15:12:49 UTC*

  * 74db589 Merge pull request `#51707`_ from isbm/isbm-pillar-refresh-fix

  * 269ae76 Refresh matchers and beacons on pillar refresh

* **PR** `#51674`_: (`Ch3LL`_) [2019.2] Merge forward from 2018.3 to 2019.2
  @ *2019-02-20 17:35:07 UTC*

  * 82cbd98 Merge pull request `#51674`_ from Ch3LL/merge-2019.2

  * 4171271 Fix pylint, remove unused import

  * 3f14619 Remove skipif and change expected return for solarisips test

  * d3660d5 Merge branch '2019.2' into merge-2019.2

* **PR** `#51715`_: (`dwoz`_) [2019.2] Fix ruby gems tests, again
  @ *2019-02-19 21:44:21 UTC*

  * 7a82c65 Merge pull request `#51715`_ from dwoz/gemstestagain_2019.2

  * 95ce288 Fix ruby gems tests, again

  * 043efa0 Skip solarisips when not on solaris

  * 7ed0d7d Fix ruby gems tests, again

  * b46eac3 Merge branch '2019.2' into merge-2019.2

* **PR** `#51561`_: (`isbm`_) SaltSSH: fix delay when creating thin TAR
  @ *2019-02-19 10:15:47 UTC*

  * 0bd2d6e Merge pull request `#51561`_ from isbm/isbm-saltssh-thintar-delay-fix

  * 2b02975 Give up on sync for Py3 because of the way tests for py2 are written here

  * f79c81a Update UT mocking, adjusting for temporary file

  * 2f90054 Use temporary filename instead of output directly to the "thin.tgz"

  * d841164 Copy over the result, cleanup afterwards

  * c6792ee Add a function that reserves temporary filename for further tarball generation

* **PR** `#51678`_: (`Ch3LL`_) [2019.2] Merge forward from 2019.2.0.rc1 to 2019.2
  @ *2019-02-17 19:02:33 UTC*

  * 5f9764a Merge pull request `#51678`_ from Ch3LL/merge-2019.2.0.rc

  * f8372ca Merge branch '2019.2' into merge-2019.2.0.rc

* **ISSUE** `#51503`_: (`garethhowell`_) smartos.image_present fails with "does not exist" (refs: `#51383`_)

* **ISSUE** `#51351`_: (`garethhowell`_) Exception using smartos.vm_present to create docker zone (refs: `#51383`_)

* **PR** `#51679`_: (`Ch3LL`_) Backport `#51383`_ into 2019.2
  @ *2019-02-16 00:31:06 UTC*

  * **PR** `#51383`_: (`sjorge`_) imgadm module should deal with invalid images better (refs: `#51679`_)

  * 2036c8a Merge pull request `#51679`_ from Ch3LL/bp-51383

  * e4971fc imgadm module should deal with invalid images better

  * 58f2407 Merge branch '2019.2.0.rc1' into 2019.2

    * 6292f86 Revert "Remove custom grains module from 2018.3 branch"

    * 92bd6b9 Fix salt.utils.is_windows call

    * ffa2f5f Merge branch '2018.3' into '2019.2'

    * a8898f6 Merge pull request `#51635`_ from lomeroe/lgpo_boolean_element_fix

      * b97c2b2 Merge branch '2018.3' into lgpo_boolean_element_fix

      * 5a98fb9 Merge branch '2018.3' into lgpo_boolean_element_fix

    * abd3760 Merge pull request `#51610`_ from garethgreenaway/51266_schedule_enable_disable_break_save

      * fbacb35 Merge branch '2018.3' into 51266_schedule_enable_disable_break_save

    * 6765eea Merge pull request `#51649`_ from dwoz/increase_wait_2018.3

      * 9c964ef Merge branch '2018.3' into increase_wait_2018.3

    * 852a6be Merge pull request `#51644`_ from dwoz/batch_exit_2018.3

      * 1087d10 increase batch test timeout on windows

      * 918030e Increase minion wait for slow boxes

      * 3d52b26 Merge branch '2018.3' into 51266_schedule_enable_disable_break_save

    * dadf414 Merge pull request `#51637`_ from twangboy/backport_50887_2018.3

      * d8d2b86 backport `#50887`_

    * a55e8f6 Merge pull request `#51626`_ from twangboy/fix_lgpo_2018.3

      * b2c9c3b Use makedirs instead of mkdir

          * 2be2f42 Merge branch '2018.3' into 51266_schedule_enable_disable_break_save

    * 0f1a411 Merge pull request `#51187`_ from menglong81/fix-broken-thing

      * 298ad5c Merge branch '2018.3' into fix-broken-thing

      * d879d18 fix broken network.py

      * 76770f3 ss command replace to netstat command

      * 241707e ss command replace to netstat command

            * deeefc7 Merge branch '2018.3' into 51266_schedule_enable_disable_break_save

    * 7ed5189 Merge pull request `#51613`_ from twangboy/fix_51566

      * 1206a94 Merge branch '2018.3' into fix_51566

    * 8b06d06 Merge pull request `#51630`_ from twangboy/add_tests_51534

      * ddc017c Merge branch '2018.3' into add_tests_51534

    * c4bbe1a Merge pull request `#51177`_ from nullify005/51069-ri-and-rdoc-removed

      * 6b1a201 Merge branch '2018.3' into 51069-ri-and-rdoc-removed

      * f339608 Merge branch '2018.3' into 51069-ri-and-rdoc-removed

      * e586370 Merge branch '2018.3' into 51069-ri-and-rdoc-removed

      * 13d3288 Fix lint issues

      * 5de5e64 Update tests

      * 22eda16 Fix lint violations

      * 2e6252c Support rubygems 3 cli param changes

              * 9e3a01b Use existing file instead of tzutil

              * 30c1832 Use tempfile to get temp dir

              * e3d3c5a Add tests for issue 51309

              * 1168141 Add test for explicit lists

              * 84f5d63 Merge branch '2018.3' into fix_51566

              * 7376cb9 Handle explicit lists properly

                    * 28fc070 Merge branch '2018.3' into 51266_schedule_enable_disable_break_save

                    * 0760133 adding integration.scheduler.test_helpers to various files to by pass the test_module_name_source_match check.

                    * 1552fba lint cleanup

                    * 086066b Adding a test to ensure _get_schedule which is used by the save functionality works when there is an enabled attribute.

                    * 1c6d4fb When looping through the schedule to remove hidden attributes, we should only do that if the item in question is a dictionary.  It could be the attribute that determines if the entire scheudle is enabled or disable.

                    * 5ed8eb6 Properly create the value for a "True" boolean element item

    * f1e29c8 Merge pull request `#51548`_ from s0undt3ch/2018.3

      * 611065e Merge branch '2018.3' into 2018.3

    * 00a6246 Merge pull request `#51622`_ from brejoc/2018.3-empty-job-workaround

      * d263410 Prevents crash when there is no job entry

      * 5342305 Allow NOT to install pip dependencies

    * fdb13a3 Merge pull request `#51523`_ from lomeroe/solarisips_fixes

      * e8e91e3 Merge branch '2018.3' into solarisips_fixes

      * b7bfe17 lint fixes

      * cdaccf4 add tests to validate command being sent to cmd.run_all

      * eaa229d add unit test

      * 432428d Don't assume that each item in "pkgs" is a dict (as packed by pkg.installed state).

    * e3d5fbe Merge pull request `#51577`_ from garethgreenaway/merge-2017.7

      * e060b97 Merge branch '2018.3' into merge-2017.7

      * 3eee038 Fixing a couple issues that did not merge properly.

      * 25b2ca6 Merge branch '2018.3' into merge-2017.7

      * c337fce Merge branch '2018.3' into merge-2017.7

      * f9d6828 Fixing missed merge.

      * a041775 Merge branch '2017.7' into merge-2017.7

        * 61889ba Merge pull request `#51452`_ from terminalmage/bp-50963

          * 54d2e02 Merge branch '2017.7' into bp-50963

        * 0c989f0 Merge pull request `#51437`_ from twangboy/fix_raise_2017.7

          * ecd1637 Merge branch '2017.7' into fix_raise_2017.7

          * f3c9cd4 Add missing raise statement

            * d06526c Allow for kwargs to be used in object initialization

            * 0e760b5 pip states: Use case-insensitive dictionaries for pip.list return

            * 5ca9f82 Add a CaseInsensitiveDict implementation

            * 2aaa9f9 pip.installed: Fix traceback when _find_key doesn't return a match

        * 67b7d28 Merge pull request `#51370`_ from dwoz/setup_py_req_fix

          * e1e06a0 Fix python 3 path for shell test cases

          * 09cd5fc Merge branch '2017.7' into setup_py_req_fix

          * 0de189d Handle pipenv like version restrictions

        * e9b3d94 Merge pull request `#51367`_ from dwoz/cloud_config_2017

          * 3f4c5a3e Merge branch 'cloud_config_2017' of github.com:dwoz/salt into cloud_config_2017

            * 8b8d41a Merge branch '2017.7' into cloud_config_2017

          * 7bb4ceb Fix python 3 path for shell test cases

          * a2bbf4d Fix linter issues

          * 004d9b8 Cloud provider and profile configs are merged

        * 3a21afa Coverage on windows chokes with the tox env var `COVERAGE_PROCESS_START`

        * 1c62e27 Switch required PyTest dependency

        * b80320d Merge pull request `#51402`_ from dwoz/win_test_fix

          * 21359e6 Merge branch '2017.7' into win_test_fix

        * 1199530 Merge pull request `#51397`_ from dwoz/gemstest

          * 43ac36e Use gems.github.com no longer exists, use gemcutter.org

          * bac652f Add testing path to run_script commands

        * f511ad2 Merge pull request `#51227`_ from astronouth7303/doc-modules-additional-globals

          * cbe1e17 Merge branch '2017.7' into doc-modules-additional-globals

        * 2a9bf17 Merge pull request `#51312`_ from s0undt3ch/features/tox-runtests

          * 3840af8 "Tell" coverage to track subprocesses.

          * f67a529 Remove unused imports

          * 15ab061 Show objects on assertion failure

          * 0281fc5 Don't fail the test because of order

          * 9a31be7 Don't call `.keys()` on dictionaries

          * 97ced3a Add `pytest-salt-from-filenames` to pytest requirements

          * 8d2c4d2 Remove duplicate dependency

          * 5eec144 Add `.coveragerc`

          * aa108d5 Run tests from tox, whether runtests or pytest

          * 80a3826 Update TODO

          * 1945c30 Document the client-defined dunders

    * 5bb9b32 Merge pull request `#51393`_ from garethgreenaway/various_documentation_fixes

      * 8bb7535 Merge branch '2018.3' into various_documentation_fixes

      * c15406a Merge branch '2018.3' into various_documentation_fixes

      * 33bb4e4 Merge branch '2018.3' into various_documentation_fixes

      * 3582f6e Fixing the underline.

      * a8f42a0 Various documentation fixes.

    * 884981f Merge pull request `#51465`_ from ezh/50556

      * a3ee70c fix `#50556`_ state.orchestrate_show_sls

    * 231d6e2 Merge pull request `#51541`_ from bdrung/silence-linux_distribution-deprecation-warning

      * c4feea1 Merge branch '2018.3' into silence-linux_distribution-deprecation-warning

      * e1dcbb5 Silence linux_distribution deprecation warning

    * f87d5ec Merge pull request `#51558`_ from bdrung/test-zypp-plugin

      * c34967d Merge branch '2018.3' into test-zypp-plugin

    * edb1093 Merge pull request `#51609`_ from dwoz/wait_minions_2018.3

      * d794edb fix linter

      * d6720d2 Wait for minions to be pingable before starting tests

    * 8d79359 Merge pull request `#51599`_ from terminalmage/bp-51510

      * ed194c7 grains: assign os_family Debian to Debian derivative TurnKey Linux

    * 24aa083 Merge pull request `#51598`_ from terminalmage/add-grain-option-documentation

      * 4ee9440 Improve ec2 pillar documentation

      * 9c02104 Add link to metadata grain module docs

      * 997ce26 Add documentation for the metadata_server_grains config option

    * d89c489 Merge pull request `#51491`_ from terminalmage/issue51268

      * 550e9ab Don't log shell warning if output_loglevel is quiet

          * 7678c28 Do not load zyppnotify file on module import

    * c6dfded Merge pull request `#51588`_ from dwoz/script_fix_2018.3

      * cbac390 Use the code directory instead of cwd for python path

* **PR** `#51658`_: (`dwoz`_) [2019.2] Let memcopy make the null bytes, better py3 support
  @ *2019-02-15 05:42:37 UTC*

  * **PR** `#51586`_: (`garethgreenaway`_) [2019.2] Merge forward from 2018.3 to 2019.2 (refs: `#51658`_)

  * 1ea6f4b Merge pull request `#51658`_ from dwoz/pip_test_fix

  * c811a70 Let memcopy make the null bytes, better py3 support

* **PR** `#51650`_: (`dwoz`_) [2019.2]  Increase minion wait for slow boxes
  @ *2019-02-14 16:31:59 UTC*

  * 22a04c1 Merge pull request `#51650`_ from dwoz/increase_wait_2019.2

  * ad294f3 Merge branch '2019.2' into increase_wait_2019.2

* **PR** `#51645`_: (`dwoz`_) [2019.2] increase batch test timeout on windows
  @ *2019-02-14 16:29:26 UTC*

  * a0982f7 Merge pull request `#51645`_ from dwoz/batch_exit_2019.2

  * 1a882d7 Merge branch '2019.2' into batch_exit_2019.2

* **PR** `#51586`_: (`garethgreenaway`_) [2019.2] Merge forward from 2018.3 to 2019.2 (refs: `#51658`_)
  @ *2019-02-14 16:25:29 UTC*

  * 705a62d Merge pull request `#51586`_ from garethgreenaway/merge-2018.3

  * 09fb3e7 Merge branch '2019.2' into merge-2018.3

  * 95c505a Merge branch '2019.2' into merge-2018.3

  * 4abd9d0 Merge branch '2019.2' into merge-2018.3

  * 6c99cb1 Merge branch '2018.3' into merge-2018.3

    * 41e25a6 Merge pull request `#51580`_ from garethgreenaway/merge-2018.3.4

      * 84e15ce Fixing lint

      * e891b3f Merge branch '2018.3.4' into merge-2018.3.4

      * d0cad3e Merge pull request `#51553`_ from twangboy/update_libsodium

        * 4177f64 Update url to libsodium for mac builds

      * 564a65a Merge pull request `#51544`_ from twangboy/fix_test_ssh_2018.3.4

        * 7771632 Fix ssh on Windows

      * b4299a3 Merge pull request `#51532`_ from frogunder/new_releasenotes

        * 09faf0b Merge branch '2018.3.4' into new_releasenotes

        * c6bfe53 2018.3.4 releasenotes

      * c37bdb7 Merge pull request `#51534`_ from twangboy/fix_51309

        * 3ad95bc Convert data to string using salt util

      * 5b41af3 Merge pull request `#51530`_ from garethgreenaway/48204_mysql_module_handle_mariadb_versions

        * cdf5298 Later versions of MariaDB still support "ALL PRIVILEGES"

        * d31c902 Updating the mysql module to handle MariDB versions.

      * f3f345c Merge pull request `#51529`_ from frogunder/releasenotes

        * fb678ee fix escaped asterisks

        * 6a4f0da 2018.3.4 releasenotes

      * a37fb7d Merge pull request `#51525`_ from twangboy/backport_51095_2018.3.4

        * b6acc92 Backport 51095

      * 602ddc8 Merge pull request `#51520`_ from frogunder/man_pages

        * 0cbe3f8 Update man pages for 2018.3.4

      * 1f981c6 Merge pull request `#51429`_ from yosnoop/replace-noclass-with-nocl-for-dig

        * 5231e73 Merge branch '2018.3.4' into replace-noclass-with-nocl-for-dig

        * 14e6fb7 In case the test machine can't resolve

        * 95e8a2f The +nocl is supported much wider than +noclass

        * a00d708 Test dig options for salt.utils.dns.lookup

      * 209ef32 Merge pull request `#51441`_ from Ch3LL/bp-51366

        * 5bc466e Fix python 3 path for shell test cases

        * 5351e5c Add testing path to run_script commands

        * 2d8a364 Fix linter issues

        * 9b8718a Cloud provider and profile configs are merged

      * 90a8682 Merge pull request `#51458`_ from twangboy/add_py2_warning

        * 05522c0 Merge branch '2018.3.4' into add_py2_warning

      * b492021 Merge pull request `#51460`_ from twangboy/update_installer_mac_2018.3.4

        * 3c92688 Merge branch '2018.3.4' into update_installer_mac_2018.3.4

      * 892d98c Merge pull request `#51471`_ from twangboy/fix_test_win_dns_client

        * c9f6b01 Merge branch '2018.3.4' into fix_test_win_dns_client

      * a05305d Merge pull request `#51462`_ from ShantonRU/fix-insecure-sql-queries-in-mysql-module-1

        * d3ef2cb Merge branch '2018.3.4' into fix-insecure-sql-queries-in-mysql-module-1

        * f47dda6 Fix improper use of socket authentication in mysql.user_chpass

        * ed62a2f Fix insecure SQL queries in mysql.user_chpass

          * 33922c9 Fix the failing dns test on Windows

      * 48936c2 Merge pull request `#51445`_ from terminalmage/fix-custom-grains-traceback

        * 191235d Remove custom grains module from 2018.3 branch

        * 72fd1a2 Roll back icon change

        * 7dd1704 Add welcome_py2.rtf

        * c93e9e3 Add Py2 Warning to installer package

        * b658900 Add Py2 Warning for Py2 Installer

      * a880e42 Merge pull request `#51438`_ from twangboy/fix_raise_2018.3.4

        * 5830fad Add missing raise statement

      * 28b898c Merge pull request `#51432`_ from Ch3LL/bp-51324

        * bd41ff0 Fixing various bits in x509 module and unit test to ensure tests are passing on python2 & python3

      * 01717d2 Merge pull request `#51377`_ from twangboy/fix_auditpol_2018.3.4

        * 19e5181 Fix issue when directory doesn't exist

      * 43a9d2f Merge pull request `#51338`_ from Ch3LL/bp-51207

        * 345ae67 Backport PR# 50771 to 2018.3 branch

      * 3dcd11d Merge pull request `#51337`_ from Ch3LL/bp-51170

        * 4e85505 Merge branch '2018.3.4' into bp-51170

      * 7656aa5 Merge pull request `#51340`_ from Ch3LL/bp-51252

        * e74a6c6 Fix py3 managed.file test failure

        * 6f2c7cf Remoe un-needed log statement

        * 824950c Fix 50221 regression test on Windows

        * 1840af9 peserve newlines from pillar data for file.managed

      * e90ca1d Merge pull request `#51290`_ from s0undt3ch/hotfix/fix-network

        * da3aace Merge branch '2018.3.4' into hotfix/fix-network

        * 04f16b8 Fix tests. We no longer get `ipaddress` instances back.

        * c3fa82a Fix minion start issue

          * c893dc4 Fix saltmod roster test

          * b61854f Roster defines the roster system not a file

          * 484bab4 Fix linter

          * 5e2db2f Honor roster file for ssh orchestrations

      * c8db7e3 Merge pull request `#51317`_ from terminalmage/fix-pr-50417

        * 4be2891 Merge branch '2018.3.4' into fix-pr-50417

      * e246fdb Merge pull request `#51311`_ from twangboy/fix_test_file.test_managed

        * f4177e0 Remove mode parameter on Windows

        * 4c4ded3 Fix regression in dynamic pillarenv

      * 40b20126 Merge pull request `#51292`_ from Ch3LL/bp-51226

        * aba114e Merge branch '2018.3.4' into bp-51226

      * fc0bec5 Merge pull request `#51295`_ from Ch3LL/bp-51279

        * 5c4a7a4 Merge branch '2018.3.4' into bp-51279

      * dacd1ea Merge pull request `#51293`_ from Ch3LL/bp-51233-2

        * a155fd7 Accounting for when permissions are not returned from file.check_perms, eg. windows systems.

        * 53ba068 When test=True and there are permissions changes, report it.

        * d2eba77 Remove network.py patch

        * d431c71 Add __context__ support

          * de6c13d Handle spaces in fstab opts, similar fix to `#39593`_

      * 1abffb2 Merge pull request `#51278`_ from dwoz/issue51248

        * c614198 Use pillar roots validation method

        * 0d2b0c6 Fix linter warnings

        * 5b98895 Fix wart in pillar_roots validation

    * f7d50b1 Merge pull request `#50784`_ from sathieu/dynamic_file_roots

      * 7ca2aa4 Allow dynamic file_roots

    * 5e840a5 Merge pull request `#51527`_ from garethgreenaway/bp-51475

      * 801abf2 Fix Elasticsearch retuner

    * 1f6da6a Merge pull request `#50921`_ from terminalmage/issue49894

      * a35c023 Don't use a decorator that assumes /etc/apt/sources.list.d exists

      * 6a62e79 Add integration test for architecture support

      * 67ae5a5 Add support for architectures for APT pkgrepo.managed states

    * 3f17776 Actually, remove python-ldap. It needs system deps. Have salt-jenkins do it.

    * afcb6bd Fix the `ldap` package name in requirements/tests.txt

    * 588cb87 Merge pull request `#51454`_ from terminalmage/fix-deprecation-warning

      * 529cce0 Fix deprecation warning in nested outputter

    * 13de0b8 Merge pull request `#50963`_ from terminalmage/issue50942

      * c84be3f Allow for kwargs to be used in object initialization

      * 2bf93fd pip states: Use case-insensitive dictionaries for pip.list return

      * 792f054 Add a CaseInsensitiveDict implementation

      * 1410164 pip.installed: Fix traceback when _find_key doesn't return a match

    * 60953b7 Merge pull request `#51366`_ from dwoz/cloud_config_merge

      * ae351eb Fix python 3 path for shell test cases

      * 48062c8 Merge branch '2018.3' into cloud_config_merge

      * eeea289 Add testing path to run_script commands

      * 542d857 Fix linter issues

      * a8af3ba Cloud provider and profile configs are merged

    * 9ab2ec6 Coverage on windows chokes with the tox env var `COVERAGE_PROCESS_START`

    * 4994c38 Switch required PyTest dependency

    * 89710a7 Merge pull request `#51401`_ from dwoz/run_script_win

      * 77fdf35 Add testing path to run_script commands

    * 1438a62 Merge pull request `#51389`_ from terminalmage/proxy-fixes

      * 3cec85e Normalize results if test proxy is enabled

    * 8acd9e5 Merge pull request `#51368`_ from s0undt3ch/hotfix/tests

      * f4e1692 Fix test

    * ab60782 Merge pull request `#51319`_ from terminalmage/issue51255

      * 04eb66b Merge branch '2018.3' into issue51255

    * fdf2cf4 Merge pull request `#51250`_ from yosnoop/fix-salt-utils-dns-lookup

      * 0ddfad1 Merge branch '2018.3' into fix-salt-utils-dns-lookup

      * 9fb4abe Merge branch '2018.3' into fix-salt-utils-dns-lookup

      * 67e4131 Merge branch '2018.3' into fix-salt-utils-dns-lookup

      * 9a34bcd Unit test for lookup with servers option

      * 9498fdc Fix _lookup_host to make it work when server specified

      * af867e1 Remove excessive whitespaces

      * 0d074a4 Fix a comment

      * 1363d2b Proper way to specify _server_ to query with _host_

      * 7b2facc Fix broken lookup in salt/utils/dns.py

    * 73528a5 Merge pull request `#51339`_ from dwoz/aws_role_backport

      * 156f532 Backport aws role support

    * 7908875 Merge pull request `#51341`_ from Ch3LL/bp-51299

      * e3080f1 Add sleep before sending stop over UDP

    * 326425c Merge pull request `#51352`_ from garethgreenaway/fixing_service_beacon_documentation

      * 021fe85 Fixing the documentation for the service beacon.  If not options are provided for the service then there needs to be an empty dictionary.

    * 14a84e8 Merge pull request `#51333`_ from Ch3LL/merge-2018.3

      * 27d7a89 Merge branch '2018.3' into merge-2018.3

    * 31b921f Merge pull request `#51304`_ from terminalmage/issue51270

      * 36673fb Merge branch '2018.3' into issue51270

    * 2c3aef7 Merge pull request `#51313`_ from s0undt3ch/features/tox-runtests-2018.3

      * 2eafc5c "Tell" coverage to track subprocesses.

      * f6babeb Remove unused imports

      * ff6824c Don't fail the test because of order

      * 4d12ccb Show objects on assertion failure

      * ee2f10a Add `pytest-salt-from-filenames` to pytest requirements

      * 4f4d019 Remove duplicate dependency

      * 1d4b9f5 Add `.coveragerc`

      * 78c6d68 Run tests from tox, whether runtests or pytest

      * c02757d gitfs: Fix use of deprecated pygit2 function

        * ae62ebc Merge branch '2017.7' into '2018.3'

        * 9309639 Merge pull request `#51305`_ from s0undt3ch/2017.7

          * 09b20df Add 2017.7 codecov config

        * 4fa2a02 Merge pull request `#51267`_ from ethframe/fix-file-directory

          * c108825 Fix missing file error in file.directory.

              * ad17ac5 Fix mocks to reflect changes to git.latest state

              * c817213 Don't try to run git.config_get_regexp from nonexistent cwd

              * f8c3e44 git.latest: add auth to merge/reset calls when LFS used with SSH auth

                    * 4b11d6b increase batch test timeout on windows

                    * a5af9c5 Increase minion wait for slow boxes

* **PR** `#51549`_: (`s0undt3ch`_) [2019.2] Allow NOT to install pip dependencies
  @ *2019-02-13 18:16:52 UTC*

  * e7ee04e Merge pull request `#51549`_ from s0undt3ch/2019.2

  * d2125aa Allow NOT to install pip dependencies

* **PR** `#51595`_: (`mirceaulinic`_) Fix ipaddress imports
  @ *2019-02-13 17:33:08 UTC*

  * c96464b Merge pull request `#51595`_ from mirceaulinic/mircea/port-824e0e5

  * 91bcb4f Merge branch '2019.2' into mircea/port-824e0e5

  * 84fc76d Fix ipaddress imports

* **PR** `#51517`_: (`damianosSemmle`_) Fixed string format index out of range error
  @ *2019-02-13 08:18:38 UTC*

  * e3c9a3e Merge pull request `#51517`_ from damianosSemmle/fix-string-format-index

  * c0959e2 Merge branch '2019.2' into fix-string-format-index

* **PR** `#51581`_: (`garethgreenaway`_) [2019.2] Merge forward from 2019.2.0rc1 to 2019.2
  @ *2019-02-13 04:11:15 UTC*

  * 82500bb Merge pull request `#51581`_ from garethgreenaway/merge-2019.2.0rc1

  * b00e7e8 Merge branch '2019.2' into merge-2019.2.0rc1

* **PR** `#51607`_: (`dwoz`_) [2019.2]  Wait for minions to be pingable before starting tests
  @ *2019-02-13 00:48:47 UTC*

  * edb5e94 Merge pull request `#51607`_ from dwoz/wait_minions_2019.2

  * ab0a6a3 fix linter

  * f2e4a30 Wait for minions to be pingable before starting tests

* **PR** `#51584`_: (`dwoz`_) [2019.2] Use the code directory instead of cwd for python path
  @ *2019-02-12 18:43:46 UTC*

  * 1e0275e Merge pull request `#51584`_ from dwoz/script_fixes

  * dbf4356 Use the code directory instead of cwd for python path

  * cd24006 Merge branch '2019.2' into merge-2019.2.0rc1

  * 6e55164 Merge branch '2019.2.0.rc1' into merge-2019.2.0rc1

    * ac73745 Merge branch '2019.2' into fix-string-format-index

* **PR** `#51583`_: (`dwoz`_) Add testing path to run_script commands
  @ *2019-02-11 21:38:51 UTC*

  * f446c52 Merge pull request `#51583`_ from dwoz/scriptfix

  * e49ba86 Add testing path to run_script commands

  * 788f7e0 Fixed string format index out of range error

* **PR** `#51405`_: (`aplanas`_) Documentation: fix typo in "equivalent"
  @ *2019-02-01 21:11:12 UTC*

  * c3e27be Merge pull request `#51405`_ from aplanas/backport_49669

  * 58279b4 Documentation: fix typo in "equivalent"

* **PR** `#51406`_: (`aplanas`_) states_pt3: fix rST link format
  @ *2019-02-01 21:10:43 UTC*

  * 5c26652 Merge pull request `#51406`_ from aplanas/backport_49670

  * 204432d Merge branch '2019.2' into backport_49670

* **PR** `#51426`_: (`aplanas`_) mount: cache blkid information
  @ *2019-02-01 21:09:51 UTC*

  * fb70bd3 Merge pull request `#51426`_ from aplanas/backport_51135

  * ac790a6 Merge branch '2019.2' into backport_51135

  * 66743d6 mount: cache blkid information

* **PR** `#51425`_: (`aplanas`_) cmdmod: add sysfs into the chroot
  @ *2019-02-01 21:09:00 UTC*

  * 2e8bf05 Merge pull request `#51425`_ from aplanas/backport_51094

  * 9193106 cmdmod: add sysfs into the chroot

* **PR** `#51419`_: (`aplanas`_) file: update attributes for lsattr and chattr
  @ *2019-02-01 21:04:54 UTC*

  * d7a47f0 Merge pull request `#51419`_ from aplanas/backport_50607

  * ab8a8b8 file: update attributes for lsattr and chattr

* **PR** `#51414`_: (`aplanas`_) service: SUSE is not based on sysvinit anymore
  @ *2019-02-01 21:02:33 UTC*

  * 7e020dd Merge pull request `#51414`_ from aplanas/backport_50396

  * b5cff17 service: SUSE is not based on sysvinit anymore

* **PR** `#51408`_: (`aplanas`_) parted: fix the ordering of list command
  @ *2019-02-01 21:00:19 UTC*

  * **PR** `#50473`_: (`aplanas`_) parted: support variable length output for print (refs: `#51408`_)

  * **PR** `#49804`_: (`aplanas`_) parted: fix the ordering of list command (refs: `#51408`_)

  * 9f87dda Merge pull request `#51408`_ from aplanas/backport_49804

  * 467daf2 parted: support variable length output for print

  * da2e632 parted: fix the ordering of list command

* **ISSUE** `#50097`_: (`aplanas`_) lowpkg.diff refers to a package name, but a package file is required (refs: `#51410`_)

* **PR** `#51410`_: (`aplanas`_) Fix lowpkg.diff documentation and parameter name
  @ *2019-02-01 20:57:50 UTC*

  * 7e14499 Merge pull request `#51410`_ from aplanas/backport_50126

  * d38622e Fix lowpkg.diff documentation and parameter name

    * e61a077 states_pt3: fix rST link format

* **PR** `#51404`_: (`aplanas`_) blockdev: fix url from comment
  @ *2019-01-30 20:05:54 UTC*

  * a16461b Merge pull request `#51404`_ from aplanas/backport_49668

  * da2e30d blockdev: fix url from comment

* **PR** `#51407`_: (`aplanas`_) parted: fix _validate_partition_boundary
  @ *2019-01-30 20:05:02 UTC*

  * 756c367 Merge pull request `#51407`_ from aplanas/backport_49803

  * b004b33 parted: fix _validate_partition_boundary

* **PR** `#51435`_: (`damianosSemmle`_) Fixed not raised exceptions
  @ *2019-01-30 18:32:57 UTC*

  * 1d45664 Merge pull request `#51435`_ from damianosSemmle/fix-raise-exception

  * 7a9ff59 Fixed not raised exceptions

* **PR** `#51336`_: (`Ch3LL`_) [2019.2] Merge Forward from 2019.2.0.rc1 to 2019.2
  @ *2019-01-27 23:55:08 UTC*

  * d4b9093 Merge pull request `#51336`_ from Ch3LL/merge-2019.2.0rc1

  * 62a20b1 Remove unused import

  * 2284ea5 Merge branch '2019.2' into merge-2019.2.0rc1

  * 18bf236 Merge branch '2019.2.0.rc1' into 2019.2

* **PR** `#51334`_: (`Ch3LL`_) [2019.2] Merge forward from 2018.3 to 2019.2
  @ *2019-01-27 23:49:32 UTC*

  * 02b43a0 Merge pull request `#51334`_ from Ch3LL/merge-2019.2

  * 25ec653 Merge branch '2018.3' into '2019.2'

    * f62cc11 Merge pull request `#51324`_ from garethgreenaway/1257_something_something_bytes_argh_python2

      * bd7072f Merge branch '2018.3' into 1257_something_something_bytes_argh_python2

    * b44cd84 Merge pull request `#51323`_ from garethgreenaway/network_dns_check_test

      * 055eadc Merge branch '2018.3' into network_dns_check_test

    * be57a0f Merge pull request `#51321`_ from terminalmage/issue51256

      * d9c4462 Fix 500 error when using wheel_async

      * c847f54 Swap passed addr for string rather than ipaddress object.

      * 87f3972 removing another debugging log.

      * ad64efb Use MagicMock

      * 172ad2e removing debugging

      * 5812eae Adding a test to ensure dns_check works as expected.

      * 0e542c5 Fixing various bits in x509 module and unit test to ensure tests are passing on python2 & python3

    * 85e7ac6 Merge pull request `#51306`_ from s0undt3ch/2018.3

      * 5f0f296 Add 2018.3 codecov config

    * 5a398a3 Merge pull request `#51207`_ from twangboy/fix_test_pkg

      * d4ab6d8 Merge branch '2018.3' into fix_test_pkg

    * 7a97cb4 Merge pull request `#51252`_ from dwoz/issue-50221

      * f96828a Merge branch '2018.3' into issue-50221

    * 253f5e4 Merge pull request `#51264`_ from gtmanfred/2018.3

      * f3ebd32 Merge branch '2018.3' into 2018.3

    * aacc047 Merge pull request `#51274`_ from twangboy/fix_network

      * 344bf65 Fix tests. We no longer get `ipaddress` instances back.

      * 345aa5b Fix minion start issue

        * f553be7 tuples don't have pop

        * 55ea80e don't shadow builtin

        * 6148c50 an argument is not always needed to be passed to open a file

    * 8a89cb2 Merge pull request `#51279`_ from twangboy/backport_lgpo

      * 06b1545 Remove network.py patch

      * 2356f25 Add __context__ support

        * a5255f0 Merge remote-tracking branch 'saltstack/2018.3' into issue-50221

    * 6796e65 Merge pull request `#51276`_ from garethgreenaway/merge-2018.3

      * 44ddc43 Merge branch '2018.3' into merge-2018.3

    * 0adde9b Merge pull request `#51220`_ from sathieu/artifactory-classifier-2018.3

      * a85f146 fixes `#31179`_ by appling the same logic as used in the nexus module

    * f6a7cad Merge pull request `#51225`_ from astronouth7303/loader-docs-2018.3

      * 6e7da95 Add the tokens system.

      * 7e2838c Add reference to the execution module docs

      * f30f9e8 Remove search system

      * f0cc183 Fileserver modules can be loaded from the fileserver.

    * 1a2f680 Merge pull request `#51239`_ from garethgreenaway/51208_file_manage_escaped_double_quotes

      * 4251c0c Merge branch '2018.3' into 51208_file_manage_escaped_double_quotes

      * 6a9daa7 Merge branch '2018.3' into 51208_file_manage_escaped_double_quotes

      * 0bf468c Fixing lint.  Using a constant instead of looking for the condition in the string.

      * a233dbc Ensuring we can handle a string that contains single quote + an escaped double quote.

    * d614127 Merge pull request `#51261`_ from OrangeDog/patch-2

      * d809b9b Avoid double-counting errors and ignore test runs

      * 6ca7deb Remove unused host parameter and average/disaster keys

      * 2d44527 Just let zabbix_sender use the config file

      * 6404e2c Fix fallback command so it's actually run

      * b79a55a Fix KeyError in Zabbix returner

                  * 0971035 Merge branch '2018.3' into merge-2018.3

                  * 243dc06 Merge branch '2017.7' into merge-2018.3

                    * acfb7d8 Update pytest requirements

                    * c19479b Move all of PyTest requirements to its own requiremnts file

                    * 39e633f Merge pull request `#51246`_ from garethgreenaway/bp-50358

                      * c33c558 Backport `#50358`_ to 2017.7

                      * c1ea10f Fix py3 managed.file test failure

                      * 537114c Remoe un-needed log statement

                      * ac978f0 Fix 50221 regression test on Windows

                      * 65f38b5 peserve newlines from pillar data for file.managed

                      * 464d813 Merge branch '2018.3' into fix_test_pkg

    * 276d621 Merge pull request `#51197`_ from Ch3LL/tag_manager

      * b9a0705 Merge branch '2018.3' into tag_manager

      * 210238b Merge branch '2018.3' into tag_manager

      * 827d6c3 Merge branch '2018.3' into tag_manager

      * fcdfe69 Add Google Tag Manager to Docs

    * c8e70a9 Merge pull request `#51206`_ from terminalmage/fix-reload

      * 8e23a6c Add missing import

      * 31ca7c6 Fix usage of reload for PY3 compatibility

    * 41ae390 Merge pull request `#51231`_ from terminalmage/issue51056

      * 4a61477 Clarify documentation for the the gitfs "all_saltenvs" config param

                      * 0574476 Merge branch '2018.3' into fix_test_pkg

                      * b91b2c6 Backport PR# 50771 to 2018.3 branch

* **PR** `#51314`_: (`s0undt3ch`_) [2019.2] Allow running runtests.py using tox
  @ *2019-01-25 18:56:01 UTC*

  * 95607d1 Merge pull request `#51314`_ from s0undt3ch/features/tox-runtests-2019.2

  * 39fb981 "Tell" coverage to track subprocesses.

  * f27589a Remove unused imports

  * 3000d20 Fix tests. We no longer get `ipaddress` instances back.

  * 8fcf235 Fix minion start issue

  * a26ba7f Don't fail the test because of order

  * 138ca2e Show objects on assertion failure

  * 840b3d2 Add `pytest-salt-from-filenames` to pytest requirements

  * 716bda4 Remove duplicate dependency

  * 6d62156 Add `.coveragerc`

  * 6bb56ce Run tests from tox, whether runtests or pytest

* **PR** `#51307`_: (`s0undt3ch`_) Add 2019.2 codecov config
  @ *2019-01-24 13:34:25 UTC*

  * b348034 Merge pull request `#51307`_ from s0undt3ch/2019.2

  * 495aa5c Add 2019.2 codecov config

* **PR** `#51280`_: (`garethgreenaway`_) [2019.2] Merge forward from 2019.2.0rc1 to 2019.2
  @ *2019-01-23 07:08:32 UTC*

  * d224096 Merge pull request `#51280`_ from garethgreenaway/merge-2019.2-rc

  * e78ede2 Merge branch '2019.2' into merge-2019.2-rc

  * a425de6 Merge branch '2019.2.0.rc1' into merge-2019.2-rc

* **PR** `#51277`_: (`garethgreenaway`_) [2019.2] Merge forward from 2018.3 to 2019.2
  @ *2019-01-23 07:01:29 UTC*

  * 8596ee4 Merge pull request `#51277`_ from garethgreenaway/merge-2019.2

  * f05e754 Merge branch '2019.2' into merge-2019.2

* **ISSUE** `#51273`_: (`isbm`_) How to properly fix API? (refs: `#51285`_)

* **PR** `#51285`_: (`garethgreenaway`_) [2019.2] Add metadata to accepted keyword arguments
  @ *2019-01-22 23:07:44 UTC*

  * 8cca51b Merge pull request `#51285`_ from garethgreenaway/51273_metadata_auth_keyword_argument

  * bd82d80 Ensure metadata is an accepted keyword argument for authentication functions.

  * d0d5726 Merge branch '2018.3' into merge-2019.2

  * a6a9040 Merge pull request `#51179`_ from terminalmage/fix-regex-chars

    * 9951b8d Fix possible oversight in nodegroup modifications

  * d5acd5b Merge pull request `#51170`_ from dwoz/issue51158

    * b69c002 Fix saltmod roster test

    * 2594f24 Roster defines the roster system not a file

    * 05836b3 Merge branch '2018.3' into issue51158

    * bf47f6f Fix linter

    * 6223596 Honor roster file for ssh orchestrations

  * 5543a53 Update pytest requirements

  * f958df5 Move all of PyTest requirements to its own requiremnts file

  * 8f8ebbc Merge pull request `#51226`_ from garethgreenaway/51195_handle_spaces_in_fstab_opts

    * 1902ce8 Merge branch '2018.3' into 51195_handle_spaces_in_fstab_opts

  * e3a9e99 Merge pull request `#51233`_ from Ch3LL/bp-51105

    * eef49e8 Merge branch '2018.3' into bp-51105

  * e53e9b1 Merge pull request `#51230`_ from Ch3LL/merge-2018.3

    * 0ef7675 Merge branch '2017.7' into '2018.3'

    * 4a12c5f Merge pull request `#50852`_ from mirceaulinic/fix-capirca

      * fa91267 Merge branch '2017.7' into fix-capirca

      * 71913ff Merge branch '2017.7' into fix-capirca

      * 6fc3484 Lint?

      * 3d56750 Extra newline for lint

      * 5176cd8 Improve the Capirca and related modules for ACL config generation

    * 3f4759b Merge pull request `#50923`_ from astronouth7303/patch-2

      * 4f631a6 Document {% include %}

    * 210e817 Merge pull request `#51111`_ from s0undt3ch/2017.7

      * 08e0ae7 Update to salt-bootstrap v2019.01.08

        * c3520aa Accounting for when permissions are not returned from file.check_perms, eg. windows systems.

        * cd80548 When test=True and there are permissions changes, report it.

        * 89345eb Handle spaces in fstab opts, similar fix to `#39593`_

* **ISSUE** `#50538`_: (`sjorge`_) salt.modules.pdbedit broken on Samba 4.9.x (refs: `#50540`_, `#51221`_)

* **PR** `#51221`_: (`Ch3LL`_) Backport `#50538`_ into 2019.2
  @ *2019-01-18 22:42:36 UTC*

  * **PR** `#50540`_: (`sjorge`_) Fix pdbedit module on samba 4.9 (Fixes `#50538`_)

  * 0ccd5c3 Merge pull request `#51221`_ from Ch3LL/bp-50540

  * 223e7c0 Merge branch '2019.2' into bp-50540

* **PR** `#51232`_: (`Ch3LL`_) [2019.2] Merge forward from 2018.3 to 2019.2
  @ *2019-01-18 20:51:37 UTC*

  * 3edaf18 Merge pull request `#51232`_ from Ch3LL/merge-2019.2

  * 3b966f3 Merge branch '2019.2' into merge-2019.2

  * ffe23fa Merge branch '2018.3' into '2019.2'

    * 26008ef Merge pull request `#51212`_ from sathieu/file_roots_slash

      * b769f18 Allow slash in file_roots envs

      * f9437e2 Test for file_roots envs with slash leads to "No such file or directory"

    * 5916282 Merge pull request `#51209`_ from garethgreenaway/bp-51124

      * 82acce4 Handle encoding when opening file for both py2/py3

    * 094bd33 Merge pull request `#51184`_ from twangboy/fix_auditpol

      * 2e68d35 directly call cmd.run_all

    * ac71922 Merge pull request `#51191`_ from Ch3LL/bp-50918

      * 7300d84 Skip debian tests on Windows

      * 4622433 Fix `test_debian_ip` on Windows

    * e7f53a3 Merge pull request `#51144`_ from jgleissner/2018.3-azurearm-py3

      * 3178f1a msazure.py: remove unused imports

      * 99a4b9d azurearm: fix list_locations

      * aebe34b azurearm: fix show_instance function

      * d80669f msazure: fix object_to_dict for python 3

    * 1206f92 Merge pull request `#51171`_ from twangboy/fix_crypt

      * 6caa93b Add random sleep time to avoid overloading Windows

    * a96deed Merge pull request `#51174`_ from jpsv/2018.3

      * 055823e Update opsgenie.py

      * 501c8df Merge branch '2018.3' into 2018.3

      * 220aa8a Update opsgenie.py

      * 5dc21cc Update to from V1 API to V2

      * f93ce7c Update to V2 API

    * 563d487 Merge pull request `#51010`_ from amendlik/ldap-groups

      * cd336ed Merge branch '2018.3' into ldap-groups

      * 94f8ee4 Update unit tests for auth.ldap

      * 08e36d0 Allow unauthenticated bind for listing LDAP groups

    * 6dc3752 Merge pull request `#51112`_ from s0undt3ch/2018.3

      * 4f1d846 Update to salt-bootstrap v2019.01.08

    * b19c990 Merge pull request `#51097`_ from terminalmage/fix-keyerror-raise

      * a3c0b49 Fix poorly-written test

      * c0ff7b1 Fix more incorrect exception raises

      * f11dbcc Fix improper KeyError raise

    * 8920a86 Merge pull request `#51169`_ from twangboy/fix_git_state

      * f2d1180 More descriptive error when missing GitPython or PyGit2

    * 58eede6 Merge pull request `#51173`_ from dwoz/issue51160

      * 11cc7b3 Remove un-needed test

      * 0f87812 Merge develop, Revert exception handling

      * 7365a1a Pass bytes to idna

    * 83c38c6 Revert "wordsmithing"

    * a40739c wordsmithing

    * b348ace Make sure blackout tests clean up after themselves. Properly.

    * 68a12d5 These should not be considered destructive tests

    * 475404d fix docstring quote style

    * 71c3574 Revert "backport test improvements from develop"

    * e32d219 backport test improvements from develop Bogus random test failures forklifted from develop at 414bfe61a4fbe6f84be32242924f23c7126c24d6

    * 42654d8 socket.connect needs a tuple TypeError https://docs.python.org/2/library/socket.html RTFD "Note This method has historically accepted a pair of parameters for AF_INET addresses instead of only a tuple. This was never intentional and is no longer available in Python 2.0 and later. "

    * 27254fc syntax error bad parentheses

    * 24bb94f Don't ip_bracket addresses returned by check_dns.

    * 02b825e expose error in tests

    * 0a92c46 Need more detail on test failure

    * 3574698 ip_address does not need str() and parse_host_port handles ipv6 or ipv4

    * 7a6bc57 avoid TypeError by not constructing an ip_address from an ip_address

    * 35410dd try to debug error in tests (revert me)

    * 2f8ca47 wordsmithing

    * 1dd1f7d parsing logic error

    * 98041c1 minimize diff

    * c92a247 don't try to handle/log test exception

    * eb60586 remove bad extra test assertion inside exception handler

    * e1e5d87 checking for truthiness better than len

    * a984a43 typo in ipaddress.IPv6Address()

    * 5fc6c60 clear up lint, disambiguation

    * 8c6dfea lint pep8 whitespace

    * f9594b8 don't test invalid combination

    * de823fd fix good_host_ports iteration

    * c5a5b34 test assertion correction

    * e169e0d fixup rebase merge goof

    * d28bab6 fix test setup

    * 42c710e lint pep8

    * 15c6deb fix horrible mistakes

    * c092baf fix indentation doh

    * 9080745 debug ipaddress.ip_address TypeError

    * 8bd82f4 debug ipaddress.ip_address TypeError

    * 080ab70 fix parse_host_port() parse error on hostname only arg

    * 571603c coverage for master host:port ipv4 and ipv6 config value support fix test_parse_host_port bad values lint

    * f14ff16 fix minion zmq connecting to master configured as IPv6 address

    * 9d72f13 pylint E741 triggers error in salt-pylint E8741 (unhandled)

    * 2052838 avoid error on (redundant) is_ip check

    * 0eaeb1e avoid error on (redundant) is_ip check

    * f8bd08e fix parse_host_port() is_ip call

    * 89519fe fix parse_host_port() parse error on hostname only arg

    * 1417528 fix parse_host_port() bad exception on hostname only arg

    * 194a024 coverage for master host:port ipv4 and ipv6 config value support fix test_parse_host_port bad values lint

    * df73388 fix minion zmq connecting to master configured as IPv6 address

    * 06854cf Merge pull request `#51147`_ from Ch3LL/merge-2018.3

      * d39d8b7 Merge branch '2018.3' into merge-2018.3

    * b79c09e Merge pull request `#51161`_ from amendlik/long-hostname

      * 6fcc4ad Merge branch '2018.3' into long-hostname

    * 1424734 Merge pull request `#51159`_ from rkrieger/fix-issue-51067

      * 1440ccf Prevent crash by testing for 'manufacturer' in osdata on OpenBSD

      * 1a4e307 Ignore exceptions when generating the minion ID

    * 5e37326 Merge pull request `#51146`_ from terminalmage/fix-vsphere-tuple-issue

      * 5d60022 Fix invalid assignment in vsphere module

    * fad8621 Merge pull request `#51154`_ from twangboy/auditpol

      * 9064376 Add support for Advanced Audit policies

    * f7a100c Merge pull request `#51151`_ from Ch3LL/bp_51061

      * ffdae27 When writing output to stdout we want to ensure that the data is a string not bytes.  Under py2 the salt.utils.data.encode function results in a string but under py3 the result is a bytestring.  Swapping out salt.utils.data.encode for salt.utils.stringutils.to_str.

    * 3a50a57 Merge pull request `#51150`_ from Ch3LL/bp-49508

      * 7ae53ad Do not silently ignore errors.

      * deb0134 Convert to string before sending via 'publish'.

      * 651c551 Use to_str salt.utils when writing to a file.

    * 8bb589d Merge pull request `#51152`_ from garethgreenaway/50433_handle_grants_better

      * f7caa4d Fixing lint

      * e8c8c0f Adding some tests to ensure "ALL PRIVILEGES" is handled correctly in 8.0 and 5.6

      * b4bfd9f Add additional grants.  Adding logic to handle when ALL or ALL PRIVILEGES is passed for the grant, including some logic to handle the fact that the grants are split when show grants is run for a particular user.

        * 74edfd9 Fix pylint

        * 81a3d47 Merge branch '2017.7' into '2018.3'

        * 8a76a19 Merge pull request `#50858`_ from jasonarewhy/bugfix-2017.7/ubuntu-networking-searchdomain

          * 3395a3d Merge branch '2017.7' into bugfix-2017.7/ubuntu-networking-searchdomain

          * 69d25aa update debian_ip test

          * a6b896c get searchdomain in Ubuntu 12+

    * dda1ebb Merge pull request `#51133`_ from 5uper5hoot/issue-`#50849`_

      * ec14e13 Fixes mysql server version comparison.

    * 9d4321d Merge pull request `#50878`_ from max-arnold/output-docs

      * d7403da Fix profile outputter docs

    * ce87504 Merge pull request `#51076`_ from OrangeDog/patch-1

      * 568e4fb Revert add -> check

      * 4d7ebe7 Typos in index_template_present documentation

    * d08abf4 Merge pull request `#51081`_ from garethgreenaway/merge-2018.3

      * 027804a Merge branch '2018.3' into merge-2018.3

    * 335088b Merge pull request `#51080`_ from garethgreenaway/50966_nxos_ensure_kwargs_list

    * 230a66b Merge branch '2018.3' into 50966_nxos_ensure_kwargs_list

    * 629dc25 Ensure kwargs is a list before we attempt to loop through.  Similar fix to https://github.com/rallytime/salt/commit/430c462f34eb4eedf2384e06fbee8dc19b8026f6 in the proxy module.

    * a20791b Merge branch '2018.3' into merge-2018.3

    * 9386aab Merge branch '2017.7' into merge-2018.3

    * 998feca Merge pull request `#51030`_ from terminalmage/issue38502

    * 6dbd81f Add unit test to ensure we don't diff bare repos

    * 3c4b243 Merge branch '2019.2' into bp-50540

* **PR** `#51234`_: (`KChandrashekhar`_) Added a note in Release notes about py 2.7 EOL
  @ *2019-01-18 15:53:51 UTC*

  * e6ab913 Merge pull request `#51234`_ from KChandrashekhar/2019.2-docs

  * e4afc81 Addressing Megan's comment to fix the py2.7 deprecation message in release notes

  * 8ec0296 Added a note in Release notes about py 2.7 EOL

* **PR** `#51198`_: (`Ch3LL`_) [2019.2] Merge forward from 2019.2.0.rc1 to 2019.2
  @ *2019-01-17 21:23:34 UTC*

  * 644ef8c Merge pull request `#51198`_ from Ch3LL/merge-2019.2-rc

  * 810c611 Merge branch '2019.2.0.rc1' into 2019.2

  * 3f61e77 Fix pdbedit module on samba 4.9 (Fixes `#50538`_)

* **PR** `#51148`_: (`Ch3LL`_) [2019.2] Merge forward from 2018.3 to 2019.2
  @ *2019-01-14 22:49:02 UTC*

  * 12901c3 Merge pull request `#51148`_ from Ch3LL/merge-2019.2

  * 1d7329a Fix pylint

  * 5271636 Fixes mysql server version comparison.

  * b53f171 Ensure kwargs is a list before we attempt to loop through.  Similar fix to https://github.com/rallytime/salt/commit/430c462f34eb4eedf2384e06fbee8dc19b8026f6 in the proxy module.

  * d0f2d15 Revert add -> check

  * 437d8b5 Typos in index_template_present documentation

  * 3bf189e Add unit test to ensure we don't diff bare repos

  * 2f8e391 Fix profile outputter docs

* **PR** `#51100`_: (`dwoz`_) Fix typo in method name (2019.2)
  @ *2019-01-08 18:12:23 UTC*

  * 4c2d76d Merge pull request `#51100`_ from dwoz/cloud_typo

  * 60f53d0 Fix typo in method name

* **PR** `#51099`_: (`terminalmage`_) Fix improper exception raises (2019.2)
  @ *2019-01-08 17:55:53 UTC*

  * 39b28f4 Merge pull request `#51099`_ from terminalmage/fix-exception-raise

  * 2a25530 Fix improper exception raise

* **PR** `#51084`_: (`s0undt3ch`_) [fluorine] Cleanup the singleton instances map.
  @ *2019-01-07 22:03:29 UTC*

  * 8827193 Merge pull request `#51084`_ from s0undt3ch/merge-singleton-last-ref-close-fluorine

  * 979fbac Merge branch '2019.2' into merge-singleton-last-ref-close-fluorine

  * 63f051a Merge branch '2019.2' into merge-singleton-last-ref-close-fluorine

  * bd6c46d Cleanup the singleton instances map.

.. _`#1`: https://github.com/saltstack/salt/issues/1
.. _`#21927`: https://github.com/saltstack/salt/issues/21927
.. _`#22063`: https://github.com/saltstack/salt/issues/22063
.. _`#2731`: https://github.com/saltstack/salt/issues/2731
.. _`#31179`: https://github.com/saltstack/salt/issues/31179
.. _`#32245`: https://github.com/saltstack/salt/issues/32245
.. _`#37945`: https://github.com/saltstack/salt/issues/37945
.. _`#39593`: https://github.com/saltstack/salt/pull/39593
.. _`#46265`: https://github.com/saltstack/salt/pull/46265
.. _`#47212`: https://github.com/saltstack/salt/pull/47212
.. _`#49039`: https://github.com/saltstack/salt/pull/49039
.. _`#49147`: https://github.com/saltstack/salt/issues/49147
.. _`#49559`: https://github.com/saltstack/salt/issues/49559
.. _`#49661`: https://github.com/saltstack/salt/issues/49661
.. _`#49663`: https://github.com/saltstack/salt/issues/49663
.. _`#49680`: https://github.com/saltstack/salt/issues/49680
.. _`#49804`: https://github.com/saltstack/salt/pull/49804
.. _`#49832`: https://github.com/saltstack/salt/pull/49832
.. _`#50087`: https://github.com/saltstack/salt/pull/50087
.. _`#50097`: https://github.com/saltstack/salt/issues/50097
.. _`#50183`: https://github.com/saltstack/salt/pull/50183
.. _`#50310`: https://github.com/saltstack/salt/issues/50310
.. _`#50358`: https://github.com/saltstack/salt/pull/50358
.. _`#50381`: https://github.com/saltstack/salt/issues/50381
.. _`#50400`: https://github.com/saltstack/salt/pull/50400
.. _`#50402`: https://github.com/saltstack/salt/pull/50402
.. _`#50473`: https://github.com/saltstack/salt/pull/50473
.. _`#50535`: https://github.com/saltstack/salt/issues/50535
.. _`#50538`: https://github.com/saltstack/salt/issues/50538
.. _`#50540`: https://github.com/saltstack/salt/pull/50540
.. _`#50556`: https://github.com/saltstack/salt/issues/50556
.. _`#50567`: https://github.com/saltstack/salt/pull/50567
.. _`#50768`: https://github.com/saltstack/salt/pull/50768
.. _`#50784`: https://github.com/saltstack/salt/pull/50784
.. _`#50812`: https://github.com/saltstack/salt/pull/50812
.. _`#50814`: https://github.com/saltstack/salt/issues/50814
.. _`#50849`: https://github.com/saltstack/salt/issues/50849
.. _`#50852`: https://github.com/saltstack/salt/pull/50852
.. _`#50858`: https://github.com/saltstack/salt/pull/50858
.. _`#50878`: https://github.com/saltstack/salt/pull/50878
.. _`#50887`: https://github.com/saltstack/salt/pull/50887
.. _`#50921`: https://github.com/saltstack/salt/pull/50921
.. _`#50923`: https://github.com/saltstack/salt/pull/50923
.. _`#50963`: https://github.com/saltstack/salt/pull/50963
.. _`#51008`: https://github.com/saltstack/salt/issues/51008
.. _`#51010`: https://github.com/saltstack/salt/pull/51010
.. _`#51030`: https://github.com/saltstack/salt/pull/51030
.. _`#51076`: https://github.com/saltstack/salt/pull/51076
.. _`#51080`: https://github.com/saltstack/salt/pull/51080
.. _`#51081`: https://github.com/saltstack/salt/pull/51081
.. _`#51084`: https://github.com/saltstack/salt/pull/51084
.. _`#51097`: https://github.com/saltstack/salt/pull/51097
.. _`#51099`: https://github.com/saltstack/salt/pull/51099
.. _`#51100`: https://github.com/saltstack/salt/pull/51100
.. _`#51111`: https://github.com/saltstack/salt/pull/51111
.. _`#51112`: https://github.com/saltstack/salt/pull/51112
.. _`#51133`: https://github.com/saltstack/salt/pull/51133
.. _`#51144`: https://github.com/saltstack/salt/pull/51144
.. _`#51146`: https://github.com/saltstack/salt/pull/51146
.. _`#51147`: https://github.com/saltstack/salt/pull/51147
.. _`#51148`: https://github.com/saltstack/salt/pull/51148
.. _`#51150`: https://github.com/saltstack/salt/pull/51150
.. _`#51151`: https://github.com/saltstack/salt/pull/51151
.. _`#51152`: https://github.com/saltstack/salt/pull/51152
.. _`#51154`: https://github.com/saltstack/salt/pull/51154
.. _`#51159`: https://github.com/saltstack/salt/pull/51159
.. _`#51161`: https://github.com/saltstack/salt/pull/51161
.. _`#51164`: https://github.com/saltstack/salt/pull/51164
.. _`#51169`: https://github.com/saltstack/salt/pull/51169
.. _`#51170`: https://github.com/saltstack/salt/pull/51170
.. _`#51171`: https://github.com/saltstack/salt/pull/51171
.. _`#51173`: https://github.com/saltstack/salt/pull/51173
.. _`#51174`: https://github.com/saltstack/salt/pull/51174
.. _`#51177`: https://github.com/saltstack/salt/pull/51177
.. _`#51179`: https://github.com/saltstack/salt/pull/51179
.. _`#51182`: https://github.com/saltstack/salt/pull/51182
.. _`#51184`: https://github.com/saltstack/salt/pull/51184
.. _`#51187`: https://github.com/saltstack/salt/pull/51187
.. _`#51191`: https://github.com/saltstack/salt/pull/51191
.. _`#51197`: https://github.com/saltstack/salt/pull/51197
.. _`#51198`: https://github.com/saltstack/salt/pull/51198
.. _`#51201`: https://github.com/saltstack/salt/pull/51201
.. _`#51206`: https://github.com/saltstack/salt/pull/51206
.. _`#51207`: https://github.com/saltstack/salt/pull/51207
.. _`#51209`: https://github.com/saltstack/salt/pull/51209
.. _`#51212`: https://github.com/saltstack/salt/pull/51212
.. _`#51220`: https://github.com/saltstack/salt/pull/51220
.. _`#51221`: https://github.com/saltstack/salt/pull/51221
.. _`#51225`: https://github.com/saltstack/salt/pull/51225
.. _`#51226`: https://github.com/saltstack/salt/pull/51226
.. _`#51227`: https://github.com/saltstack/salt/pull/51227
.. _`#51230`: https://github.com/saltstack/salt/pull/51230
.. _`#51231`: https://github.com/saltstack/salt/pull/51231
.. _`#51232`: https://github.com/saltstack/salt/pull/51232
.. _`#51233`: https://github.com/saltstack/salt/pull/51233
.. _`#51234`: https://github.com/saltstack/salt/pull/51234
.. _`#51239`: https://github.com/saltstack/salt/pull/51239
.. _`#51246`: https://github.com/saltstack/salt/pull/51246
.. _`#51250`: https://github.com/saltstack/salt/pull/51250
.. _`#51252`: https://github.com/saltstack/salt/pull/51252
.. _`#51261`: https://github.com/saltstack/salt/pull/51261
.. _`#51264`: https://github.com/saltstack/salt/pull/51264
.. _`#51267`: https://github.com/saltstack/salt/pull/51267
.. _`#51273`: https://github.com/saltstack/salt/issues/51273
.. _`#51274`: https://github.com/saltstack/salt/pull/51274
.. _`#51276`: https://github.com/saltstack/salt/pull/51276
.. _`#51277`: https://github.com/saltstack/salt/pull/51277
.. _`#51278`: https://github.com/saltstack/salt/pull/51278
.. _`#51279`: https://github.com/saltstack/salt/pull/51279
.. _`#51280`: https://github.com/saltstack/salt/pull/51280
.. _`#51285`: https://github.com/saltstack/salt/pull/51285
.. _`#51290`: https://github.com/saltstack/salt/pull/51290
.. _`#51292`: https://github.com/saltstack/salt/pull/51292
.. _`#51293`: https://github.com/saltstack/salt/pull/51293
.. _`#51295`: https://github.com/saltstack/salt/pull/51295
.. _`#51304`: https://github.com/saltstack/salt/pull/51304
.. _`#51305`: https://github.com/saltstack/salt/pull/51305
.. _`#51306`: https://github.com/saltstack/salt/pull/51306
.. _`#51307`: https://github.com/saltstack/salt/pull/51307
.. _`#51311`: https://github.com/saltstack/salt/pull/51311
.. _`#51312`: https://github.com/saltstack/salt/pull/51312
.. _`#51313`: https://github.com/saltstack/salt/pull/51313
.. _`#51314`: https://github.com/saltstack/salt/pull/51314
.. _`#51317`: https://github.com/saltstack/salt/pull/51317
.. _`#51319`: https://github.com/saltstack/salt/pull/51319
.. _`#51321`: https://github.com/saltstack/salt/pull/51321
.. _`#51323`: https://github.com/saltstack/salt/pull/51323
.. _`#51324`: https://github.com/saltstack/salt/pull/51324
.. _`#51333`: https://github.com/saltstack/salt/pull/51333
.. _`#51334`: https://github.com/saltstack/salt/pull/51334
.. _`#51336`: https://github.com/saltstack/salt/pull/51336
.. _`#51337`: https://github.com/saltstack/salt/pull/51337
.. _`#51338`: https://github.com/saltstack/salt/pull/51338
.. _`#51339`: https://github.com/saltstack/salt/pull/51339
.. _`#51340`: https://github.com/saltstack/salt/pull/51340
.. _`#51341`: https://github.com/saltstack/salt/pull/51341
.. _`#51351`: https://github.com/saltstack/salt/issues/51351
.. _`#51352`: https://github.com/saltstack/salt/pull/51352
.. _`#51361`: https://github.com/saltstack/salt/pull/51361
.. _`#51366`: https://github.com/saltstack/salt/pull/51366
.. _`#51367`: https://github.com/saltstack/salt/pull/51367
.. _`#51368`: https://github.com/saltstack/salt/pull/51368
.. _`#51370`: https://github.com/saltstack/salt/pull/51370
.. _`#51377`: https://github.com/saltstack/salt/pull/51377
.. _`#51383`: https://github.com/saltstack/salt/pull/51383
.. _`#51387`: https://github.com/saltstack/salt/pull/51387
.. _`#51389`: https://github.com/saltstack/salt/pull/51389
.. _`#51393`: https://github.com/saltstack/salt/pull/51393
.. _`#51397`: https://github.com/saltstack/salt/pull/51397
.. _`#51401`: https://github.com/saltstack/salt/pull/51401
.. _`#51402`: https://github.com/saltstack/salt/pull/51402
.. _`#51404`: https://github.com/saltstack/salt/pull/51404
.. _`#51405`: https://github.com/saltstack/salt/pull/51405
.. _`#51406`: https://github.com/saltstack/salt/pull/51406
.. _`#51407`: https://github.com/saltstack/salt/pull/51407
.. _`#51408`: https://github.com/saltstack/salt/pull/51408
.. _`#51410`: https://github.com/saltstack/salt/pull/51410
.. _`#51414`: https://github.com/saltstack/salt/pull/51414
.. _`#51419`: https://github.com/saltstack/salt/pull/51419
.. _`#51425`: https://github.com/saltstack/salt/pull/51425
.. _`#51426`: https://github.com/saltstack/salt/pull/51426
.. _`#51429`: https://github.com/saltstack/salt/pull/51429
.. _`#51432`: https://github.com/saltstack/salt/pull/51432
.. _`#51435`: https://github.com/saltstack/salt/pull/51435
.. _`#51437`: https://github.com/saltstack/salt/pull/51437
.. _`#51438`: https://github.com/saltstack/salt/pull/51438
.. _`#51441`: https://github.com/saltstack/salt/pull/51441
.. _`#51442`: https://github.com/saltstack/salt/pull/51442
.. _`#51445`: https://github.com/saltstack/salt/pull/51445
.. _`#51452`: https://github.com/saltstack/salt/pull/51452
.. _`#51454`: https://github.com/saltstack/salt/pull/51454
.. _`#51458`: https://github.com/saltstack/salt/pull/51458
.. _`#51460`: https://github.com/saltstack/salt/pull/51460
.. _`#51462`: https://github.com/saltstack/salt/pull/51462
.. _`#51465`: https://github.com/saltstack/salt/pull/51465
.. _`#51469`: https://github.com/saltstack/salt/pull/51469
.. _`#51471`: https://github.com/saltstack/salt/pull/51471
.. _`#51491`: https://github.com/saltstack/salt/pull/51491
.. _`#51502`: https://github.com/saltstack/salt/pull/51502
.. _`#51503`: https://github.com/saltstack/salt/issues/51503
.. _`#51517`: https://github.com/saltstack/salt/pull/51517
.. _`#51520`: https://github.com/saltstack/salt/pull/51520
.. _`#51523`: https://github.com/saltstack/salt/pull/51523
.. _`#51525`: https://github.com/saltstack/salt/pull/51525
.. _`#51527`: https://github.com/saltstack/salt/pull/51527
.. _`#51528`: https://github.com/saltstack/salt/pull/51528
.. _`#51529`: https://github.com/saltstack/salt/pull/51529
.. _`#51530`: https://github.com/saltstack/salt/pull/51530
.. _`#51532`: https://github.com/saltstack/salt/pull/51532
.. _`#51534`: https://github.com/saltstack/salt/pull/51534
.. _`#51541`: https://github.com/saltstack/salt/pull/51541
.. _`#51544`: https://github.com/saltstack/salt/pull/51544
.. _`#51547`: https://github.com/saltstack/salt/pull/51547
.. _`#51548`: https://github.com/saltstack/salt/pull/51548
.. _`#51549`: https://github.com/saltstack/salt/pull/51549
.. _`#51553`: https://github.com/saltstack/salt/pull/51553
.. _`#51558`: https://github.com/saltstack/salt/pull/51558
.. _`#51561`: https://github.com/saltstack/salt/pull/51561
.. _`#51562`: https://github.com/saltstack/salt/pull/51562
.. _`#51577`: https://github.com/saltstack/salt/pull/51577
.. _`#51580`: https://github.com/saltstack/salt/pull/51580
.. _`#51581`: https://github.com/saltstack/salt/pull/51581
.. _`#51583`: https://github.com/saltstack/salt/pull/51583
.. _`#51584`: https://github.com/saltstack/salt/pull/51584
.. _`#51586`: https://github.com/saltstack/salt/pull/51586
.. _`#51588`: https://github.com/saltstack/salt/pull/51588
.. _`#51589`: https://github.com/saltstack/salt/pull/51589
.. _`#51595`: https://github.com/saltstack/salt/pull/51595
.. _`#51597`: https://github.com/saltstack/salt/pull/51597
.. _`#51598`: https://github.com/saltstack/salt/pull/51598
.. _`#51599`: https://github.com/saltstack/salt/pull/51599
.. _`#51607`: https://github.com/saltstack/salt/pull/51607
.. _`#51608`: https://github.com/saltstack/salt/pull/51608
.. _`#51609`: https://github.com/saltstack/salt/pull/51609
.. _`#51610`: https://github.com/saltstack/salt/pull/51610
.. _`#51613`: https://github.com/saltstack/salt/pull/51613
.. _`#51622`: https://github.com/saltstack/salt/pull/51622
.. _`#51626`: https://github.com/saltstack/salt/pull/51626
.. _`#51630`: https://github.com/saltstack/salt/pull/51630
.. _`#51631`: https://github.com/saltstack/salt/pull/51631
.. _`#51635`: https://github.com/saltstack/salt/pull/51635
.. _`#51637`: https://github.com/saltstack/salt/pull/51637
.. _`#51643`: https://github.com/saltstack/salt/pull/51643
.. _`#51644`: https://github.com/saltstack/salt/pull/51644
.. _`#51645`: https://github.com/saltstack/salt/pull/51645
.. _`#51646`: https://github.com/saltstack/salt/pull/51646
.. _`#51647`: https://github.com/saltstack/salt/pull/51647
.. _`#51648`: https://github.com/saltstack/salt/pull/51648
.. _`#51649`: https://github.com/saltstack/salt/pull/51649
.. _`#51650`: https://github.com/saltstack/salt/pull/51650
.. _`#51655`: https://github.com/saltstack/salt/pull/51655
.. _`#51658`: https://github.com/saltstack/salt/pull/51658
.. _`#51661`: https://github.com/saltstack/salt/pull/51661
.. _`#51671`: https://github.com/saltstack/salt/pull/51671
.. _`#51674`: https://github.com/saltstack/salt/pull/51674
.. _`#51676`: https://github.com/saltstack/salt/pull/51676
.. _`#51678`: https://github.com/saltstack/salt/pull/51678
.. _`#51679`: https://github.com/saltstack/salt/pull/51679
.. _`#51680`: https://github.com/saltstack/salt/pull/51680
.. _`#51681`: https://github.com/saltstack/salt/pull/51681
.. _`#51689`: https://github.com/saltstack/salt/pull/51689
.. _`#51694`: https://github.com/saltstack/salt/pull/51694
.. _`#51707`: https://github.com/saltstack/salt/pull/51707
.. _`#51712`: https://github.com/saltstack/salt/pull/51712
.. _`#51713`: https://github.com/saltstack/salt/pull/51713
.. _`#51714`: https://github.com/saltstack/salt/pull/51714
.. _`#51715`: https://github.com/saltstack/salt/pull/51715
.. _`#51721`: https://github.com/saltstack/salt/pull/51721
.. _`#51723`: https://github.com/saltstack/salt/issues/51723
.. _`#51724`: https://github.com/saltstack/salt/pull/51724
.. _`#51728`: https://github.com/saltstack/salt/pull/51728
.. _`#51732`: https://github.com/saltstack/salt/pull/51732
.. _`#51733`: https://github.com/saltstack/salt/pull/51733
.. _`#51734`: https://github.com/saltstack/salt/pull/51734
.. _`#51738`: https://github.com/saltstack/salt/pull/51738
.. _`#51745`: https://github.com/saltstack/salt/issues/51745
.. _`#51747`: https://github.com/saltstack/salt/pull/51747
.. _`#51748`: https://github.com/saltstack/salt/issues/51748
.. _`#51749`: https://github.com/saltstack/salt/pull/51749
.. _`#51753`: https://github.com/saltstack/salt/pull/51753
.. _`#51756`: https://github.com/saltstack/salt/pull/51756
.. _`#51757`: https://github.com/saltstack/salt/pull/51757
.. _`#51761`: https://github.com/saltstack/salt/pull/51761
.. _`#51770`: https://github.com/saltstack/salt/pull/51770
.. _`#51771`: https://github.com/saltstack/salt/pull/51771
.. _`#51772`: https://github.com/saltstack/salt/pull/51772
.. _`#51774`: https://github.com/saltstack/salt/pull/51774
.. _`#51775`: https://github.com/saltstack/salt/pull/51775
.. _`#51776`: https://github.com/saltstack/salt/pull/51776
.. _`#51799`: https://github.com/saltstack/salt/pull/51799
.. _`#51800`: https://github.com/saltstack/salt/pull/51800
.. _`#51802`: https://github.com/saltstack/salt/pull/51802
.. _`#51806`: https://github.com/saltstack/salt/pull/51806
.. _`#51807`: https://github.com/saltstack/salt/pull/51807
.. _`#51810`: https://github.com/saltstack/salt/pull/51810
.. _`#51815`: https://github.com/saltstack/salt/pull/51815
.. _`#51816`: https://github.com/saltstack/salt/issues/51816
.. _`#51818`: https://github.com/saltstack/salt/issues/51818
.. _`#51821`: https://github.com/saltstack/salt/issues/51821
.. _`#51824`: https://github.com/saltstack/salt/issues/51824
.. _`#51825`: https://github.com/saltstack/salt/issues/51825
.. _`#51832`: https://github.com/saltstack/salt/issues/51832
.. _`#51836`: https://github.com/saltstack/salt/pull/51836
.. _`#51837`: https://github.com/saltstack/salt/pull/51837
.. _`#51842`: https://github.com/saltstack/salt/issues/51842
.. _`#51849`: https://github.com/saltstack/salt/pull/51849
.. _`#51850`: https://github.com/saltstack/salt/pull/51850
.. _`#51855`: https://github.com/saltstack/salt/pull/51855
.. _`#51861`: https://github.com/saltstack/salt/pull/51861
.. _`#51865`: https://github.com/saltstack/salt/issues/51865
.. _`#51867`: https://github.com/saltstack/salt/pull/51867
.. _`#51869`: https://github.com/saltstack/salt/issues/51869
.. _`#51875`: https://github.com/saltstack/salt/pull/51875
.. _`#51878`: https://github.com/saltstack/salt/pull/51878
.. _`#51879`: https://github.com/saltstack/salt/issues/51879
.. _`#51892`: https://github.com/saltstack/salt/pull/51892
.. _`#51893`: https://github.com/saltstack/salt/pull/51893
.. _`#51895`: https://github.com/saltstack/salt/pull/51895
.. _`#51896`: https://github.com/saltstack/salt/pull/51896
.. _`#51905`: https://github.com/saltstack/salt/pull/51905
.. _`#51908`: https://github.com/saltstack/salt/pull/51908
.. _`#51913`: https://github.com/saltstack/salt/pull/51913
.. _`#51918`: https://github.com/saltstack/salt/pull/51918
.. _`#51920`: https://github.com/saltstack/salt/pull/51920
.. _`#51930`: https://github.com/saltstack/salt/pull/51930
.. _`#51931`: https://github.com/saltstack/salt/pull/51931
.. _`#51932`: https://github.com/saltstack/salt/issues/51932
.. _`#51935`: https://github.com/saltstack/salt/pull/51935
.. _`#51936`: https://github.com/saltstack/salt/pull/51936
.. _`#51937`: https://github.com/saltstack/salt/pull/51937
.. _`#51946`: https://github.com/saltstack/salt/pull/51946
.. _`#51962`: https://github.com/saltstack/salt/pull/51962
.. _`#51963`: https://github.com/saltstack/salt/pull/51963
.. _`#51964`: https://github.com/saltstack/salt/pull/51964
.. _`#51966`: https://github.com/saltstack/salt/pull/51966
.. _`#51967`: https://github.com/saltstack/salt/pull/51967
.. _`#51974`: https://github.com/saltstack/salt/pull/51974
.. _`#51975`: https://github.com/saltstack/salt/pull/51975
.. _`#51976`: https://github.com/saltstack/salt/pull/51976
.. _`#51980`: https://github.com/saltstack/salt/pull/51980
.. _`#51981`: https://github.com/saltstack/salt/pull/51981
.. _`#51982`: https://github.com/saltstack/salt/issues/51982
.. _`#51983`: https://github.com/saltstack/salt/pull/51983
.. _`#51984`: https://github.com/saltstack/salt/pull/51984
.. _`#51992`: https://github.com/saltstack/salt/pull/51992
.. _`#51995`: https://github.com/saltstack/salt/pull/51995
.. _`#52004`: https://github.com/saltstack/salt/pull/52004
.. _`#52008`: https://github.com/saltstack/salt/pull/52008
.. _`#52028`: https://github.com/saltstack/salt/pull/52028
.. _`#52029`: https://github.com/saltstack/salt/pull/52029
.. _`#52030`: https://github.com/saltstack/salt/pull/52030
.. _`#52032`: https://github.com/saltstack/salt/pull/52032
.. _`#52034`: https://github.com/saltstack/salt/pull/52034
.. _`#52035`: https://github.com/saltstack/salt/pull/52035
.. _`#52036`: https://github.com/saltstack/salt/issues/52036
.. _`#52037`: https://github.com/saltstack/salt/pull/52037
.. _`#52038`: https://github.com/saltstack/salt/pull/52038
.. _`#52040`: https://github.com/saltstack/salt/pull/52040
.. _`#52041`: https://github.com/saltstack/salt/issues/52041
.. _`#52043`: https://github.com/saltstack/salt/pull/52043
.. _`#52046`: https://github.com/saltstack/salt/pull/52046
.. _`#52065`: https://github.com/saltstack/salt/pull/52065
.. _`#52112`: https://github.com/saltstack/salt/pull/52112
.. _`#52113`: https://github.com/saltstack/salt/pull/52113
.. _`#52116`: https://github.com/saltstack/salt/issues/52116
.. _`#52134`: https://github.com/saltstack/salt/issues/52134
.. _`#52145`: https://github.com/saltstack/salt/pull/52145
.. _`#52146`: https://github.com/saltstack/salt/pull/52146
.. _`#52151`: https://github.com/saltstack/salt/pull/52151
.. _`#52160`: https://github.com/saltstack/salt/pull/52160
.. _`#52170`: https://github.com/saltstack/salt/pull/52170
.. _`#52172`: https://github.com/saltstack/salt/pull/52172
.. _`#52173`: https://github.com/saltstack/salt/issues/52173
.. _`#52174`: https://github.com/saltstack/salt/issues/52174
.. _`#52189`: https://github.com/saltstack/salt/pull/52189
.. _`#52190`: https://github.com/saltstack/salt/pull/52190
.. _`#52191`: https://github.com/saltstack/salt/pull/52191
.. _`#52193`: https://github.com/saltstack/salt/pull/52193
.. _`#52194`: https://github.com/saltstack/salt/pull/52194
.. _`#52201`: https://github.com/saltstack/salt/pull/52201
.. _`#52208`: https://github.com/saltstack/salt/pull/52208
.. _`#52209`: https://github.com/saltstack/salt/pull/52209
.. _`#52212`: https://github.com/saltstack/salt/pull/52212
.. _`#52213`: https://github.com/saltstack/salt/pull/52213
.. _`#52215`: https://github.com/saltstack/salt/pull/52215
.. _`#52226`: https://github.com/saltstack/salt/pull/52226
.. _`#52234`: https://github.com/saltstack/salt/pull/52234
.. _`#52240`: https://github.com/saltstack/salt/pull/52240
.. _`#52245`: https://github.com/saltstack/salt/issues/52245
.. _`#52250`: https://github.com/saltstack/salt/pull/52250
.. _`#52251`: https://github.com/saltstack/salt/issues/52251
.. _`#52261`: https://github.com/saltstack/salt/pull/52261
.. _`#52262`: https://github.com/saltstack/salt/pull/52262
.. _`#52269`: https://github.com/saltstack/salt/pull/52269
.. _`#52276`: https://github.com/saltstack/salt/pull/52276
.. _`#52277`: https://github.com/saltstack/salt/issues/52277
.. _`#52283`: https://github.com/saltstack/salt/pull/52283
.. _`#52290`: https://github.com/saltstack/salt/pull/52290
.. _`#52306`: https://github.com/saltstack/salt/pull/52306
.. _`#52307`: https://github.com/saltstack/salt/pull/52307
.. _`#52310`: https://github.com/saltstack/salt/pull/52310
.. _`#52311`: https://github.com/saltstack/salt/pull/52311
.. _`#52312`: https://github.com/saltstack/salt/pull/52312
.. _`#52314`: https://github.com/saltstack/salt/pull/52314
.. _`#52326`: https://github.com/saltstack/salt/pull/52326
.. _`#52334`: https://github.com/saltstack/salt/pull/52334
.. _`#52341`: https://github.com/saltstack/salt/pull/52341
.. _`#52344`: https://github.com/saltstack/salt/pull/52344
.. _`#52345`: https://github.com/saltstack/salt/pull/52345
.. _`#52347`: https://github.com/saltstack/salt/pull/52347
.. _`#52350`: https://github.com/saltstack/salt/issues/52350
.. _`#52370`: https://github.com/saltstack/salt/pull/52370
.. _`#52381`: https://github.com/saltstack/salt/pull/52381
.. _`#52391`: https://github.com/saltstack/salt/issues/52391
.. _`#52393`: https://github.com/saltstack/salt/pull/52393
.. _`#52396`: https://github.com/saltstack/salt/pull/52396
.. _`#52397`: https://github.com/saltstack/salt/pull/52397
.. _`#52399`: https://github.com/saltstack/salt/pull/52399
.. _`#52401`: https://github.com/saltstack/salt/pull/52401
.. _`#52403`: https://github.com/saltstack/salt/pull/52403
.. _`#52413`: https://github.com/saltstack/salt/pull/52413
.. _`#52415`: https://github.com/saltstack/salt/pull/52415
.. _`#52423`: https://github.com/saltstack/salt/pull/52423
.. _`#52427`: https://github.com/saltstack/salt/pull/52427
.. _`#52445`: https://github.com/saltstack/salt/pull/52445
.. _`#52449`: https://github.com/saltstack/salt/issues/52449
.. _`#52462`: https://github.com/saltstack/salt/issues/52462
.. _`#52472`: https://github.com/saltstack/salt/pull/52472
.. _`#52473`: https://github.com/saltstack/salt/pull/52473
.. _`#52474`: https://github.com/saltstack/salt/pull/52474
.. _`#52475`: https://github.com/saltstack/salt/pull/52475
.. _`#52476`: https://github.com/saltstack/salt/pull/52476
.. _`#52477`: https://github.com/saltstack/salt/pull/52477
.. _`#52482`: https://github.com/saltstack/salt/pull/52482
.. _`#52487`: https://github.com/saltstack/salt/pull/52487
.. _`#52488`: https://github.com/saltstack/salt/pull/52488
.. _`#52490`: https://github.com/saltstack/salt/pull/52490
.. _`#52493`: https://github.com/saltstack/salt/pull/52493
.. _`#52496`: https://github.com/saltstack/salt/pull/52496
.. _`#52500`: https://github.com/saltstack/salt/pull/52500
.. _`#52505`: https://github.com/saltstack/salt/pull/52505
.. _`#52506`: https://github.com/saltstack/salt/pull/52506
.. _`#52508`: https://github.com/saltstack/salt/issues/52508
.. _`#52512`: https://github.com/saltstack/salt/pull/52512
.. _`#52513`: https://github.com/saltstack/salt/pull/52513
.. _`#52525`: https://github.com/saltstack/salt/issues/52525
.. _`#52526`: https://github.com/saltstack/salt/pull/52526
.. _`#52528`: https://github.com/saltstack/salt/pull/52528
.. _`#52534`: https://github.com/saltstack/salt/pull/52534
.. _`#52536`: https://github.com/saltstack/salt/pull/52536
.. _`#52540`: https://github.com/saltstack/salt/pull/52540
.. _`#52547`: https://github.com/saltstack/salt/issues/52547
.. _`#52548`: https://github.com/saltstack/salt/pull/52548
.. _`#52551`: https://github.com/saltstack/salt/pull/52551
.. _`#52552`: https://github.com/saltstack/salt/pull/52552
.. _`#52553`: https://github.com/saltstack/salt/pull/52553
.. _`#52564`: https://github.com/saltstack/salt/pull/52564
.. _`#52570`: https://github.com/saltstack/salt/pull/52570
.. _`#52591`: https://github.com/saltstack/salt/pull/52591
.. _`#52593`: https://github.com/saltstack/salt/pull/52593
.. _`#52601`: https://github.com/saltstack/salt/pull/52601
.. _`#52614`: https://github.com/saltstack/salt/pull/52614
.. _`#52615`: https://github.com/saltstack/salt/pull/52615
.. _`#52619`: https://github.com/saltstack/salt/pull/52619
.. _`#52624`: https://github.com/saltstack/salt/pull/52624
.. _`#52629`: https://github.com/saltstack/salt/pull/52629
.. _`#52632`: https://github.com/saltstack/salt/pull/52632
.. _`#52645`: https://github.com/saltstack/salt/pull/52645
.. _`#52655`: https://github.com/saltstack/salt/pull/52655
.. _`#52659`: https://github.com/saltstack/salt/pull/52659
.. _`#52696`: https://github.com/saltstack/salt/pull/52696
.. _`#52717`: https://github.com/saltstack/salt/issues/52717
.. _`#52721`: https://github.com/saltstack/salt/issues/52721
.. _`#52736`: https://github.com/saltstack/salt/pull/52736
.. _`#52753`: https://github.com/saltstack/salt/pull/52753
.. _`#52754`: https://github.com/saltstack/salt/pull/52754
.. _`#52755`: https://github.com/saltstack/salt/pull/52755
.. _`#52767`: https://github.com/saltstack/salt/pull/52767
.. _`#52768`: https://github.com/saltstack/salt/pull/52768
.. _`#52769`: https://github.com/saltstack/salt/pull/52769
.. _`#52770`: https://github.com/saltstack/salt/pull/52770
.. _`#52771`: https://github.com/saltstack/salt/pull/52771
.. _`#52780`: https://github.com/saltstack/salt/pull/52780
.. _`#52783`: https://github.com/saltstack/salt/pull/52783
.. _`#52787`: https://github.com/saltstack/salt/pull/52787
.. _`#52796`: https://github.com/saltstack/salt/pull/52796
.. _`#52797`: https://github.com/saltstack/salt/pull/52797
.. _`#52817`: https://github.com/saltstack/salt/issues/52817
.. _`#52818`: https://github.com/saltstack/salt/pull/52818
.. _`#52827`: https://github.com/saltstack/salt/pull/52827
.. _`#52836`: https://github.com/saltstack/salt/issues/52836
.. _`#52839`: https://github.com/saltstack/salt/pull/52839
.. _`#52842`: https://github.com/saltstack/salt/pull/52842
.. _`#52845`: https://github.com/saltstack/salt/pull/52845
.. _`#52851`: https://github.com/saltstack/salt/pull/52851
.. _`#52852`: https://github.com/saltstack/salt/pull/52852
.. _`#52853`: https://github.com/saltstack/salt/pull/52853
.. _`#52926`: https://github.com/saltstack/salt/issues/52926
.. _`#52934`: https://github.com/saltstack/salt/pull/52934
.. _`#52943`: https://github.com/saltstack/salt/pull/52943
.. _`#52952`: https://github.com/saltstack/salt/pull/52952
.. _`#52957`: https://github.com/saltstack/salt/pull/52957
.. _`#52966`: https://github.com/saltstack/salt/pull/52966
.. _`#52968`: https://github.com/saltstack/salt/pull/52968
.. _`#52972`: https://github.com/saltstack/salt/pull/52972
.. _`#52973`: https://github.com/saltstack/salt/pull/52973
.. _`#52986`: https://github.com/saltstack/salt/pull/52986
.. _`#53020`: https://github.com/saltstack/salt/pull/53020
.. _`#53025`: https://github.com/saltstack/salt/pull/53025
.. _`#53072`: https://github.com/saltstack/salt/pull/53072
.. _`#53073`: https://github.com/saltstack/salt/pull/53073
.. _`#53131`: https://github.com/saltstack/salt/pull/53131
.. _`#53137`: https://github.com/saltstack/salt/issues/53137
.. _`#53138`: https://github.com/saltstack/salt/pull/53138
.. _`#53141`: https://github.com/saltstack/salt/pull/53141
.. _`#53153`: https://github.com/saltstack/salt/pull/53153
.. _`#53157`: https://github.com/saltstack/salt/pull/53157
.. _`#53161`: https://github.com/saltstack/salt/pull/53161
.. _`#53165`: https://github.com/saltstack/salt/pull/53165
.. _`#53171`: https://github.com/saltstack/salt/issues/53171
.. _`#53192`: https://github.com/saltstack/salt/pull/53192
.. _`#53210`: https://github.com/saltstack/salt/pull/53210
.. _`#53220`: https://github.com/saltstack/salt/pull/53220
.. _`#53235`: https://github.com/saltstack/salt/pull/53235
.. _`#53238`: https://github.com/saltstack/salt/pull/53238
.. _`#53240`: https://github.com/saltstack/salt/pull/53240
.. _`#53242`: https://github.com/saltstack/salt/pull/53242
.. _`#53258`: https://github.com/saltstack/salt/pull/53258
.. _`#53264`: https://github.com/saltstack/salt/pull/53264
.. _`#53273`: https://github.com/saltstack/salt/pull/53273
.. _`#53274`: https://github.com/saltstack/salt/issues/53274
.. _`#53283`: https://github.com/saltstack/salt/issues/53283
.. _`#53287`: https://github.com/saltstack/salt/pull/53287
.. _`#53289`: https://github.com/saltstack/salt/pull/53289
.. _`#53295`: https://github.com/saltstack/salt/pull/53295
.. _`#53297`: https://github.com/saltstack/salt/pull/53297
.. _`#53304`: https://github.com/saltstack/salt/pull/53304
.. _`#53306`: https://github.com/saltstack/salt/issues/53306
.. _`#53311`: https://github.com/saltstack/salt/pull/53311
.. _`#53323`: https://github.com/saltstack/salt/pull/53323
.. _`#53332`: https://github.com/saltstack/salt/pull/53332
.. _`#53344`: https://github.com/saltstack/salt/pull/53344
.. _`#53351`: https://github.com/saltstack/salt/pull/53351
.. _`#53356`: https://github.com/saltstack/salt/pull/53356
.. _`#53361`: https://github.com/saltstack/salt/pull/53361
.. _`#53369`: https://github.com/saltstack/salt/pull/53369
.. _`#53385`: https://github.com/saltstack/salt/pull/53385
.. _`#53386`: https://github.com/saltstack/salt/pull/53386
.. _`#53389`: https://github.com/saltstack/salt/pull/53389
.. _`#53408`: https://github.com/saltstack/salt/pull/53408
.. _`#53411`: https://github.com/saltstack/salt/issues/53411
.. _`#53412`: https://github.com/saltstack/salt/pull/53412
.. _`#53417`: https://github.com/saltstack/salt/pull/53417
.. _`#53430`: https://github.com/saltstack/salt/pull/53430
.. _`#53431`: https://github.com/saltstack/salt/pull/53431
.. _`#53432`: https://github.com/saltstack/salt/pull/53432
.. _`#53434`: https://github.com/saltstack/salt/pull/53434
.. _`#53437`: https://github.com/saltstack/salt/pull/53437
.. _`#53461`: https://github.com/saltstack/salt/pull/53461
.. _`#53466`: https://github.com/saltstack/salt/pull/53466
.. _`#53467`: https://github.com/saltstack/salt/pull/53467
.. _`#53475`: https://github.com/saltstack/salt/pull/53475
.. _`#53485`: https://github.com/saltstack/salt/pull/53485
.. _`#53491`: https://github.com/saltstack/salt/pull/53491
.. _`#53492`: https://github.com/saltstack/salt/pull/53492
.. _`#53493`: https://github.com/saltstack/salt/pull/53493
.. _`#53494`: https://github.com/saltstack/salt/pull/53494
.. _`#53498`: https://github.com/saltstack/salt/pull/53498
.. _`#53514`: https://github.com/saltstack/salt/pull/53514
.. _`#53526`: https://github.com/saltstack/salt/pull/53526
.. _`#53532`: https://github.com/saltstack/salt/issues/53532
.. _`#53542`: https://github.com/saltstack/salt/pull/53542
.. _`#53556`: https://github.com/saltstack/salt/pull/53556
.. _`#53557`: https://github.com/saltstack/salt/pull/53557
.. _`#53562`: https://github.com/saltstack/salt/pull/53562
.. _`#53563`: https://github.com/saltstack/salt/pull/53563
.. _`#53574`: https://github.com/saltstack/salt/pull/53574
.. _`#53584`: https://github.com/saltstack/salt/pull/53584
.. _`#53585`: https://github.com/saltstack/salt/pull/53585
.. _`#53587`: https://github.com/saltstack/salt/pull/53587
.. _`#53590`: https://github.com/saltstack/salt/pull/53590
.. _`#53591`: https://github.com/saltstack/salt/pull/53591
.. _`#53609`: https://github.com/saltstack/salt/pull/53609
.. _`#53614`: https://github.com/saltstack/salt/pull/53614
.. _`#53624`: https://github.com/saltstack/salt/pull/53624
.. _`#53627`: https://github.com/saltstack/salt/pull/53627
.. _`#53653`: https://github.com/saltstack/salt/pull/53653
.. _`#53662`: https://github.com/saltstack/salt/pull/53662
.. _`#53678`: https://github.com/saltstack/salt/pull/53678
.. _`#53680`: https://github.com/saltstack/salt/pull/53680
.. _`#53682`: https://github.com/saltstack/salt/pull/53682
.. _`#53688`: https://github.com/saltstack/salt/pull/53688
.. _`#53689`: https://github.com/saltstack/salt/pull/53689
.. _`#53690`: https://github.com/saltstack/salt/pull/53690
.. _`#53697`: https://github.com/saltstack/salt/pull/53697
.. _`#53719`: https://github.com/saltstack/salt/pull/53719
.. _`#53725`: https://github.com/saltstack/salt/pull/53725
.. _`#53728`: https://github.com/saltstack/salt/pull/53728
.. _`#53734`: https://github.com/saltstack/salt/pull/53734
.. _`#53735`: https://github.com/saltstack/salt/pull/53735
.. _`#53750`: https://github.com/saltstack/salt/pull/53750
.. _`#53822`: https://github.com/saltstack/salt/pull/53822
.. _`#53826`: https://github.com/saltstack/salt/pull/53826
.. _`#53829`: https://github.com/saltstack/salt/pull/53829
.. _`#53848`: https://github.com/saltstack/salt/pull/53848
.. _`#53851`: https://github.com/saltstack/salt/pull/53851
.. _`#53873`: https://github.com/saltstack/salt/pull/53873
.. _`#53897`: https://github.com/saltstack/salt/pull/53897
.. _`#53900`: https://github.com/saltstack/salt/pull/53900
.. _`#53901`: https://github.com/saltstack/salt/pull/53901
.. _`#53902`: https://github.com/saltstack/salt/pull/53902
.. _`#53913`: https://github.com/saltstack/salt/pull/53913
.. _`#53920`: https://github.com/saltstack/salt/pull/53920
.. _`#53931`: https://github.com/saltstack/salt/issues/53931
.. _`#53948`: https://github.com/saltstack/salt/issues/53948
.. _`#53953`: https://github.com/saltstack/salt/pull/53953
.. _`#53970`: https://github.com/saltstack/salt/pull/53970
.. _`#53974`: https://github.com/saltstack/salt/pull/53974
.. _`#53999`: https://github.com/saltstack/salt/pull/53999
.. _`#54001`: https://github.com/saltstack/salt/pull/54001
.. _`#54003`: https://github.com/saltstack/salt/pull/54003
.. _`#54017`: https://github.com/saltstack/salt/pull/54017
.. _`#54033`: https://github.com/saltstack/salt/pull/54033
.. _`#54038`: https://github.com/saltstack/salt/pull/54038
.. _`#54040`: https://github.com/saltstack/salt/pull/54040
.. _`#54050`: https://github.com/saltstack/salt/pull/54050
.. _`#54051`: https://github.com/saltstack/salt/pull/54051
.. _`#54057`: https://github.com/saltstack/salt/pull/54057
.. _`#54063`: https://github.com/saltstack/salt/pull/54063
.. _`#54079`: https://github.com/saltstack/salt/pull/54079
.. _`#54080`: https://github.com/saltstack/salt/pull/54080
.. _`#54108`: https://github.com/saltstack/salt/pull/54108
.. _`#54121`: https://github.com/saltstack/salt/pull/54121
.. _`#54136`: https://github.com/saltstack/salt/pull/54136
.. _`#54143`: https://github.com/saltstack/salt/pull/54143
.. _`#54153`: https://github.com/saltstack/salt/issues/54153
.. _`#54172`: https://github.com/saltstack/salt/pull/54172
.. _`#54173`: https://github.com/saltstack/salt/pull/54173
.. _`#54174`: https://github.com/saltstack/salt/issues/54174
.. _`#54178`: https://github.com/saltstack/salt/pull/54178
.. _`#54180`: https://github.com/saltstack/salt/pull/54180
.. _`#54191`: https://github.com/saltstack/salt/pull/54191
.. _`#54202`: https://github.com/saltstack/salt/pull/54202
.. _`#54203`: https://github.com/saltstack/salt/pull/54203
.. _`#54204`: https://github.com/saltstack/salt/pull/54204
.. _`#54214`: https://github.com/saltstack/salt/pull/54214
.. _`#54219`: https://github.com/saltstack/salt/issues/54219
.. _`#54223`: https://github.com/saltstack/salt/pull/54223
.. _`#54235`: https://github.com/saltstack/salt/pull/54235
.. _`#54237`: https://github.com/saltstack/salt/pull/54237
.. _`#54239`: https://github.com/saltstack/salt/pull/54239
.. _`#54240`: https://github.com/saltstack/salt/pull/54240
.. _`#54245`: https://github.com/saltstack/salt/pull/54245
.. _`#54246`: https://github.com/saltstack/salt/pull/54246
.. _`#54247`: https://github.com/saltstack/salt/pull/54247
.. _`#54251`: https://github.com/saltstack/salt/pull/54251
.. _`#54252`: https://github.com/saltstack/salt/pull/54252
.. _`#54256`: https://github.com/saltstack/salt/issues/54256
.. _`#54259`: https://github.com/saltstack/salt/pull/54259
.. _`#54263`: https://github.com/saltstack/salt/pull/54263
.. _`#54264`: https://github.com/saltstack/salt/pull/54264
.. _`#54266`: https://github.com/saltstack/salt/pull/54266
.. _`#54270`: https://github.com/saltstack/salt/pull/54270
.. _`#54274`: https://github.com/saltstack/salt/pull/54274
.. _`#54277`: https://github.com/saltstack/salt/pull/54277
.. _`#54278`: https://github.com/saltstack/salt/pull/54278
.. _`#54282`: https://github.com/saltstack/salt/pull/54282
.. _`#54303`: https://github.com/saltstack/salt/pull/54303
.. _`#54305`: https://github.com/saltstack/salt/pull/54305
.. _`#54314`: https://github.com/saltstack/salt/pull/54314
.. _`#54316`: https://github.com/saltstack/salt/pull/54316
.. _`#54324`: https://github.com/saltstack/salt/pull/54324
.. _`#54325`: https://github.com/saltstack/salt/pull/54325
.. _`#54327`: https://github.com/saltstack/salt/pull/54327
.. _`#54338`: https://github.com/saltstack/salt/pull/54338
.. _`#54353`: https://github.com/saltstack/salt/pull/54353
.. _`#54355`: https://github.com/saltstack/salt/pull/54355
.. _`#54376`: https://github.com/saltstack/salt/pull/54376
.. _`#54386`: https://github.com/saltstack/salt/pull/54386
.. _`#54388`: https://github.com/saltstack/salt/pull/54388
.. _`#54396`: https://github.com/saltstack/salt/pull/54396
.. _`#54409`: https://github.com/saltstack/salt/pull/54409
.. _`#54416`: https://github.com/saltstack/salt/pull/54416
.. _`#54419`: https://github.com/saltstack/salt/pull/54419
.. _`#54424`: https://github.com/saltstack/salt/pull/54424
.. _`#54429`: https://github.com/saltstack/salt/issues/54429
.. _`#54433`: https://github.com/saltstack/salt/pull/54433
.. _`#54434`: https://github.com/saltstack/salt/pull/54434
.. _`#54751`: https://github.com/saltstack/salt/issues/54751
.. _`#54762`: https://github.com/saltstack/salt/issues/54762
.. _`#54776`: https://github.com/saltstack/salt/issues/54776
.. _`#54731`: https://github.com/saltstack/salt/pull/54731
.. _`#54758`: https://github.com/saltstack/salt/issues/54758
.. _`#54765`: https://github.com/saltstack/salt/issues/54765
.. _`#54771`: https://github.com/saltstack/salt/issues/54771
.. _`#54759`: https://github.com/saltstack/salt/issues/54759
.. _`#5`: https://github.com/saltstack/salt/issues/5
.. _`#6`: https://github.com/saltstack/salt/issues/6
.. _`#7745`: https://github.com/saltstack/salt/issues/7745
.. _`#7`: https://github.com/saltstack/salt/issues/7
.. _`Akm0d`: https://github.com/Akm0d
.. _`Ch3LL`: https://github.com/Ch3LL
.. _`DmitryKuzmenko`: https://github.com/DmitryKuzmenko
.. _`Ethyling`: https://github.com/Ethyling
.. _`FireGrace`: https://github.com/FireGrace
.. _`KChandrashekhar`: https://github.com/KChandrashekhar
.. _`OrangeDog`: https://github.com/OrangeDog
.. _`ScoreUnder`: https://github.com/ScoreUnder
.. _`amendlik`: https://github.com/amendlik
.. _`aplanas`: https://github.com/aplanas
.. _`arsiesys`: https://github.com/arsiesys
.. _`bbinet`: https://github.com/bbinet
.. _`bryceml`: https://github.com/bryceml
.. _`cbosdo`: https://github.com/cbosdo
.. _`cdalvaro`: https://github.com/cdalvaro
.. _`chdamianos`: https://github.com/chdamianos
.. _`cmcmarrow`: https://github.com/cmcmarrow
.. _`cro`: https://github.com/cro
.. _`cwood`: https://github.com/cwood
.. _`dafyddj`: https://github.com/dafyddj
.. _`damianosSemmle`: https://github.com/damianosSemmle
.. _`dmurphy18`: https://github.com/dmurphy18
.. _`doesitblend`: https://github.com/doesitblend
.. _`dwoz`: https://github.com/dwoz
.. _`eimantaszd`: https://github.com/eimantaszd
.. _`ephreal`: https://github.com/ephreal
.. _`fayak`: https://github.com/fayak
.. _`felippeb`: https://github.com/felippeb
.. _`frogunder`: https://github.com/frogunder
.. _`furgerf`: https://github.com/furgerf
.. _`garethgreenaway`: https://github.com/garethgreenaway
.. _`garethhowell`: https://github.com/garethhowell
.. _`ghost`: https://github.com/ghost
.. _`github-abcde`: https://github.com/github-abcde
.. _`gstachowiak`: https://github.com/gstachowiak
.. _`isbm`: https://github.com/isbm
.. _`jeanpralo`: https://github.com/jeanpralo
.. _`jfindlay`: https://github.com/jfindlay
.. _`jkrauz`: https://github.com/jkrauz
.. _`lomeroe`: https://github.com/lomeroe
.. _`lordcirth`: https://github.com/lordcirth
.. _`magenbrot`: https://github.com/magenbrot
.. _`mattLLVW`: https://github.com/mattLLVW
.. _`mattp-`: https://github.com/mattp-
.. _`mgwilliams`: https://github.com/mgwilliams
.. _`mirceaulinic`: https://github.com/mirceaulinic
.. _`nicholasmhughes`: https://github.com/nicholasmhughes
.. _`nocturo`: https://github.com/nocturo
.. _`rbthomp`: https://github.com/rbthomp
.. _`rombert`: https://github.com/rombert
.. _`rsmekala`: https://github.com/rsmekala
.. _`s0undt3ch`: https://github.com/s0undt3ch
.. _`saltstack/salt#52934`: https://github.com/saltstack/salt/pull/52934
.. _`saltstack/salt#53332`: https://github.com/saltstack/salt/pull/53332
.. _`sathieu`: https://github.com/sathieu
.. _`sbrennan4`: https://github.com/sbrennan4
.. _`sdodsley`: https://github.com/sdodsley
.. _`simonflood`: https://github.com/simonflood
.. _`sjorge`: https://github.com/sjorge
.. _`sleminov-tc`: https://github.com/sleminov-tc
.. _`soer7022`: https://github.com/soer7022
.. _`sploenix`: https://github.com/sploenix
.. _`stratusjerry`: https://github.com/stratusjerry
.. _`syphernl`: https://github.com/syphernl
.. _`tanlingyun2005`: https://github.com/tanlingyun2005
.. _`terminalmage`: https://github.com/terminalmage
.. _`tkwilliams`: https://github.com/tkwilliams
.. _`tomlaredo`: https://github.com/tomlaredo
.. _`twangboy`: https://github.com/twangboy
.. _`waynew`: https://github.com/waynew
.. _`weswhet`: https://github.com/weswhet
.. _`whytewolf`: https://github.com/whytewolf
.. _`wyardley`: https://github.com/wyardley
.. _`xuhcc`: https://github.com/xuhcc
.. _`zyguy`: https://github.com/zyguy
